@@ -1,6 +1,6 @@
 /* valaccodecommaexpression.vala
  *
- * Copyright (C) 2006  Jürg Billeter
+ * Copyright (C) 2006-2007  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -19,17 +19,18 @@
  * Author:
  * 	Jürg Billeter <j@bitron.ch>
  */
-#define VALA_FREE_CHECKED(o,f) ((o) == NULL ? NULL : ((o) = (f (o), NULL)))
-#define VALA_FREE_UNCHECKED(o,f) ((o) = (f (o), NULL))
 
 #include "valaccodecommaexpression.h"
+#include <gee/arraylist.h>
+#include <gee/list.h>
+#include <gee/collection.h>
 #include <stdlib.h>
 #include <string.h>
 #include <ccode/valaccodecommaexpression.h>
 #include <ccode/valaccodenode.h>
 
 struct _ValaCCodeCommaExpressionPrivate {
-	GList* inner;
+	GeeList* inner;
 };
 #define VALA_CCODE_COMMA_EXPRESSION_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_CCODE_COMMA_EXPRESSION, ValaCCodeCommaExpressionPrivate))
 enum  {
@@ -49,7 +50,7 @@ void vala_ccode_comma_expression_append_expression (ValaCCodeCommaExpression* se
 {
 	g_return_if_fail (VALA_IS_CCODE_COMMA_EXPRESSION (self));
 	g_return_if_fail (VALA_IS_CCODE_EXPRESSION (expr));
-	self->priv->inner = g_list_append (self->priv->inner, g_object_ref (expr));
+	gee_collection_add (GEE_COLLECTION (self->priv->inner), expr);
 }
 
 
@@ -57,18 +58,18 @@ static void vala_ccode_comma_expression_real_write (ValaCCodeNode* base, ValaCCo
 {
 	ValaCCodeCommaExpression * self;
 	gboolean first;
-	self = VALA_CCODE_COMMA_EXPRESSION (base);
+	self = ((ValaCCodeCommaExpression*) base);
 	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
 	first = TRUE;
 	vala_ccode_writer_write_string (writer, "(");
 	{
-		GList* __temp0;
-		GList* expr_it;
-		__temp0 = NULL;
-		__temp0 = self->priv->inner;
-		for (expr_it = __temp0; expr_it != NULL; expr_it = expr_it->next) {
+		GeeList* expr_collection;
+		GeeIterator* expr_it;
+		expr_collection = self->priv->inner;
+		expr_it = gee_iterable_iterator (GEE_ITERABLE (expr_collection));
+		while (gee_iterator_next (expr_it)) {
 			ValaCCodeExpression* expr;
-			expr = expr_it->data;
+			expr = gee_iterator_get (expr_it);
 			{
 				if (!first) {
 					vala_ccode_writer_write_string (writer, ", ");
@@ -76,8 +77,10 @@ static void vala_ccode_comma_expression_real_write (ValaCCodeNode* base, ValaCCo
 					first = FALSE;
 				}
 				vala_ccode_node_write (VALA_CCODE_NODE (expr), writer);
+				(expr == NULL ? NULL : (expr = (g_object_unref (expr), NULL)));
 			}
 		}
+		(expr_it == NULL ? NULL : (expr_it = (g_object_unref (expr_it), NULL)));
 	}
 	vala_ccode_writer_write_string (writer, ")");
 }
@@ -95,6 +98,7 @@ static void vala_ccode_comma_expression_class_init (ValaCCodeCommaExpressionClas
 static void vala_ccode_comma_expression_init (ValaCCodeCommaExpression * self)
 {
 	self->priv = VALA_CCODE_COMMA_EXPRESSION_GET_PRIVATE (self);
+	self->priv->inner = GEE_LIST (gee_array_list_new (g_object_ref, g_object_unref, g_direct_equal));
 }
 
 
@@ -104,14 +108,14 @@ static void vala_ccode_comma_expression_dispose (GObject * obj)
 	ValaCCodeCommaExpressionClass * klass;
 	GObjectClass * parent_class;
 	self = VALA_CCODE_COMMA_EXPRESSION (obj);
-	(self->priv->inner == NULL ? NULL : (self->priv->inner = (g_list_foreach (self->priv->inner, (GFunc) g_object_unref, NULL), g_list_free (self->priv->inner), NULL)));
+	(self->priv->inner == NULL ? NULL : (self->priv->inner = (g_object_unref (self->priv->inner), NULL)));
 	klass = VALA_CCODE_COMMA_EXPRESSION_CLASS (g_type_class_peek (VALA_TYPE_CCODE_COMMA_EXPRESSION));
 	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
 	parent_class->dispose (obj);
 }
 
 
-GType vala_ccode_comma_expression_get_type ()
+GType vala_ccode_comma_expression_get_type (void)
 {
 	static GType vala_ccode_comma_expression_type_id = 0;
 	if (G_UNLIKELY (vala_ccode_comma_expression_type_id == 0)) {
