@@ -19,17 +19,18 @@
  * Author:
  * 	Jürg Billeter <j@bitron.ch>
  */
-#define VALA_FREE_CHECKED(o,f) ((o) == NULL ? NULL : ((o) = (f (o), NULL)))
-#define VALA_FREE_UNCHECKED(o,f) ((o) = (f (o), NULL))
 
 #include "valaccodedeclaration.h"
+#include <gee/arraylist.h>
+#include <gee/list.h>
+#include <gee/collection.h>
 #include <ccode/valaccodedeclaration.h>
 #include <ccode/valaccodenode.h>
 
 struct _ValaCCodeDeclarationPrivate {
 	char* _type_name;
 	ValaCCodeModifiers _modifiers;
-	GList* declarators;
+	GeeList* declarators;
 };
 #define VALA_CCODE_DECLARATION_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_CCODE_DECLARATION, ValaCCodeDeclarationPrivate))
 enum  {
@@ -43,16 +44,12 @@ static gpointer vala_ccode_declaration_parent_class = NULL;
 static void vala_ccode_declaration_dispose (GObject * obj);
 
 
-ValaCCodeDeclaration* vala_ccode_declaration_new (const char* _type_name)
+ValaCCodeDeclaration* vala_ccode_declaration_new (const char* type_name)
 {
-	GParameter * __params;
-	GParameter * __params_it;
 	ValaCCodeDeclaration * self;
-	g_return_val_if_fail (_type_name != NULL, NULL);
-	__params = g_new0 (GParameter, 1);
-	__params_it = __params;
-	(__params_it->name = "type-name", g_value_init (&__params_it->value, G_TYPE_STRING), g_value_set_string (&__params_it->value, _type_name), __params_it++);
-	self = g_object_newv (VALA_TYPE_CCODE_DECLARATION, __params_it - __params, __params);
+	g_return_val_if_fail (type_name != NULL, NULL);
+	self = g_object_newv (VALA_TYPE_CCODE_DECLARATION, 0, NULL);
+	vala_ccode_declaration_set_type_name (self, type_name);
 	return self;
 }
 
@@ -66,14 +63,14 @@ void vala_ccode_declaration_add_declarator (ValaCCodeDeclaration* self, ValaCCod
 {
 	g_return_if_fail (VALA_IS_CCODE_DECLARATION (self));
 	g_return_if_fail (VALA_IS_CCODE_DECLARATOR (decl));
-	self->priv->declarators = g_list_append (self->priv->declarators, g_object_ref (decl));
+	gee_collection_add (GEE_COLLECTION (self->priv->declarators), decl);
 }
 
 
 static void vala_ccode_declaration_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer)
 {
 	ValaCCodeDeclaration * self;
-	self = VALA_CCODE_DECLARATION (base);
+	self = ((ValaCCodeDeclaration*) base);
 	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
 	if ((vala_ccode_declaration_get_modifiers (self) & VALA_CCODE_MODIFIERS_STATIC) == VALA_CCODE_MODIFIERS_STATIC) {
 		gboolean first;
@@ -84,13 +81,13 @@ static void vala_ccode_declaration_real_write (ValaCCodeNode* base, ValaCCodeWri
 		vala_ccode_writer_write_string (writer, " ");
 		first = TRUE;
 		{
-			GList* __temp0;
-			GList* decl_it;
-			__temp0 = NULL;
-			__temp0 = self->priv->declarators;
-			for (decl_it = __temp0; decl_it != NULL; decl_it = decl_it->next) {
+			GeeList* decl_collection;
+			GeeIterator* decl_it;
+			decl_collection = self->priv->declarators;
+			decl_it = gee_iterable_iterator (GEE_ITERABLE (decl_collection));
+			while (gee_iterator_next (decl_it)) {
 				ValaCCodeDeclarator* decl;
-				decl = decl_it->data;
+				decl = gee_iterator_get (decl_it);
 				{
 					if (!first) {
 						vala_ccode_writer_write_string (writer, ", ");
@@ -98,24 +95,28 @@ static void vala_ccode_declaration_real_write (ValaCCodeNode* base, ValaCCodeWri
 						first = FALSE;
 					}
 					vala_ccode_node_write (VALA_CCODE_NODE (decl), writer);
+					(decl == NULL ? NULL : (decl = (g_object_unref (decl), NULL)));
 				}
 			}
+			(decl_it == NULL ? NULL : (decl_it = (g_object_unref (decl_it), NULL)));
 		}
 		vala_ccode_writer_write_string (writer, ";");
 		vala_ccode_writer_write_newline (writer);
 	} else {
 		{
-			GList* __temp1;
-			GList* decl_it;
-			__temp1 = NULL;
-			__temp1 = self->priv->declarators;
-			for (decl_it = __temp1; decl_it != NULL; decl_it = decl_it->next) {
+			GeeList* decl_collection;
+			GeeIterator* decl_it;
+			decl_collection = self->priv->declarators;
+			decl_it = gee_iterable_iterator (GEE_ITERABLE (decl_collection));
+			while (gee_iterator_next (decl_it)) {
 				ValaCCodeDeclarator* decl;
-				decl = decl_it->data;
+				decl = gee_iterator_get (decl_it);
 				{
 					vala_ccode_declarator_write_initialization (decl, writer);
+					(decl == NULL ? NULL : (decl = (g_object_unref (decl), NULL)));
 				}
 			}
+			(decl_it == NULL ? NULL : (decl_it = (g_object_unref (decl_it), NULL)));
 		}
 	}
 }
@@ -125,7 +126,7 @@ static void vala_ccode_declaration_real_write_declaration (ValaCCodeNode* base,
 {
 	ValaCCodeDeclaration * self;
 	gboolean first;
-	self = VALA_CCODE_DECLARATION (base);
+	self = ((ValaCCodeDeclaration*) base);
 	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
 	if ((vala_ccode_declaration_get_modifiers (self) & VALA_CCODE_MODIFIERS_STATIC) == VALA_CCODE_MODIFIERS_STATIC) {
 		return;
@@ -139,13 +140,13 @@ static void vala_ccode_declaration_real_write_declaration (ValaCCodeNode* base,
 	vala_ccode_writer_write_string (writer, " ");
 	first = TRUE;
 	{
-		GList* __temp2;
-		GList* decl_it;
-		__temp2 = NULL;
-		__temp2 = self->priv->declarators;
-		for (decl_it = __temp2; decl_it != NULL; decl_it = decl_it->next) {
+		GeeList* decl_collection;
+		GeeIterator* decl_it;
+		decl_collection = self->priv->declarators;
+		decl_it = gee_iterable_iterator (GEE_ITERABLE (decl_collection));
+		while (gee_iterator_next (decl_it)) {
 			ValaCCodeDeclarator* decl;
-			decl = decl_it->data;
+			decl = gee_iterator_get (decl_it);
 			{
 				if (!first) {
 					vala_ccode_writer_write_string (writer, ", ");
@@ -153,8 +154,10 @@ static void vala_ccode_declaration_real_write_declaration (ValaCCodeNode* base,
 					first = FALSE;
 				}
 				vala_ccode_node_write_declaration (VALA_CCODE_NODE (decl), writer);
+				(decl == NULL ? NULL : (decl = (g_object_unref (decl), NULL)));
 			}
 		}
+		(decl_it == NULL ? NULL : (decl_it = (g_object_unref (decl_it), NULL)));
 	}
 	vala_ccode_writer_write_string (writer, ";");
 	vala_ccode_writer_write_newline (writer);
@@ -170,10 +173,10 @@ char* vala_ccode_declaration_get_type_name (ValaCCodeDeclaration* self)
 
 void vala_ccode_declaration_set_type_name (ValaCCodeDeclaration* self, const char* value)
 {
-	char* __temp4;
+	char* __temp1;
 	g_return_if_fail (VALA_IS_CCODE_DECLARATION (self));
-	__temp4 = NULL;
-	self->priv->_type_name = (__temp4 = g_strdup (value), (self->priv->_type_name = (g_free (self->priv->_type_name), NULL)), __temp4);
+	__temp1 = NULL;
+	self->priv->_type_name = (__temp1 = g_strdup (value), (self->priv->_type_name = (g_free (self->priv->_type_name), NULL)), __temp1);
 }
 
 
@@ -230,7 +233,7 @@ static void vala_ccode_declaration_class_init (ValaCCodeDeclarationClass * klass
 	G_OBJECT_CLASS (klass)->dispose = vala_ccode_declaration_dispose;
 	VALA_CCODE_NODE_CLASS (klass)->write = vala_ccode_declaration_real_write;
 	VALA_CCODE_NODE_CLASS (klass)->write_declaration = vala_ccode_declaration_real_write_declaration;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_DECLARATION_TYPE_NAME, g_param_spec_string ("type-name", "foo", "bar", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_DECLARATION_TYPE_NAME, g_param_spec_string ("type-name", "foo", "bar", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_DECLARATION_MODIFIERS, g_param_spec_int ("modifiers", "foo", "bar", G_MININT, G_MAXINT, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
@@ -238,6 +241,7 @@ static void vala_ccode_declaration_class_init (ValaCCodeDeclarationClass * klass
 static void vala_ccode_declaration_init (ValaCCodeDeclaration * self)
 {
 	self->priv = VALA_CCODE_DECLARATION_GET_PRIVATE (self);
+	self->priv->declarators = GEE_LIST (gee_array_list_new (g_object_ref, g_object_unref, g_direct_equal));
 }
 
 
@@ -248,14 +252,14 @@ static void vala_ccode_declaration_dispose (GObject * obj)
 	GObjectClass * parent_class;
 	self = VALA_CCODE_DECLARATION (obj);
 	(self->priv->_type_name = (g_free (self->priv->_type_name), NULL));
-	(self->priv->declarators == NULL ? NULL : (self->priv->declarators = (g_list_foreach (self->priv->declarators, (GFunc) g_object_unref, NULL), g_list_free (self->priv->declarators), NULL)));
+	(self->priv->declarators == NULL ? NULL : (self->priv->declarators = (g_object_unref (self->priv->declarators), NULL)));
 	klass = VALA_CCODE_DECLARATION_CLASS (g_type_class_peek (VALA_TYPE_CCODE_DECLARATION));
 	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
 	parent_class->dispose (obj);
 }
 
 
-GType vala_ccode_declaration_get_type ()
+GType vala_ccode_declaration_get_type (void)
 {
 	static GType vala_ccode_declaration_type_id = 0;
 	if (G_UNLIKELY (vala_ccode_declaration_type_id == 0)) {
