@@ -57,13 +57,13 @@ struct _ValaCCodeDeclarationClass {
 	ValaCCodeStatementClass parent;
 };
 
-ValaCCodeDeclaration* vala_ccode_declaration_new (const char* _type_name);
+ValaCCodeDeclaration* vala_ccode_declaration_new (const char* type_name);
 void vala_ccode_declaration_add_declarator (ValaCCodeDeclaration* self, ValaCCodeDeclarator* decl);
 char* vala_ccode_declaration_get_type_name (ValaCCodeDeclaration* self);
 void vala_ccode_declaration_set_type_name (ValaCCodeDeclaration* self, const char* value);
 ValaCCodeModifiers vala_ccode_declaration_get_modifiers (ValaCCodeDeclaration* self);
 void vala_ccode_declaration_set_modifiers (ValaCCodeDeclaration* self, ValaCCodeModifiers value);
-GType vala_ccode_declaration_get_type ();
+GType vala_ccode_declaration_get_type (void);
 
 G_END_DECLS
 
