@@ -19,15 +19,16 @@
  * Author:
  * 	Jürg Billeter <j@bitron.ch>
  */
-#define VALA_FREE_CHECKED(o,f) ((o) == NULL ? NULL : ((o) = (f (o), NULL)))
-#define VALA_FREE_UNCHECKED(o,f) ((o) = (f (o), NULL))
 
 #include "valaccodeenum.h"
+#include <gee/arraylist.h>
+#include <gee/list.h>
+#include <gee/collection.h>
 #include <ccode/valaccodeenum.h>
 
 struct _ValaCCodeEnumPrivate {
 	char* _name;
-	GList* values;
+	GeeList* values;
 };
 #define VALA_CCODE_ENUM_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_CCODE_ENUM, ValaCCodeEnumPrivate))
 enum  {
@@ -39,15 +40,11 @@ static gpointer vala_ccode_enum_parent_class = NULL;
 static void vala_ccode_enum_dispose (GObject * obj);
 
 
-ValaCCodeEnum* vala_ccode_enum_new (const char* n)
+ValaCCodeEnum* vala_ccode_enum_new (const char* name)
 {
-	GParameter * __params;
-	GParameter * __params_it;
 	ValaCCodeEnum * self;
-	__params = g_new0 (GParameter, 1);
-	__params_it = __params;
-	(__params_it->name = "name", g_value_init (&__params_it->value, G_TYPE_STRING), g_value_set_string (&__params_it->value, n), __params_it++);
-	self = g_object_newv (VALA_TYPE_CCODE_ENUM, __params_it - __params, __params);
+	self = g_object_newv (VALA_TYPE_CCODE_ENUM, 0, NULL);
+	vala_ccode_enum_set_name (self, name);
 	return self;
 }
 
@@ -63,9 +60,12 @@ void vala_ccode_enum_add_value (ValaCCodeEnum* self, const char* name, const cha
 	g_return_if_fail (VALA_IS_CCODE_ENUM (self));
 	g_return_if_fail (name != NULL);
 	if (value == NULL) {
-		self->priv->values = g_list_append (self->priv->values, g_strdup (name));
+		gee_collection_add (GEE_COLLECTION (self->priv->values), name);
 	} else {
-		self->priv->values = g_list_append (self->priv->values, g_strdup_printf ("%s = %s", name, value));
+		char* __temp0;
+		__temp0 = NULL;
+		gee_collection_add (GEE_COLLECTION (self->priv->values), (__temp0 = g_strdup_printf ("%s = %s", name, value)));
+		(__temp0 = (g_free (__temp0), NULL));
 	}
 }
 
@@ -74,7 +74,7 @@ static void vala_ccode_enum_real_write (ValaCCodeNode* base, ValaCCodeWriter* wr
 {
 	ValaCCodeEnum * self;
 	gboolean first;
-	self = VALA_CCODE_ENUM (base);
+	self = ((ValaCCodeEnum*) base);
 	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
 	if (vala_ccode_enum_get_name (self) != NULL) {
 		vala_ccode_writer_write_string (writer, "typedef ");
@@ -83,13 +83,13 @@ static void vala_ccode_enum_real_write (ValaCCodeNode* base, ValaCCodeWriter* wr
 	vala_ccode_writer_write_begin_block (writer);
 	first = TRUE;
 	{
-		GList* __temp0;
-		GList* value_it;
-		__temp0 = NULL;
-		__temp0 = self->priv->values;
-		for (value_it = __temp0; value_it != NULL; value_it = value_it->next) {
+		GeeList* value_collection;
+		GeeIterator* value_it;
+		value_collection = self->priv->values;
+		value_it = gee_iterable_iterator (GEE_ITERABLE (value_collection));
+		while (gee_iterator_next (value_it)) {
 			char* value;
-			value = value_it->data;
+			value = gee_iterator_get (value_it);
 			{
 				if (!first) {
 					vala_ccode_writer_write_string (writer, ",");
@@ -98,8 +98,10 @@ static void vala_ccode_enum_real_write (ValaCCodeNode* base, ValaCCodeWriter* wr
 				vala_ccode_writer_write_indent (writer);
 				vala_ccode_writer_write_string (writer, value);
 				first = FALSE;
+				(value = (g_free (value), NULL));
 			}
 		}
+		(value_it == NULL ? NULL : (value_it = (g_object_unref (value_it), NULL)));
 	}
 	if (!first) {
 		vala_ccode_writer_write_newline (writer);
@@ -171,6 +173,7 @@ static void vala_ccode_enum_class_init (ValaCCodeEnumClass * klass)
 static void vala_ccode_enum_init (ValaCCodeEnum * self)
 {
 	self->priv = VALA_CCODE_ENUM_GET_PRIVATE (self);
+	self->priv->values = GEE_LIST (gee_array_list_new (g_strdup, g_free, g_direct_equal));
 }
 
 
@@ -181,14 +184,14 @@ static void vala_ccode_enum_dispose (GObject * obj)
 	GObjectClass * parent_class;
 	self = VALA_CCODE_ENUM (obj);
 	(self->priv->_name = (g_free (self->priv->_name), NULL));
-	(self->priv->values == NULL ? NULL : (self->priv->values = (g_list_foreach (self->priv->values, (GFunc) g_free, NULL), g_list_free (self->priv->values), NULL)));
+	(self->priv->values == NULL ? NULL : (self->priv->values = (g_object_unref (self->priv->values), NULL)));
 	klass = VALA_CCODE_ENUM_CLASS (g_type_class_peek (VALA_TYPE_CCODE_ENUM));
 	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
 	parent_class->dispose (obj);
 }
 
 
-GType vala_ccode_enum_get_type ()
+GType vala_ccode_enum_get_type (void)
 {
 	static GType vala_ccode_enum_type_id = 0;
 	if (G_UNLIKELY (vala_ccode_enum_type_id == 0)) {
