@@ -1,6 +1,6 @@
 /* valaccodeforstatement.vala
  *
- * Copyright (C) 2006  Jürg Billeter
+ * Copyright (C) 2006-2007  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -54,14 +54,14 @@ struct _ValaCCodeForStatementClass {
 	ValaCCodeStatementClass parent;
 };
 
-ValaCCodeForStatement* vala_ccode_for_statement_new (ValaCCodeExpression* cond, ValaCCodeStatement* stmt);
+ValaCCodeForStatement* vala_ccode_for_statement_new (ValaCCodeExpression* condition, ValaCCodeStatement* body);
 void vala_ccode_for_statement_add_initializer (ValaCCodeForStatement* self, ValaCCodeExpression* expr);
 void vala_ccode_for_statement_add_iterator (ValaCCodeForStatement* self, ValaCCodeExpression* expr);
 ValaCCodeExpression* vala_ccode_for_statement_get_condition (ValaCCodeForStatement* self);
 void vala_ccode_for_statement_set_condition (ValaCCodeForStatement* self, ValaCCodeExpression* value);
 ValaCCodeStatement* vala_ccode_for_statement_get_body (ValaCCodeForStatement* self);
 void vala_ccode_for_statement_set_body (ValaCCodeForStatement* self, ValaCCodeStatement* value);
-GType vala_ccode_for_statement_get_type ();
+GType vala_ccode_for_statement_get_type (void);
 
 G_END_DECLS
 
