@@ -22,9 +22,6 @@
 
 #ifndef __VALACCODEIDENTIFIER_H__
 #define __VALACCODEIDENTIFIER_H__
-typedef struct _ValaCCodeIdentifier ValaCCodeIdentifier;
-typedef struct _ValaCCodeIdentifierClass ValaCCodeIdentifierClass;
-typedef struct _ValaCCodeIdentifierPrivate ValaCCodeIdentifierPrivate;
 
 #include <glib.h>
 #include <glib-object.h>
@@ -43,6 +40,9 @@ G_BEGIN_DECLS
 #define VALA_IS_CCODE_IDENTIFIER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_CCODE_IDENTIFIER))
 #define VALA_CCODE_IDENTIFIER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_CCODE_IDENTIFIER, ValaCCodeIdentifierClass))
 
+typedef struct _ValaCCodeIdentifier ValaCCodeIdentifier;
+typedef struct _ValaCCodeIdentifierClass ValaCCodeIdentifierClass;
+typedef struct _ValaCCodeIdentifierPrivate ValaCCodeIdentifierPrivate;
 
 /**
  * Represents a identifier in the C code.
@@ -58,7 +58,7 @@ struct _ValaCCodeIdentifierClass {
 ValaCCodeIdentifier* vala_ccode_identifier_new (const char* _name);
 char* vala_ccode_identifier_get_name (ValaCCodeIdentifier* self);
 void vala_ccode_identifier_set_name (ValaCCodeIdentifier* self, const char* value);
-GType vala_ccode_identifier_get_type ();
+GType vala_ccode_identifier_get_type (void);
 
 G_END_DECLS
 
