@@ -19,8 +19,6 @@
  * Author:
  * 	Jürg Billeter <j@bitron.ch>
  */
-#define VALA_FREE_CHECKED(o,f) ((o) == NULL ? NULL : ((o) = (f (o), NULL)))
-#define VALA_FREE_UNCHECKED(o,f) ((o) = (f (o), NULL))
 
 #include "valaccodeincludedirective.h"
 #include <ccode/valaccodeincludedirective.h>
@@ -33,7 +31,7 @@ struct _ValaCCodeIncludeDirectivePrivate {
 enum  {
 	VALA_CCODE_INCLUDE_DIRECTIVE_DUMMY_PROPERTY,
 	VALA_CCODE_INCLUDE_DIRECTIVE_FILENAME,
-	VALA_CCODE_INCLUDE_DIRECTIVE_LOCAL,
+	VALA_CCODE_INCLUDE_DIRECTIVE_LOCAL
 };
 static void vala_ccode_include_directive_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer);
 static gpointer vala_ccode_include_directive_parent_class = NULL;
@@ -42,19 +40,28 @@ static void vala_ccode_include_directive_dispose (GObject * obj);
 
 ValaCCodeIncludeDirective* vala_ccode_include_directive_new (const char* _filename, gboolean _local)
 {
+	GParameter * __params;
+	GParameter * __params_it;
+	ValaCCodeIncludeDirective * self;
 	g_return_val_if_fail (_filename != NULL, NULL);
-	GParameter * __params = g_new0 (GParameter, 2);
-	GParameter * __params_it = __params;
+	__params = g_new0 (GParameter, 1);
+	__params_it = __params;
 	(__params_it->name = "filename", g_value_init (&__params_it->value, G_TYPE_STRING), g_value_set_string (&__params_it->value, _filename), __params_it++);
-	(__params_it->name = "local", g_value_init (&__params_it->value, G_TYPE_BOOLEAN), g_value_set_boolean (&__params_it->value, _local), __params_it++);
-	ValaCCodeIncludeDirective * self = g_object_newv (VALA_TYPE_CCODE_INCLUDE_DIRECTIVE, __params_it - __params, __params);
+	self = g_object_newv (VALA_TYPE_CCODE_INCLUDE_DIRECTIVE, __params_it - __params, __params);
+	vala_ccode_include_directive_set_local (self, _local);
+	while (__params_it > __params) {
+		--__params_it;
+		g_value_unset (&__params_it->value);
+	}
+	g_free (__params);
 	return self;
 }
 
 
 static void vala_ccode_include_directive_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer)
 {
-	ValaCCodeIncludeDirective * self = VALA_CCODE_INCLUDE_DIRECTIVE (base);
+	ValaCCodeIncludeDirective * self;
+	self = ((ValaCCodeIncludeDirective*) base);
 	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
 	vala_ccode_writer_write_indent (writer);
 	vala_ccode_writer_write_string (writer, "#include ");
@@ -82,8 +89,9 @@ char* vala_ccode_include_directive_get_filename (ValaCCodeIncludeDirective* self
 
 void vala_ccode_include_directive_set_filename (ValaCCodeIncludeDirective* self, const char* value)
 {
+	char* __temp1;
 	g_return_if_fail (VALA_IS_CCODE_INCLUDE_DIRECTIVE (self));
-	char* __temp1 = NULL;
+	__temp1 = NULL;
 	self->priv->_filename = (__temp1 = g_strdup (value), (self->priv->_filename = (g_free (self->priv->_filename), NULL)), __temp1);
 }
 
@@ -104,7 +112,8 @@ void vala_ccode_include_directive_set_local (ValaCCodeIncludeDirective* self, gb
 
 static void vala_ccode_include_directive_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec)
 {
-	ValaCCodeIncludeDirective * self = VALA_CCODE_INCLUDE_DIRECTIVE (object);
+	ValaCCodeIncludeDirective * self;
+	self = VALA_CCODE_INCLUDE_DIRECTIVE (object);
 	switch (property_id) {
 		case VALA_CCODE_INCLUDE_DIRECTIVE_FILENAME:
 		g_value_set_string (value, vala_ccode_include_directive_get_filename (self));
@@ -118,7 +127,8 @@ static void vala_ccode_include_directive_get_property (GObject * object, guint p
 
 static void vala_ccode_include_directive_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec)
 {
-	ValaCCodeIncludeDirective * self = VALA_CCODE_INCLUDE_DIRECTIVE (object);
+	ValaCCodeIncludeDirective * self;
+	self = VALA_CCODE_INCLUDE_DIRECTIVE (object);
 	switch (property_id) {
 		case VALA_CCODE_INCLUDE_DIRECTIVE_FILENAME:
 		vala_ccode_include_directive_set_filename (self, g_value_get_string (value));
@@ -151,17 +161,18 @@ static void vala_ccode_include_directive_init (ValaCCodeIncludeDirective * self)
 
 static void vala_ccode_include_directive_dispose (GObject * obj)
 {
-	ValaCCodeIncludeDirective * self = VALA_CCODE_INCLUDE_DIRECTIVE (obj);
-	(self->priv->_filename = (g_free (self->priv->_filename), NULL));
+	ValaCCodeIncludeDirective * self;
 	ValaCCodeIncludeDirectiveClass * klass;
 	GObjectClass * parent_class;
+	self = VALA_CCODE_INCLUDE_DIRECTIVE (obj);
+	(self->priv->_filename = (g_free (self->priv->_filename), NULL));
 	klass = VALA_CCODE_INCLUDE_DIRECTIVE_CLASS (g_type_class_peek (VALA_TYPE_CCODE_INCLUDE_DIRECTIVE));
 	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
 	parent_class->dispose (obj);
 }
 
 
-GType vala_ccode_include_directive_get_type ()
+GType vala_ccode_include_directive_get_type (void)
 {
 	static GType vala_ccode_include_directive_type_id = 0;
 	if (G_UNLIKELY (vala_ccode_include_directive_type_id == 0)) {
