@@ -20,8 +20,6 @@
  * Author:
  * 	Jürg Billeter <j@bitron.ch>
  */
-#define VALA_FREE_CHECKED(o,f) ((o) == NULL ? NULL : ((o) = (f (o), NULL)))
-#define VALA_FREE_UNCHECKED(o,f) ((o) = (f (o), NULL))
 
 #include "valaccodenewline.h"
 
@@ -35,7 +33,7 @@ static gpointer vala_ccode_newline_parent_class = NULL;
 static void vala_ccode_newline_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer)
 {
 	ValaCCodeNewline * self;
-	self = VALA_CCODE_NEWLINE (base);
+	self = ((ValaCCodeNewline*) base);
 	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
 	vala_ccode_writer_write_newline (writer);
 }
@@ -53,7 +51,7 @@ static void vala_ccode_newline_init (ValaCCodeNewline * self)
 }
 
 
-GType vala_ccode_newline_get_type ()
+GType vala_ccode_newline_get_type (void)
 {
 	static GType vala_ccode_newline_type_id = 0;
 	if (G_UNLIKELY (vala_ccode_newline_type_id == 0)) {
