@@ -19,8 +19,6 @@
  * Author:
  * 	Jürg Billeter <j@bitron.ch>
  */
-#define VALA_FREE_CHECKED(o,f) ((o) == NULL ? NULL : ((o) = (f (o), NULL)))
-#define VALA_FREE_UNCHECKED(o,f) ((o) = (f (o), NULL))
 
 #include "valaccodenode.h"
 #include <ccode/valaccodelinedirective.h>
@@ -160,7 +158,7 @@ static void vala_ccode_node_dispose (GObject * obj)
 }
 
 
-GType vala_ccode_node_get_type ()
+GType vala_ccode_node_get_type (void)
 {
 	static GType vala_ccode_node_type_id = 0;
 	if (G_UNLIKELY (vala_ccode_node_type_id == 0)) {
