@@ -19,8 +19,6 @@
  * Author:
  * 	Jürg Billeter <j@bitron.ch>
  */
-#define VALA_FREE_CHECKED(o,f) ((o) == NULL ? NULL : ((o) = (f (o), NULL)))
-#define VALA_FREE_UNCHECKED(o,f) ((o) = (f (o), NULL))
 
 #include "valaccodeparenthesizedexpression.h"
 #include <stdlib.h>
@@ -34,7 +32,7 @@ struct _ValaCCodeParenthesizedExpressionPrivate {
 #define VALA_CCODE_PARENTHESIZED_EXPRESSION_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_CCODE_PARENTHESIZED_EXPRESSION, ValaCCodeParenthesizedExpressionPrivate))
 enum  {
 	VALA_CCODE_PARENTHESIZED_EXPRESSION_DUMMY_PROPERTY,
-	VALA_CCODE_PARENTHESIZED_EXPRESSION_INNER,
+	VALA_CCODE_PARENTHESIZED_EXPRESSION_INNER
 };
 static void vala_ccode_parenthesized_expression_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer);
 static gpointer vala_ccode_parenthesized_expression_parent_class = NULL;
@@ -43,18 +41,27 @@ static void vala_ccode_parenthesized_expression_dispose (GObject * obj);
 
 ValaCCodeParenthesizedExpression* vala_ccode_parenthesized_expression_new (ValaCCodeExpression* expr)
 {
+	GParameter * __params;
+	GParameter * __params_it;
+	ValaCCodeParenthesizedExpression * self;
 	g_return_val_if_fail (VALA_IS_CCODE_EXPRESSION (expr), NULL);
-	GParameter * __params = g_new0 (GParameter, 1);
-	GParameter * __params_it = __params;
+	__params = g_new0 (GParameter, 1);
+	__params_it = __params;
 	(__params_it->name = "inner", g_value_init (&__params_it->value, VALA_TYPE_CCODE_EXPRESSION), g_value_set_object (&__params_it->value, expr), __params_it++);
-	ValaCCodeParenthesizedExpression * self = g_object_newv (VALA_TYPE_CCODE_PARENTHESIZED_EXPRESSION, __params_it - __params, __params);
+	self = g_object_newv (VALA_TYPE_CCODE_PARENTHESIZED_EXPRESSION, __params_it - __params, __params);
+	while (__params_it > __params) {
+		--__params_it;
+		g_value_unset (&__params_it->value);
+	}
+	g_free (__params);
 	return self;
 }
 
 
 static void vala_ccode_parenthesized_expression_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer)
 {
-	ValaCCodeParenthesizedExpression * self = VALA_CCODE_PARENTHESIZED_EXPRESSION (base);
+	ValaCCodeParenthesizedExpression * self;
+	self = ((ValaCCodeParenthesizedExpression*) base);
 	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
 	vala_ccode_writer_write_string (writer, "(");
 	vala_ccode_node_write (VALA_CCODE_NODE (vala_ccode_parenthesized_expression_get_inner (self)), writer);
@@ -71,15 +78,17 @@ ValaCCodeExpression* vala_ccode_parenthesized_expression_get_inner (ValaCCodePar
 
 void vala_ccode_parenthesized_expression_set_inner (ValaCCodeParenthesizedExpression* self, ValaCCodeExpression* value)
 {
+	ValaCCodeExpression* __temp1;
 	g_return_if_fail (VALA_IS_CCODE_PARENTHESIZED_EXPRESSION (self));
-	ValaCCodeExpression* __temp1 = NULL;
+	__temp1 = NULL;
 	self->priv->_inner = (__temp1 = g_object_ref (value), (self->priv->_inner == NULL ? NULL : (self->priv->_inner = (g_object_unref (self->priv->_inner), NULL))), __temp1);
 }
 
 
 static void vala_ccode_parenthesized_expression_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec)
 {
-	ValaCCodeParenthesizedExpression * self = VALA_CCODE_PARENTHESIZED_EXPRESSION (object);
+	ValaCCodeParenthesizedExpression * self;
+	self = VALA_CCODE_PARENTHESIZED_EXPRESSION (object);
 	switch (property_id) {
 		case VALA_CCODE_PARENTHESIZED_EXPRESSION_INNER:
 		g_value_set_object (value, vala_ccode_parenthesized_expression_get_inner (self));
@@ -90,7 +99,8 @@ static void vala_ccode_parenthesized_expression_get_property (GObject * object,
 
 static void vala_ccode_parenthesized_expression_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec)
 {
-	ValaCCodeParenthesizedExpression * self = VALA_CCODE_PARENTHESIZED_EXPRESSION (object);
+	ValaCCodeParenthesizedExpression * self;
+	self = VALA_CCODE_PARENTHESIZED_EXPRESSION (object);
 	switch (property_id) {
 		case VALA_CCODE_PARENTHESIZED_EXPRESSION_INNER:
 		vala_ccode_parenthesized_expression_set_inner (self, g_value_get_object (value));
@@ -119,17 +129,18 @@ static void vala_ccode_parenthesized_expression_init (ValaCCodeParenthesizedExpr
 
 static void vala_ccode_parenthesized_expression_dispose (GObject * obj)
 {
-	ValaCCodeParenthesizedExpression * self = VALA_CCODE_PARENTHESIZED_EXPRESSION (obj);
-	(self->priv->_inner == NULL ? NULL : (self->priv->_inner = (g_object_unref (self->priv->_inner), NULL)));
+	ValaCCodeParenthesizedExpression * self;
 	ValaCCodeParenthesizedExpressionClass * klass;
 	GObjectClass * parent_class;
+	self = VALA_CCODE_PARENTHESIZED_EXPRESSION (obj);
+	(self->priv->_inner == NULL ? NULL : (self->priv->_inner = (g_object_unref (self->priv->_inner), NULL)));
 	klass = VALA_CCODE_PARENTHESIZED_EXPRESSION_CLASS (g_type_class_peek (VALA_TYPE_CCODE_PARENTHESIZED_EXPRESSION));
 	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
 	parent_class->dispose (obj);
 }
 
 
-GType vala_ccode_parenthesized_expression_get_type ()
+GType vala_ccode_parenthesized_expression_get_type (void)
 {
 	static GType vala_ccode_parenthesized_expression_type_id = 0;
 	if (G_UNLIKELY (vala_ccode_parenthesized_expression_type_id == 0)) {
