@@ -22,9 +22,6 @@
 
 #ifndef __VALACCODESTATEMENT_H__
 #define __VALACCODESTATEMENT_H__
-typedef struct _ValaCCodeStatement ValaCCodeStatement;
-typedef struct _ValaCCodeStatementClass ValaCCodeStatementClass;
-typedef struct _ValaCCodeStatementPrivate ValaCCodeStatementPrivate;
 
 #include <glib.h>
 #include <glib-object.h>
@@ -40,6 +37,9 @@ G_BEGIN_DECLS
 #define VALA_IS_CCODE_STATEMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_CCODE_STATEMENT))
 #define VALA_CCODE_STATEMENT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_CCODE_STATEMENT, ValaCCodeStatementClass))
 
+typedef struct _ValaCCodeStatement ValaCCodeStatement;
+typedef struct _ValaCCodeStatementClass ValaCCodeStatementClass;
+typedef struct _ValaCCodeStatementPrivate ValaCCodeStatementPrivate;
 
 /**
  * Represents a statement in the C code.
@@ -52,7 +52,7 @@ struct _ValaCCodeStatementClass {
 	ValaCCodeNodeClass parent;
 };
 
-GType vala_ccode_statement_get_type ();
+GType vala_ccode_statement_get_type (void);
 
 G_END_DECLS
 
