@@ -22,9 +22,6 @@
 
 #ifndef __VALACCODESTRUCT_H__
 #define __VALACCODESTRUCT_H__
-typedef struct _ValaCCodeStruct ValaCCodeStruct;
-typedef struct _ValaCCodeStructClass ValaCCodeStructClass;
-typedef struct _ValaCCodeStructPrivate ValaCCodeStructPrivate;
 
 #include <glib.h>
 #include <glib-object.h>
@@ -44,6 +41,9 @@ G_BEGIN_DECLS
 #define VALA_IS_CCODE_STRUCT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_CCODE_STRUCT))
 #define VALA_CCODE_STRUCT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_CCODE_STRUCT, ValaCCodeStructClass))
 
+typedef struct _ValaCCodeStruct ValaCCodeStruct;
+typedef struct _ValaCCodeStructClass ValaCCodeStructClass;
+typedef struct _ValaCCodeStructPrivate ValaCCodeStructPrivate;
 
 /**
  * Represents a struct declaration in the C code.
@@ -56,12 +56,12 @@ struct _ValaCCodeStructClass {
 	ValaCCodeNodeClass parent;
 };
 
-ValaCCodeStruct* vala_ccode_struct_new (const char* n);
+ValaCCodeStruct* vala_ccode_struct_new (const char* name);
 void vala_ccode_struct_add_declaration (ValaCCodeStruct* self, ValaCCodeDeclaration* decl);
 void vala_ccode_struct_add_field (ValaCCodeStruct* self, const char* type_name, const char* name);
 char* vala_ccode_struct_get_name (ValaCCodeStruct* self);
 void vala_ccode_struct_set_name (ValaCCodeStruct* self, const char* value);
-GType vala_ccode_struct_get_type ();
+GType vala_ccode_struct_get_type (void);
 
 G_END_DECLS
 
