@@ -1,6 +1,6 @@
 /* valaccodeswitchstatement.vala
  *
- * Copyright (C) 2006  Jürg Billeter
+ * Copyright (C) 2006-2007  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -19,10 +19,11 @@
  * Author:
  * 	Jürg Billeter <j@bitron.ch>
  */
-#define VALA_FREE_CHECKED(o,f) ((o) == NULL ? NULL : ((o) = (f (o), NULL)))
-#define VALA_FREE_UNCHECKED(o,f) ((o) = (f (o), NULL))
 
 #include "valaccodeswitchstatement.h"
+#include <gee/arraylist.h>
+#include <gee/list.h>
+#include <gee/collection.h>
 #include <stdlib.h>
 #include <string.h>
 #include <ccode/valaccodeswitchstatement.h>
@@ -30,25 +31,24 @@
 
 struct _ValaCCodeSwitchStatementPrivate {
 	ValaCCodeExpression* _expression;
-	GList* case_statements;
+	GeeList* case_statements;
 };
 #define VALA_CCODE_SWITCH_STATEMENT_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_CCODE_SWITCH_STATEMENT, ValaCCodeSwitchStatementPrivate))
 enum  {
 	VALA_CCODE_SWITCH_STATEMENT_DUMMY_PROPERTY,
-	VALA_CCODE_SWITCH_STATEMENT_EXPRESSION,
+	VALA_CCODE_SWITCH_STATEMENT_EXPRESSION
 };
 static void vala_ccode_switch_statement_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer);
 static gpointer vala_ccode_switch_statement_parent_class = NULL;
 static void vala_ccode_switch_statement_dispose (GObject * obj);
 
 
-ValaCCodeSwitchStatement* vala_ccode_switch_statement_new (ValaCCodeExpression* expr)
+ValaCCodeSwitchStatement* vala_ccode_switch_statement_new (ValaCCodeExpression* expression)
 {
-	g_return_val_if_fail (VALA_IS_CCODE_EXPRESSION (expr), NULL);
-	GParameter * __params = g_new0 (GParameter, 1);
-	GParameter * __params_it = __params;
-	(__params_it->name = "expression", g_value_init (&__params_it->value, VALA_TYPE_CCODE_EXPRESSION), g_value_set_object (&__params_it->value, expr), __params_it++);
-	ValaCCodeSwitchStatement * self = g_object_newv (VALA_TYPE_CCODE_SWITCH_STATEMENT, __params_it - __params, __params);
+	ValaCCodeSwitchStatement * self;
+	g_return_val_if_fail (VALA_IS_CCODE_EXPRESSION (expression), NULL);
+	self = g_object_newv (VALA_TYPE_CCODE_SWITCH_STATEMENT, 0, NULL);
+	vala_ccode_switch_statement_set_expression (self, expression);
 	return self;
 }
 
@@ -62,13 +62,14 @@ void vala_ccode_switch_statement_add_case (ValaCCodeSwitchStatement* self, ValaC
 {
 	g_return_if_fail (VALA_IS_CCODE_SWITCH_STATEMENT (self));
 	g_return_if_fail (VALA_IS_CCODE_CASE_STATEMENT (case_stmt));
-	self->priv->case_statements = g_list_append (self->priv->case_statements, g_object_ref (case_stmt));
+	gee_collection_add (GEE_COLLECTION (self->priv->case_statements), case_stmt);
 }
 
 
 static void vala_ccode_switch_statement_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer)
 {
-	ValaCCodeSwitchStatement * self = VALA_CCODE_SWITCH_STATEMENT (base);
+	ValaCCodeSwitchStatement * self;
+	self = ((ValaCCodeSwitchStatement*) base);
 	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
 	vala_ccode_writer_write_indent (writer);
 	vala_ccode_writer_write_string (writer, "switch (");
@@ -76,15 +77,19 @@ static void vala_ccode_switch_statement_real_write (ValaCCodeNode* base, ValaCCo
 	vala_ccode_writer_write_string (writer, ")");
 	vala_ccode_writer_write_begin_block (writer);
 	{
-		GList* __temp0 = NULL;
-		__temp0 = self->priv->case_statements;
-		GList* case_stmt_it;
-		for (case_stmt_it = __temp0; case_stmt_it != NULL; case_stmt_it = case_stmt_it->next) {
-			ValaCCodeCaseStatement* case_stmt = case_stmt_it->data;
+		GeeList* case_stmt_collection;
+		GeeIterator* case_stmt_it;
+		case_stmt_collection = self->priv->case_statements;
+		case_stmt_it = gee_iterable_iterator (GEE_ITERABLE (case_stmt_collection));
+		while (gee_iterator_next (case_stmt_it)) {
+			ValaCCodeCaseStatement* case_stmt;
+			case_stmt = gee_iterator_get (case_stmt_it);
 			{
 				vala_ccode_node_write (VALA_CCODE_NODE (case_stmt), writer);
+				(case_stmt == NULL ? NULL : (case_stmt = (g_object_unref (case_stmt), NULL)));
 			}
 		}
+		(case_stmt_it == NULL ? NULL : (case_stmt_it = (g_object_unref (case_stmt_it), NULL)));
 	}
 	vala_ccode_writer_write_end_block (writer);
 }
@@ -99,15 +104,17 @@ ValaCCodeExpression* vala_ccode_switch_statement_get_expression (ValaCCodeSwitch
 
 void vala_ccode_switch_statement_set_expression (ValaCCodeSwitchStatement* self, ValaCCodeExpression* value)
 {
+	ValaCCodeExpression* __temp1;
 	g_return_if_fail (VALA_IS_CCODE_SWITCH_STATEMENT (self));
-	ValaCCodeExpression* __temp2 = NULL;
-	self->priv->_expression = (__temp2 = g_object_ref (value), (self->priv->_expression == NULL ? NULL : (self->priv->_expression = (g_object_unref (self->priv->_expression), NULL))), __temp2);
+	__temp1 = NULL;
+	self->priv->_expression = (__temp1 = g_object_ref (value), (self->priv->_expression == NULL ? NULL : (self->priv->_expression = (g_object_unref (self->priv->_expression), NULL))), __temp1);
 }
 
 
 static void vala_ccode_switch_statement_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec)
 {
-	ValaCCodeSwitchStatement * self = VALA_CCODE_SWITCH_STATEMENT (object);
+	ValaCCodeSwitchStatement * self;
+	self = VALA_CCODE_SWITCH_STATEMENT (object);
 	switch (property_id) {
 		case VALA_CCODE_SWITCH_STATEMENT_EXPRESSION:
 		g_value_set_object (value, vala_ccode_switch_statement_get_expression (self));
@@ -118,7 +125,8 @@ static void vala_ccode_switch_statement_get_property (GObject * object, guint pr
 
 static void vala_ccode_switch_statement_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec)
 {
-	ValaCCodeSwitchStatement * self = VALA_CCODE_SWITCH_STATEMENT (object);
+	ValaCCodeSwitchStatement * self;
+	self = VALA_CCODE_SWITCH_STATEMENT (object);
 	switch (property_id) {
 		case VALA_CCODE_SWITCH_STATEMENT_EXPRESSION:
 		vala_ccode_switch_statement_set_expression (self, g_value_get_object (value));
@@ -135,30 +143,32 @@ static void vala_ccode_switch_statement_class_init (ValaCCodeSwitchStatementClas
 	G_OBJECT_CLASS (klass)->set_property = vala_ccode_switch_statement_set_property;
 	G_OBJECT_CLASS (klass)->dispose = vala_ccode_switch_statement_dispose;
 	VALA_CCODE_NODE_CLASS (klass)->write = vala_ccode_switch_statement_real_write;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_SWITCH_STATEMENT_EXPRESSION, g_param_spec_object ("expression", "foo", "bar", VALA_TYPE_CCODE_EXPRESSION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_SWITCH_STATEMENT_EXPRESSION, g_param_spec_object ("expression", "foo", "bar", VALA_TYPE_CCODE_EXPRESSION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
 
 static void vala_ccode_switch_statement_init (ValaCCodeSwitchStatement * self)
 {
 	self->priv = VALA_CCODE_SWITCH_STATEMENT_GET_PRIVATE (self);
+	self->priv->case_statements = GEE_LIST (gee_array_list_new (g_object_ref, g_object_unref, g_direct_equal));
 }
 
 
 static void vala_ccode_switch_statement_dispose (GObject * obj)
 {
-	ValaCCodeSwitchStatement * self = VALA_CCODE_SWITCH_STATEMENT (obj);
-	(self->priv->_expression == NULL ? NULL : (self->priv->_expression = (g_object_unref (self->priv->_expression), NULL)));
-	(self->priv->case_statements == NULL ? NULL : (self->priv->case_statements = (g_list_foreach (self->priv->case_statements, (GFunc) g_object_unref, NULL), g_list_free (self->priv->case_statements), NULL)));
+	ValaCCodeSwitchStatement * self;
 	ValaCCodeSwitchStatementClass * klass;
 	GObjectClass * parent_class;
+	self = VALA_CCODE_SWITCH_STATEMENT (obj);
+	(self->priv->_expression == NULL ? NULL : (self->priv->_expression = (g_object_unref (self->priv->_expression), NULL)));
+	(self->priv->case_statements == NULL ? NULL : (self->priv->case_statements = (g_object_unref (self->priv->case_statements), NULL)));
 	klass = VALA_CCODE_SWITCH_STATEMENT_CLASS (g_type_class_peek (VALA_TYPE_CCODE_SWITCH_STATEMENT));
 	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
 	parent_class->dispose (obj);
 }
 
 
-GType vala_ccode_switch_statement_get_type ()
+GType vala_ccode_switch_statement_get_type (void)
 {
 	static GType vala_ccode_switch_statement_type_id = 0;
 	if (G_UNLIKELY (vala_ccode_switch_statement_type_id == 0)) {
