@@ -61,7 +61,7 @@ char* vala_ccode_type_definition_get_type_name (ValaCCodeTypeDefinition* self);
 void vala_ccode_type_definition_set_type_name (ValaCCodeTypeDefinition* self, const char* value);
 ValaCCodeDeclarator* vala_ccode_type_definition_get_declarator (ValaCCodeTypeDefinition* self);
 void vala_ccode_type_definition_set_declarator (ValaCCodeTypeDefinition* self, ValaCCodeDeclarator* value);
-GType vala_ccode_type_definition_get_type ();
+GType vala_ccode_type_definition_get_type (void);
 
 G_END_DECLS
 
