@@ -19,8 +19,6 @@
  * Author:
  * 	Jürg Billeter <j@bitron.ch>
  */
-#define VALA_FREE_CHECKED(o,f) ((o) == NULL ? NULL : ((o) = (f (o), NULL)))
-#define VALA_FREE_UNCHECKED(o,f) ((o) = (f (o), NULL))
 
 #include "valaccodevariabledeclarator.h"
 #include <ccode/valaccodevariabledeclarator.h>
@@ -53,6 +51,11 @@ ValaCCodeVariableDeclarator* vala_ccode_variable_declarator_new (const char* _na
 	__params_it = __params;
 	(__params_it->name = "name", g_value_init (&__params_it->value, G_TYPE_STRING), g_value_set_string (&__params_it->value, _name), __params_it++);
 	self = g_object_newv (VALA_TYPE_CCODE_VARIABLE_DECLARATOR, __params_it - __params, __params);
+	while (__params_it > __params) {
+		--__params_it;
+		g_value_unset (&__params_it->value);
+	}
+	g_free (__params);
 	return self;
 }
 
@@ -64,11 +67,16 @@ ValaCCodeVariableDeclarator* vala_ccode_variable_declarator_new_with_initializer
 	ValaCCodeVariableDeclarator * self;
 	g_return_val_if_fail (_name != NULL, NULL);
 	g_return_val_if_fail (init == NULL || VALA_IS_CCODE_EXPRESSION (init), NULL);
-	__params = g_new0 (GParameter, 2);
+	__params = g_new0 (GParameter, 1);
 	__params_it = __params;
 	(__params_it->name = "name", g_value_init (&__params_it->value, G_TYPE_STRING), g_value_set_string (&__params_it->value, _name), __params_it++);
-	(__params_it->name = "initializer", g_value_init (&__params_it->value, VALA_TYPE_CCODE_EXPRESSION), g_value_set_object (&__params_it->value, init), __params_it++);
 	self = g_object_newv (VALA_TYPE_CCODE_VARIABLE_DECLARATOR, __params_it - __params, __params);
+	vala_ccode_variable_declarator_set_initializer (self, init);
+	while (__params_it > __params) {
+		--__params_it;
+		g_value_unset (&__params_it->value);
+	}
+	g_free (__params);
 	return self;
 }
 
@@ -76,7 +84,7 @@ ValaCCodeVariableDeclarator* vala_ccode_variable_declarator_new_with_initializer
 static void vala_ccode_variable_declarator_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer)
 {
 	ValaCCodeVariableDeclarator * self;
-	self = VALA_CCODE_VARIABLE_DECLARATOR (base);
+	self = ((ValaCCodeVariableDeclarator*) base);
 	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
 	vala_ccode_writer_write_string (writer, vala_ccode_variable_declarator_get_name (self));
 	if (vala_ccode_variable_declarator_get_initializer (self) != NULL) {
@@ -89,7 +97,7 @@ static void vala_ccode_variable_declarator_real_write (ValaCCodeNode* base, Vala
 static void vala_ccode_variable_declarator_real_write_declaration (ValaCCodeNode* base, ValaCCodeWriter* writer)
 {
 	ValaCCodeVariableDeclarator * self;
-	self = VALA_CCODE_VARIABLE_DECLARATOR (base);
+	self = ((ValaCCodeVariableDeclarator*) base);
 	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
 	vala_ccode_writer_write_string (writer, vala_ccode_variable_declarator_get_name (self));
 }
@@ -98,7 +106,7 @@ static void vala_ccode_variable_declarator_real_write_declaration (ValaCCodeNode
 static void vala_ccode_variable_declarator_real_write_initialization (ValaCCodeDeclarator* base, ValaCCodeWriter* writer)
 {
 	ValaCCodeVariableDeclarator * self;
-	self = VALA_CCODE_VARIABLE_DECLARATOR (base);
+	self = ((ValaCCodeVariableDeclarator*) base);
 	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
 	if (vala_ccode_variable_declarator_get_initializer (self) != NULL) {
 		vala_ccode_writer_write_indent (writer);
@@ -210,7 +218,7 @@ static void vala_ccode_variable_declarator_dispose (GObject * obj)
 }
 
 
-GType vala_ccode_variable_declarator_get_type ()
+GType vala_ccode_variable_declarator_get_type (void)
 {
 	static GType vala_ccode_variable_declarator_type_id = 0;
 	if (G_UNLIKELY (vala_ccode_variable_declarator_type_id == 0)) {
