@@ -26,6 +26,8 @@
 #include <glib.h>
 #include <glib-object.h>
 #include <vala/valacodecontext.h>
+#include <stdlib.h>
+#include <string.h>
 
 G_BEGIN_DECLS
 
@@ -52,9 +54,9 @@ struct _ValaCCodeCompilerClass {
 	GObjectClass parent;
 };
 
-ValaCCodeCompiler* vala_ccode_compiler_new ();
-void vala_ccode_compiler_compile (ValaCCodeCompiler* self, ValaCodeContext* context);
-GType vala_ccode_compiler_get_type ();
+ValaCCodeCompiler* vala_ccode_compiler_new (void);
+void vala_ccode_compiler_compile (ValaCCodeCompiler* self, ValaCodeContext* context, const char* cc_command, char** cc_options);
+GType vala_ccode_compiler_get_type (void);
 
 G_END_DECLS
 
