@@ -28,11 +28,8 @@
 #include <glib-object.h>
 #include <vala/valacodevisitor.h>
 #include <vala/valacodecontext.h>
-#include <vala/valanamespace.h>
 #include <vala/valaenum.h>
 #include <vala/valaenumvalue.h>
-#include <vala/valaflags.h>
-#include <vala/valaflagsvalue.h>
 #include <vala/valacallback.h>
 #include <vala/valamember.h>
 #include <vala/valaconstant.h>
@@ -43,7 +40,6 @@
 #include <vala/valaconstructor.h>
 #include <vala/valadestructor.h>
 #include <vala/valablock.h>
-#include <ccode/valaccodeblock.h>
 #include <vala/valaemptystatement.h>
 #include <vala/valastruct.h>
 #include <vala/valadeclarationstatement.h>
@@ -55,6 +51,7 @@
 #include <ccode/valaccodeexpression.h>
 #include <vala/valaexpression.h>
 #include <ccode/valaccodefragment.h>
+#include <gee/collection.h>
 #include <vala/valacodenode.h>
 #include <vala/valaexpressionstatement.h>
 #include <vala/valastatement.h>
@@ -109,6 +106,7 @@
 #include <vala/valamethod.h>
 #include <ccode/valaccodestatement.h>
 #include <vala/valacreationmethod.h>
+#include <ccode/valaccodeblock.h>
 #include <ccode/valaccodeincludedirective.h>
 #include <vala/valasourcefile.h>
 
@@ -141,7 +139,7 @@ ValaCodeGenerator* vala_code_generator_new (gboolean manage_memory);
 void vala_code_generator_emit (ValaCodeGenerator* self, ValaCodeContext* context);
 gboolean vala_code_generator_get_memory_management (ValaCodeGenerator* self);
 void vala_code_generator_set_memory_management (ValaCodeGenerator* self, gboolean value);
-GType vala_code_generator_get_type ();
+GType vala_code_generator_get_type (void);
 
 G_END_DECLS
 
