@@ -81,7 +81,7 @@ ValaExpression* vala_binary_expression_get_left (ValaBinaryExpression* self);
 void vala_binary_expression_set_left (ValaBinaryExpression* self, ValaExpression* value);
 ValaExpression* vala_binary_expression_get_right (ValaBinaryExpression* self);
 void vala_binary_expression_set_right (ValaBinaryExpression* self, ValaExpression* value);
-GType vala_binary_expression_get_type ();
+GType vala_binary_expression_get_type (void);
 
 G_END_DECLS
 
