@@ -1,6 +1,6 @@
 /* valabreakstatement.vala
  *
- * Copyright (C) 2006  Jürg Billeter
+ * Copyright (C) 2006-2007  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -19,8 +19,6 @@
  * Author:
  * 	Jürg Billeter <j@bitron.ch>
  */
-#define VALA_FREE_CHECKED(o,f) ((o) == NULL ? NULL : ((o) = (f (o), NULL)))
-#define VALA_FREE_UNCHECKED(o,f) ((o) = (f (o), NULL))
 
 #include "valabreakstatement.h"
 #include <vala/valasourcereference.h>
@@ -32,6 +30,7 @@ enum  {
 };
 static void vala_break_statement_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static gpointer vala_break_statement_parent_class = NULL;
+static ValaStatementIface* vala_break_statement_vala_statement_parent_iface = NULL;
 
 
 /**
@@ -42,14 +41,10 @@ static gpointer vala_break_statement_parent_class = NULL;
  */
 ValaBreakStatement* vala_break_statement_new (ValaSourceReference* source)
 {
-	GParameter * __params;
-	GParameter * __params_it;
 	ValaBreakStatement * self;
 	g_return_val_if_fail (source == NULL || VALA_IS_SOURCE_REFERENCE (source), NULL);
-	__params = g_new0 (GParameter, 1);
-	__params_it = __params;
-	(__params_it->name = "source-reference", g_value_init (&__params_it->value, VALA_TYPE_SOURCE_REFERENCE), g_value_set_object (&__params_it->value, source), __params_it++);
-	self = g_object_newv (VALA_TYPE_BREAK_STATEMENT, __params_it - __params, __params);
+	self = g_object_newv (VALA_TYPE_BREAK_STATEMENT, 0, NULL);
+	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source);
 	return self;
 }
 
@@ -57,7 +52,7 @@ ValaBreakStatement* vala_break_statement_new (ValaSourceReference* source)
 static void vala_break_statement_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor)
 {
 	ValaBreakStatement * self;
-	self = VALA_BREAK_STATEMENT (base);
+	self = ((ValaBreakStatement*) base);
 	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	vala_code_visitor_visit_break_statement (visitor, self);
 }
@@ -70,17 +65,25 @@ static void vala_break_statement_class_init (ValaBreakStatementClass * klass)
 }
 
 
+static void vala_break_statement_vala_statement_interface_init (ValaStatementIface * iface)
+{
+	vala_break_statement_vala_statement_parent_iface = g_type_interface_peek_parent (iface);
+}
+
+
 static void vala_break_statement_init (ValaBreakStatement * self)
 {
 }
 
 
-GType vala_break_statement_get_type ()
+GType vala_break_statement_get_type (void)
 {
 	static GType vala_break_statement_type_id = 0;
 	if (G_UNLIKELY (vala_break_statement_type_id == 0)) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaBreakStatementClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_break_statement_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaBreakStatement), 0, (GInstanceInitFunc) vala_break_statement_init };
-		vala_break_statement_type_id = g_type_register_static (VALA_TYPE_STATEMENT, "ValaBreakStatement", &g_define_type_info, 0);
+		static const GInterfaceInfo vala_statement_info = { (GInterfaceInitFunc) vala_break_statement_vala_statement_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
+		vala_break_statement_type_id = g_type_register_static (VALA_TYPE_CODE_NODE, "ValaBreakStatement", &g_define_type_info, 0);
+		g_type_add_interface_static (vala_break_statement_type_id, VALA_TYPE_STATEMENT, &vala_statement_info);
 	}
 	return vala_break_statement_type_id;
 }
