@@ -19,13 +19,10 @@
  * Author:
  * 	Jürg Billeter <j@bitron.ch>
  */
-#define VALA_FREE_CHECKED(o,f) ((o) == NULL ? NULL : ((o) = (f (o), NULL)))
-#define VALA_FREE_UNCHECKED(o,f) ((o) = (f (o), NULL))
 
 #include "valacodenode.h"
 #include <ccode/valaccodelinedirective.h>
 #include <vala/valacodenode.h>
-#include <vala/valasymbol.h>
 #include <vala/valasourcereference.h>
 #include <vala/valacodevisitor.h>
 #include <vala/valaattribute.h>
@@ -33,21 +30,22 @@
 
 struct _ValaCodeNodePrivate {
 	ValaCodeNode* _parent_node;
-	ValaSymbol* _symbol;
 	ValaSourceReference* _source_reference;
 	gboolean _error;
+	gboolean _tree_can_fail;
 	ValaCCodeNode* _ccodenode;
 };
 #define VALA_CODE_NODE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_CODE_NODE, ValaCodeNodePrivate))
 enum  {
 	VALA_CODE_NODE_DUMMY_PROPERTY,
 	VALA_CODE_NODE_PARENT_NODE,
-	VALA_CODE_NODE_SYMBOL,
 	VALA_CODE_NODE_SOURCE_REFERENCE,
 	VALA_CODE_NODE_CCODENODE,
 	VALA_CODE_NODE_ERROR,
+	VALA_CODE_NODE_TREE_CAN_FAIL
 };
 static void vala_code_node_real_accept (ValaCodeNode* self, ValaCodeVisitor* visitor);
+static void vala_code_node_real_accept_children (ValaCodeNode* self, ValaCodeVisitor* visitor);
 static void vala_code_node_real_replace (ValaCodeNode* self, ValaCodeNode* old_node, ValaCodeNode* new_node);
 static char* vala_code_node_real_to_string (ValaCodeNode* self);
 static gpointer vala_code_node_parent_class = NULL;
@@ -55,8 +53,7 @@ static void vala_code_node_dispose (GObject * obj);
 
 
 /**
- * Visits this code node and all children with the specified
- * CodeVisitor.
+ * Visits this code node with the specified CodeVisitor.
  *
  * @param visitor the visitor to be called while traversing
  */
@@ -73,6 +70,24 @@ void vala_code_node_accept (ValaCodeNode* self, ValaCodeVisitor* visitor)
 }
 
 
+/**
+ * Visits all children of this code node with the specified CodeVisitor.
+ *
+ * @param visitor the visitor to be called while traversing
+ */
+static void vala_code_node_real_accept_children (ValaCodeNode* self, ValaCodeVisitor* visitor)
+{
+	g_return_if_fail (VALA_IS_CODE_NODE (self));
+	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
+}
+
+
+void vala_code_node_accept_children (ValaCodeNode* self, ValaCodeVisitor* visitor)
+{
+	VALA_CODE_NODE_GET_CLASS (self)->accept_children (self, visitor);
+}
+
+
 static void vala_code_node_real_replace (ValaCodeNode* self, ValaCodeNode* old_node, ValaCodeNode* new_node)
 {
 	g_return_if_fail (VALA_IS_CODE_NODE (self));
@@ -98,17 +113,20 @@ ValaAttribute* vala_code_node_get_attribute (ValaCodeNode* self, const char* nam
 	g_return_val_if_fail (VALA_IS_CODE_NODE (self), NULL);
 	g_return_val_if_fail (name != NULL, NULL);
 	{
-		GList* __temp2 = NULL;
-		__temp2 = self->attributes;
+		GList* a_collection;
 		GList* a_it;
-		for (a_it = __temp2; a_it != NULL; a_it = a_it->next) {
-			ValaAttribute* a = a_it->data;
+		a_collection = self->attributes;
+		for (a_it = a_collection; a_it != NULL; a_it = a_it->next) {
+			ValaAttribute* __temp1;
+			ValaAttribute* a;
+			__temp1 = NULL;
+			a = (__temp1 = a_it->data, (__temp1 == NULL ? NULL : g_object_ref (__temp1)));
 			{
 				/* FIXME: use hash table*/
 				if (g_utf8_collate (vala_attribute_get_name (a), name) == 0) {
-					ValaAttribute* __temp0 = NULL;
-					return (__temp0 = a, (__temp0 == NULL ? NULL : g_object_ref (__temp0)));
+					return a;
 				}
+				(a == NULL ? NULL : (a = (g_object_unref (a), NULL)));
 			}
 		}
 	}
@@ -147,25 +165,7 @@ ValaCodeNode* vala_code_node_get_parent_node (ValaCodeNode* self)
 void vala_code_node_set_parent_node (ValaCodeNode* self, ValaCodeNode* value)
 {
 	g_return_if_fail (VALA_IS_CODE_NODE (self));
-	ValaCodeNode* __temp8 = NULL;
-	ValaCodeNode* __temp7 = NULL;
-	self->priv->_parent_node = (__temp8 = (__temp7 = value, (__temp7 == NULL ? NULL : g_object_ref (__temp7))), (self->priv->_parent_node == NULL ? NULL : (self->priv->_parent_node = (g_object_unref (self->priv->_parent_node), NULL))), __temp8);
-}
-
-
-ValaSymbol* vala_code_node_get_symbol (ValaCodeNode* self)
-{
-	g_return_val_if_fail (VALA_IS_CODE_NODE (self), NULL);
-	return self->priv->_symbol;
-}
-
-
-void vala_code_node_set_symbol (ValaCodeNode* self, ValaSymbol* value)
-{
-	g_return_if_fail (VALA_IS_CODE_NODE (self));
-	ValaSymbol* __temp11 = NULL;
-	ValaSymbol* __temp10 = NULL;
-	self->priv->_symbol = (__temp11 = (__temp10 = value, (__temp10 == NULL ? NULL : g_object_ref (__temp10))), (self->priv->_symbol == NULL ? NULL : (self->priv->_symbol = (g_object_unref (self->priv->_symbol), NULL))), __temp11);
+	self->priv->_parent_node = value;
 }
 
 
@@ -178,10 +178,12 @@ ValaSourceReference* vala_code_node_get_source_reference (ValaCodeNode* self)
 
 void vala_code_node_set_source_reference (ValaCodeNode* self, ValaSourceReference* value)
 {
+	ValaSourceReference* __temp8;
+	ValaSourceReference* __temp7;
 	g_return_if_fail (VALA_IS_CODE_NODE (self));
-	ValaSourceReference* __temp14 = NULL;
-	ValaSourceReference* __temp13 = NULL;
-	self->priv->_source_reference = (__temp14 = (__temp13 = value, (__temp13 == NULL ? NULL : g_object_ref (__temp13))), (self->priv->_source_reference == NULL ? NULL : (self->priv->_source_reference = (g_object_unref (self->priv->_source_reference), NULL))), __temp14);
+	__temp8 = NULL;
+	__temp7 = NULL;
+	self->priv->_source_reference = (__temp8 = (__temp7 = value, (__temp7 == NULL ? NULL : g_object_ref (__temp7))), (self->priv->_source_reference == NULL ? NULL : (self->priv->_source_reference = (g_object_unref (self->priv->_source_reference), NULL))), __temp8);
 }
 
 
@@ -194,15 +196,18 @@ ValaCCodeNode* vala_code_node_get_ccodenode (ValaCodeNode* self)
 
 void vala_code_node_set_ccodenode (ValaCodeNode* self, ValaCCodeNode* value)
 {
+	ValaCCodeNode* __temp12;
+	ValaCCodeNode* __temp11;
 	g_return_if_fail (VALA_IS_CODE_NODE (self));
 	if (vala_code_node_get_source_reference (self) != NULL) {
-		ValaCCodeLineDirective* __temp16 = NULL;
-		(vala_ccode_node_set_line (value, (__temp16 = vala_ccode_line_directive_new (vala_source_file_get_filename (vala_source_reference_get_file (vala_code_node_get_source_reference (self))), vala_source_reference_get_first_line (vala_code_node_get_source_reference (self))))), vala_ccode_node_get_line (value));
-		(__temp16 == NULL ? NULL : (__temp16 = (g_object_unref (__temp16), NULL)));
+		ValaCCodeLineDirective* __temp10;
+		__temp10 = NULL;
+		vala_ccode_node_set_line (value, (__temp10 = vala_ccode_line_directive_new (vala_source_file_get_filename (vala_source_reference_get_file (vala_code_node_get_source_reference (self))), vala_source_reference_get_first_line (vala_code_node_get_source_reference (self)))));
+		(__temp10 == NULL ? NULL : (__temp10 = (g_object_unref (__temp10), NULL)));
 	}
-	ValaCCodeNode* __temp18 = NULL;
-	ValaCCodeNode* __temp17 = NULL;
-	self->priv->_ccodenode = (__temp18 = (__temp17 = value, (__temp17 == NULL ? NULL : g_object_ref (__temp17))), (self->priv->_ccodenode == NULL ? NULL : (self->priv->_ccodenode = (g_object_unref (self->priv->_ccodenode), NULL))), __temp18);
+	__temp12 = NULL;
+	__temp11 = NULL;
+	self->priv->_ccodenode = (__temp12 = (__temp11 = value, (__temp11 == NULL ? NULL : g_object_ref (__temp11))), (self->priv->_ccodenode == NULL ? NULL : (self->priv->_ccodenode = (g_object_unref (self->priv->_ccodenode), NULL))), __temp12);
 }
 
 
@@ -220,16 +225,28 @@ void vala_code_node_set_error (ValaCodeNode* self, gboolean value)
 }
 
 
+gboolean vala_code_node_get_tree_can_fail (ValaCodeNode* self)
+{
+	g_return_val_if_fail (VALA_IS_CODE_NODE (self), FALSE);
+	return self->priv->_tree_can_fail;
+}
+
+
+void vala_code_node_set_tree_can_fail (ValaCodeNode* self, gboolean value)
+{
+	g_return_if_fail (VALA_IS_CODE_NODE (self));
+	self->priv->_tree_can_fail = value;
+}
+
+
 static void vala_code_node_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec)
 {
-	ValaCodeNode * self = VALA_CODE_NODE (object);
+	ValaCodeNode * self;
+	self = VALA_CODE_NODE (object);
 	switch (property_id) {
 		case VALA_CODE_NODE_PARENT_NODE:
 		g_value_set_object (value, vala_code_node_get_parent_node (self));
 		break;
-		case VALA_CODE_NODE_SYMBOL:
-		g_value_set_object (value, vala_code_node_get_symbol (self));
-		break;
 		case VALA_CODE_NODE_SOURCE_REFERENCE:
 		g_value_set_object (value, vala_code_node_get_source_reference (self));
 		break;
@@ -239,20 +256,21 @@ static void vala_code_node_get_property (GObject * object, guint property_id, GV
 		case VALA_CODE_NODE_ERROR:
 		g_value_set_boolean (value, vala_code_node_get_error (self));
 		break;
+		case VALA_CODE_NODE_TREE_CAN_FAIL:
+		g_value_set_boolean (value, vala_code_node_get_tree_can_fail (self));
+		break;
 	}
 }
 
 
 static void vala_code_node_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec)
 {
-	ValaCodeNode * self = VALA_CODE_NODE (object);
+	ValaCodeNode * self;
+	self = VALA_CODE_NODE (object);
 	switch (property_id) {
 		case VALA_CODE_NODE_PARENT_NODE:
 		vala_code_node_set_parent_node (self, g_value_get_object (value));
 		break;
-		case VALA_CODE_NODE_SYMBOL:
-		vala_code_node_set_symbol (self, g_value_get_object (value));
-		break;
 		case VALA_CODE_NODE_SOURCE_REFERENCE:
 		vala_code_node_set_source_reference (self, g_value_get_object (value));
 		break;
@@ -262,6 +280,9 @@ static void vala_code_node_set_property (GObject * object, guint property_id, co
 		case VALA_CODE_NODE_ERROR:
 		vala_code_node_set_error (self, g_value_get_boolean (value));
 		break;
+		case VALA_CODE_NODE_TREE_CAN_FAIL:
+		vala_code_node_set_tree_can_fail (self, g_value_get_boolean (value));
+		break;
 	}
 }
 
@@ -274,13 +295,14 @@ static void vala_code_node_class_init (ValaCodeNodeClass * klass)
 	G_OBJECT_CLASS (klass)->set_property = vala_code_node_set_property;
 	G_OBJECT_CLASS (klass)->dispose = vala_code_node_dispose;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_code_node_real_accept;
+	VALA_CODE_NODE_CLASS (klass)->accept_children = vala_code_node_real_accept_children;
 	VALA_CODE_NODE_CLASS (klass)->replace = vala_code_node_real_replace;
 	VALA_CODE_NODE_CLASS (klass)->to_string = vala_code_node_real_to_string;
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CODE_NODE_PARENT_NODE, g_param_spec_object ("parent-node", "foo", "bar", VALA_TYPE_CODE_NODE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CODE_NODE_SYMBOL, g_param_spec_object ("symbol", "foo", "bar", VALA_TYPE_SYMBOL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CODE_NODE_SOURCE_REFERENCE, g_param_spec_object ("source-reference", "foo", "bar", VALA_TYPE_SOURCE_REFERENCE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CODE_NODE_SOURCE_REFERENCE, g_param_spec_object ("source-reference", "foo", "bar", VALA_TYPE_SOURCE_REFERENCE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CODE_NODE_CCODENODE, g_param_spec_object ("ccodenode", "foo", "bar", VALA_TYPE_CCODE_NODE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CODE_NODE_ERROR, g_param_spec_boolean ("error", "foo", "bar", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CODE_NODE_TREE_CAN_FAIL, g_param_spec_boolean ("tree-can-fail", "foo", "bar", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
 
@@ -292,21 +314,20 @@ static void vala_code_node_init (ValaCodeNode * self)
 
 static void vala_code_node_dispose (GObject * obj)
 {
-	ValaCodeNode * self = VALA_CODE_NODE (obj);
-	(self->priv->_parent_node == NULL ? NULL : (self->priv->_parent_node = (g_object_unref (self->priv->_parent_node), NULL)));
-	(self->priv->_symbol == NULL ? NULL : (self->priv->_symbol = (g_object_unref (self->priv->_symbol), NULL)));
+	ValaCodeNode * self;
+	ValaCodeNodeClass * klass;
+	GObjectClass * parent_class;
+	self = VALA_CODE_NODE (obj);
 	(self->priv->_source_reference == NULL ? NULL : (self->priv->_source_reference = (g_object_unref (self->priv->_source_reference), NULL)));
 	(self->attributes == NULL ? NULL : (self->attributes = (g_list_foreach (self->attributes, (GFunc) g_object_unref, NULL), g_list_free (self->attributes), NULL)));
 	(self->priv->_ccodenode == NULL ? NULL : (self->priv->_ccodenode = (g_object_unref (self->priv->_ccodenode), NULL)));
-	ValaCodeNodeClass * klass;
-	GObjectClass * parent_class;
 	klass = VALA_CODE_NODE_CLASS (g_type_class_peek (VALA_TYPE_CODE_NODE));
 	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
 	parent_class->dispose (obj);
 }
 
 
-GType vala_code_node_get_type ()
+GType vala_code_node_get_type (void)
 {
 	static GType vala_code_node_type_id = 0;
 	if (G_UNLIKELY (vala_code_node_type_id == 0)) {
