@@ -49,42 +49,25 @@ struct _ValaCodeVisitor {
 };
 struct _ValaCodeVisitorClass {
 	GObjectClass parent;
-	void (*visit_begin_source_file) (ValaCodeVisitor* self, ValaSourceFile* source_file);
-	void (*visit_end_source_file) (ValaCodeVisitor* self, ValaSourceFile* source_file);
-	void (*visit_begin_namespace) (ValaCodeVisitor* self, ValaNamespace* ns);
-	void (*visit_end_namespace) (ValaCodeVisitor* self, ValaNamespace* ns);
-	void (*visit_begin_class) (ValaCodeVisitor* self, ValaClass* cl);
-	void (*visit_end_class) (ValaCodeVisitor* self, ValaClass* cl);
-	void (*visit_begin_struct) (ValaCodeVisitor* self, ValaStruct* st);
-	void (*visit_end_struct) (ValaCodeVisitor* self, ValaStruct* st);
-	void (*visit_begin_interface) (ValaCodeVisitor* self, ValaInterface* iface);
-	void (*visit_end_interface) (ValaCodeVisitor* self, ValaInterface* iface);
-	void (*visit_begin_enum) (ValaCodeVisitor* self, ValaEnum* en);
-	void (*visit_end_enum) (ValaCodeVisitor* self, ValaEnum* en);
+	void (*visit_source_file) (ValaCodeVisitor* self, ValaSourceFile* source_file);
+	void (*visit_namespace) (ValaCodeVisitor* self, ValaNamespace* ns);
+	void (*visit_class) (ValaCodeVisitor* self, ValaClass* cl);
+	void (*visit_struct) (ValaCodeVisitor* self, ValaStruct* st);
+	void (*visit_interface) (ValaCodeVisitor* self, ValaInterface* iface);
+	void (*visit_enum) (ValaCodeVisitor* self, ValaEnum* en);
 	void (*visit_enum_value) (ValaCodeVisitor* self, ValaEnumValue* ev);
-	void (*visit_begin_flags) (ValaCodeVisitor* self, ValaFlags* fl);
-	void (*visit_end_flags) (ValaCodeVisitor* self, ValaFlags* fl);
-	void (*visit_flags_value) (ValaCodeVisitor* self, ValaFlagsValue* fv);
-	void (*visit_begin_callback) (ValaCodeVisitor* self, ValaCallback* cb);
-	void (*visit_end_callback) (ValaCodeVisitor* self, ValaCallback* cb);
+	void (*visit_callback) (ValaCodeVisitor* self, ValaCallback* cb);
 	void (*visit_member) (ValaCodeVisitor* self, ValaMember* m);
 	void (*visit_constant) (ValaCodeVisitor* self, ValaConstant* c);
 	void (*visit_field) (ValaCodeVisitor* self, ValaField* f);
-	void (*visit_begin_method) (ValaCodeVisitor* self, ValaMethod* m);
-	void (*visit_end_method) (ValaCodeVisitor* self, ValaMethod* m);
-	void (*visit_begin_creation_method) (ValaCodeVisitor* self, ValaCreationMethod* m);
-	void (*visit_end_creation_method) (ValaCodeVisitor* self, ValaCreationMethod* m);
+	void (*visit_method) (ValaCodeVisitor* self, ValaMethod* m);
+	void (*visit_creation_method) (ValaCodeVisitor* self, ValaCreationMethod* m);
 	void (*visit_formal_parameter) (ValaCodeVisitor* self, ValaFormalParameter* p);
-	void (*visit_begin_property) (ValaCodeVisitor* self, ValaProperty* prop);
-	void (*visit_end_property) (ValaCodeVisitor* self, ValaProperty* prop);
-	void (*visit_begin_property_accessor) (ValaCodeVisitor* self, ValaPropertyAccessor* acc);
-	void (*visit_end_property_accessor) (ValaCodeVisitor* self, ValaPropertyAccessor* acc);
-	void (*visit_begin_signal) (ValaCodeVisitor* self, ValaSignal* sig);
-	void (*visit_end_signal) (ValaCodeVisitor* self, ValaSignal* sig);
-	void (*visit_begin_constructor) (ValaCodeVisitor* self, ValaConstructor* c);
-	void (*visit_end_constructor) (ValaCodeVisitor* self, ValaConstructor* c);
-	void (*visit_begin_destructor) (ValaCodeVisitor* self, ValaDestructor* d);
-	void (*visit_end_destructor) (ValaCodeVisitor* self, ValaDestructor* d);
+	void (*visit_property) (ValaCodeVisitor* self, ValaProperty* prop);
+	void (*visit_property_accessor) (ValaCodeVisitor* self, ValaPropertyAccessor* acc);
+	void (*visit_signal) (ValaCodeVisitor* self, ValaSignal* sig);
+	void (*visit_constructor) (ValaCodeVisitor* self, ValaConstructor* c);
+	void (*visit_destructor) (ValaCodeVisitor* self, ValaDestructor* d);
 	void (*visit_named_argument) (ValaCodeVisitor* self, ValaNamedArgument* n);
 	void (*visit_type_parameter) (ValaCodeVisitor* self, ValaTypeParameter* p);
 	void (*visit_namespace_reference) (ValaCodeVisitor* self, ValaNamespaceReference* ns);
@@ -111,12 +94,9 @@ struct _ValaCodeVisitorClass {
 	void (*visit_continue_statement) (ValaCodeVisitor* self, ValaContinueStatement* stmt);
 	void (*visit_begin_return_statement) (ValaCodeVisitor* self, ValaReturnStatement* stmt);
 	void (*visit_end_return_statement) (ValaCodeVisitor* self, ValaReturnStatement* stmt);
-	void (*visit_begin_throw_statement) (ValaCodeVisitor* self, ValaThrowStatement* stmt);
-	void (*visit_end_throw_statement) (ValaCodeVisitor* self, ValaThrowStatement* stmt);
-	void (*visit_begin_try_statement) (ValaCodeVisitor* self, ValaTryStatement* stmt);
-	void (*visit_end_try_statement) (ValaCodeVisitor* self, ValaTryStatement* stmt);
-	void (*visit_begin_catch_clause) (ValaCodeVisitor* self, ValaCatchClause* clause);
-	void (*visit_end_catch_clause) (ValaCodeVisitor* self, ValaCatchClause* clause);
+	void (*visit_throw_statement) (ValaCodeVisitor* self, ValaThrowStatement* stmt);
+	void (*visit_try_statement) (ValaCodeVisitor* self, ValaTryStatement* stmt);
+	void (*visit_catch_clause) (ValaCodeVisitor* self, ValaCatchClause* clause);
 	void (*visit_lock_statement) (ValaCodeVisitor* self, ValaLockStatement* stmt);
 	void (*visit_begin_array_creation_expression) (ValaCodeVisitor* self, ValaArrayCreationExpression* expr);
 	void (*visit_end_array_creation_expression) (ValaCodeVisitor* self, ValaArrayCreationExpression* expr);
@@ -136,6 +116,7 @@ struct _ValaCodeVisitorClass {
 	void (*visit_postfix_expression) (ValaCodeVisitor* self, ValaPostfixExpression* expr);
 	void (*visit_begin_object_creation_expression) (ValaCodeVisitor* self, ValaObjectCreationExpression* expr);
 	void (*visit_end_object_creation_expression) (ValaCodeVisitor* self, ValaObjectCreationExpression* expr);
+	void (*visit_sizeof_expression) (ValaCodeVisitor* self, ValaSizeofExpression* expr);
 	void (*visit_typeof_expression) (ValaCodeVisitor* self, ValaTypeofExpression* expr);
 	void (*visit_unary_expression) (ValaCodeVisitor* self, ValaUnaryExpression* expr);
 	void (*visit_cast_expression) (ValaCodeVisitor* self, ValaCastExpression* expr);
@@ -152,42 +133,25 @@ struct _ValaCodeVisitorClass {
 	void (*visit_end_full_expression) (ValaCodeVisitor* self, ValaExpression* expr);
 };
 
-void vala_code_visitor_visit_begin_source_file (ValaCodeVisitor* self, ValaSourceFile* source_file);
-void vala_code_visitor_visit_end_source_file (ValaCodeVisitor* self, ValaSourceFile* source_file);
-void vala_code_visitor_visit_begin_namespace (ValaCodeVisitor* self, ValaNamespace* ns);
-void vala_code_visitor_visit_end_namespace (ValaCodeVisitor* self, ValaNamespace* ns);
-void vala_code_visitor_visit_begin_class (ValaCodeVisitor* self, ValaClass* cl);
-void vala_code_visitor_visit_end_class (ValaCodeVisitor* self, ValaClass* cl);
-void vala_code_visitor_visit_begin_struct (ValaCodeVisitor* self, ValaStruct* st);
-void vala_code_visitor_visit_end_struct (ValaCodeVisitor* self, ValaStruct* st);
-void vala_code_visitor_visit_begin_interface (ValaCodeVisitor* self, ValaInterface* iface);
-void vala_code_visitor_visit_end_interface (ValaCodeVisitor* self, ValaInterface* iface);
-void vala_code_visitor_visit_begin_enum (ValaCodeVisitor* self, ValaEnum* en);
-void vala_code_visitor_visit_end_enum (ValaCodeVisitor* self, ValaEnum* en);
+void vala_code_visitor_visit_source_file (ValaCodeVisitor* self, ValaSourceFile* source_file);
+void vala_code_visitor_visit_namespace (ValaCodeVisitor* self, ValaNamespace* ns);
+void vala_code_visitor_visit_class (ValaCodeVisitor* self, ValaClass* cl);
+void vala_code_visitor_visit_struct (ValaCodeVisitor* self, ValaStruct* st);
+void vala_code_visitor_visit_interface (ValaCodeVisitor* self, ValaInterface* iface);
+void vala_code_visitor_visit_enum (ValaCodeVisitor* self, ValaEnum* en);
 void vala_code_visitor_visit_enum_value (ValaCodeVisitor* self, ValaEnumValue* ev);
-void vala_code_visitor_visit_begin_flags (ValaCodeVisitor* self, ValaFlags* fl);
-void vala_code_visitor_visit_end_flags (ValaCodeVisitor* self, ValaFlags* fl);
-void vala_code_visitor_visit_flags_value (ValaCodeVisitor* self, ValaFlagsValue* fv);
-void vala_code_visitor_visit_begin_callback (ValaCodeVisitor* self, ValaCallback* cb);
-void vala_code_visitor_visit_end_callback (ValaCodeVisitor* self, ValaCallback* cb);
+void vala_code_visitor_visit_callback (ValaCodeVisitor* self, ValaCallback* cb);
 void vala_code_visitor_visit_member (ValaCodeVisitor* self, ValaMember* m);
 void vala_code_visitor_visit_constant (ValaCodeVisitor* self, ValaConstant* c);
 void vala_code_visitor_visit_field (ValaCodeVisitor* self, ValaField* f);
-void vala_code_visitor_visit_begin_method (ValaCodeVisitor* self, ValaMethod* m);
-void vala_code_visitor_visit_end_method (ValaCodeVisitor* self, ValaMethod* m);
-void vala_code_visitor_visit_begin_creation_method (ValaCodeVisitor* self, ValaCreationMethod* m);
-void vala_code_visitor_visit_end_creation_method (ValaCodeVisitor* self, ValaCreationMethod* m);
+void vala_code_visitor_visit_method (ValaCodeVisitor* self, ValaMethod* m);
+void vala_code_visitor_visit_creation_method (ValaCodeVisitor* self, ValaCreationMethod* m);
 void vala_code_visitor_visit_formal_parameter (ValaCodeVisitor* self, ValaFormalParameter* p);
-void vala_code_visitor_visit_begin_property (ValaCodeVisitor* self, ValaProperty* prop);
-void vala_code_visitor_visit_end_property (ValaCodeVisitor* self, ValaProperty* prop);
-void vala_code_visitor_visit_begin_property_accessor (ValaCodeVisitor* self, ValaPropertyAccessor* acc);
-void vala_code_visitor_visit_end_property_accessor (ValaCodeVisitor* self, ValaPropertyAccessor* acc);
-void vala_code_visitor_visit_begin_signal (ValaCodeVisitor* self, ValaSignal* sig);
-void vala_code_visitor_visit_end_signal (ValaCodeVisitor* self, ValaSignal* sig);
-void vala_code_visitor_visit_begin_constructor (ValaCodeVisitor* self, ValaConstructor* c);
-void vala_code_visitor_visit_end_constructor (ValaCodeVisitor* self, ValaConstructor* c);
-void vala_code_visitor_visit_begin_destructor (ValaCodeVisitor* self, ValaDestructor* d);
-void vala_code_visitor_visit_end_destructor (ValaCodeVisitor* self, ValaDestructor* d);
+void vala_code_visitor_visit_property (ValaCodeVisitor* self, ValaProperty* prop);
+void vala_code_visitor_visit_property_accessor (ValaCodeVisitor* self, ValaPropertyAccessor* acc);
+void vala_code_visitor_visit_signal (ValaCodeVisitor* self, ValaSignal* sig);
+void vala_code_visitor_visit_constructor (ValaCodeVisitor* self, ValaConstructor* c);
+void vala_code_visitor_visit_destructor (ValaCodeVisitor* self, ValaDestructor* d);
 void vala_code_visitor_visit_named_argument (ValaCodeVisitor* self, ValaNamedArgument* n);
 void vala_code_visitor_visit_type_parameter (ValaCodeVisitor* self, ValaTypeParameter* p);
 void vala_code_visitor_visit_namespace_reference (ValaCodeVisitor* self, ValaNamespaceReference* ns);
@@ -214,12 +178,9 @@ void vala_code_visitor_visit_break_statement (ValaCodeVisitor* self, ValaBreakSt
 void vala_code_visitor_visit_continue_statement (ValaCodeVisitor* self, ValaContinueStatement* stmt);
 void vala_code_visitor_visit_begin_return_statement (ValaCodeVisitor* self, ValaReturnStatement* stmt);
 void vala_code_visitor_visit_end_return_statement (ValaCodeVisitor* self, ValaReturnStatement* stmt);
-void vala_code_visitor_visit_begin_throw_statement (ValaCodeVisitor* self, ValaThrowStatement* stmt);
-void vala_code_visitor_visit_end_throw_statement (ValaCodeVisitor* self, ValaThrowStatement* stmt);
-void vala_code_visitor_visit_begin_try_statement (ValaCodeVisitor* self, ValaTryStatement* stmt);
-void vala_code_visitor_visit_end_try_statement (ValaCodeVisitor* self, ValaTryStatement* stmt);
-void vala_code_visitor_visit_begin_catch_clause (ValaCodeVisitor* self, ValaCatchClause* clause);
-void vala_code_visitor_visit_end_catch_clause (ValaCodeVisitor* self, ValaCatchClause* clause);
+void vala_code_visitor_visit_throw_statement (ValaCodeVisitor* self, ValaThrowStatement* stmt);
+void vala_code_visitor_visit_try_statement (ValaCodeVisitor* self, ValaTryStatement* stmt);
+void vala_code_visitor_visit_catch_clause (ValaCodeVisitor* self, ValaCatchClause* clause);
 void vala_code_visitor_visit_lock_statement (ValaCodeVisitor* self, ValaLockStatement* stmt);
 void vala_code_visitor_visit_begin_array_creation_expression (ValaCodeVisitor* self, ValaArrayCreationExpression* expr);
 void vala_code_visitor_visit_end_array_creation_expression (ValaCodeVisitor* self, ValaArrayCreationExpression* expr);
@@ -239,6 +200,7 @@ void vala_code_visitor_visit_base_access (ValaCodeVisitor* self, ValaBaseAccess*
 void vala_code_visitor_visit_postfix_expression (ValaCodeVisitor* self, ValaPostfixExpression* expr);
 void vala_code_visitor_visit_begin_object_creation_expression (ValaCodeVisitor* self, ValaObjectCreationExpression* expr);
 void vala_code_visitor_visit_end_object_creation_expression (ValaCodeVisitor* self, ValaObjectCreationExpression* expr);
+void vala_code_visitor_visit_sizeof_expression (ValaCodeVisitor* self, ValaSizeofExpression* expr);
 void vala_code_visitor_visit_typeof_expression (ValaCodeVisitor* self, ValaTypeofExpression* expr);
 void vala_code_visitor_visit_unary_expression (ValaCodeVisitor* self, ValaUnaryExpression* expr);
 void vala_code_visitor_visit_cast_expression (ValaCodeVisitor* self, ValaCastExpression* expr);
@@ -253,7 +215,7 @@ void vala_code_visitor_visit_end_lambda_expression (ValaCodeVisitor* self, ValaL
 void vala_code_visitor_visit_begin_assignment (ValaCodeVisitor* self, ValaAssignment* a);
 void vala_code_visitor_visit_end_assignment (ValaCodeVisitor* self, ValaAssignment* a);
 void vala_code_visitor_visit_end_full_expression (ValaCodeVisitor* self, ValaExpression* expr);
-GType vala_code_visitor_get_type ();
+GType vala_code_visitor_get_type (void);
 
 G_END_DECLS
 
