@@ -20,8 +20,6 @@
  * 	Jürg Billeter <j@bitron.ch>
  *	Raffaele Sandrini <rasa@gmx.ch>
  */
-#define VALA_FREE_CHECKED(o,f) ((o) == NULL ? NULL : ((o) = (f (o), NULL)))
-#define VALA_FREE_UNCHECKED(o,f) ((o) = (f (o), NULL))
 
 #include "valaformalparameter.h"
 #include <vala/valatypereference.h>
@@ -32,7 +30,6 @@
 #include <vala/valacallback.h>
 
 struct _ValaFormalParameterPrivate {
-	char* _name;
 	ValaTypeReference* _type_reference;
 	gboolean _ellipsis;
 	ValaExpression* _default_expression;
@@ -42,15 +39,15 @@ struct _ValaFormalParameterPrivate {
 #define VALA_FORMAL_PARAMETER_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_FORMAL_PARAMETER, ValaFormalParameterPrivate))
 enum  {
 	VALA_FORMAL_PARAMETER_DUMMY_PROPERTY,
-	VALA_FORMAL_PARAMETER_NAME,
 	VALA_FORMAL_PARAMETER_TYPE_REFERENCE,
 	VALA_FORMAL_PARAMETER_ELLIPSIS,
 	VALA_FORMAL_PARAMETER_DEFAULT_EXPRESSION,
 	VALA_FORMAL_PARAMETER_NO_ARRAY_LENGTH,
-	VALA_FORMAL_PARAMETER_CONSTRUCT_PARAMETER,
+	VALA_FORMAL_PARAMETER_CONSTRUCT_PARAMETER
 };
 static void vala_formal_parameter_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
-static GList* vala_formal_parameter_real_get_parameters (ValaInvokable* base);
+static void vala_formal_parameter_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor);
+static GeeCollection* vala_formal_parameter_real_get_parameters (ValaInvokable* base);
 static ValaTypeReference* vala_formal_parameter_real_get_return_type (ValaInvokable* base);
 static gboolean vala_formal_parameter_real_is_invokable (ValaInvokable* base);
 static gpointer vala_formal_parameter_parent_class = NULL;
@@ -68,15 +65,14 @@ static void vala_formal_parameter_dispose (GObject * obj);
  */
 ValaFormalParameter* vala_formal_parameter_new (const char* _name, ValaTypeReference* type, ValaSourceReference* source)
 {
+	ValaFormalParameter * self;
 	g_return_val_if_fail (_name != NULL, NULL);
 	g_return_val_if_fail (type == NULL || VALA_IS_TYPE_REFERENCE (type), NULL);
 	g_return_val_if_fail (source == NULL || VALA_IS_SOURCE_REFERENCE (source), NULL);
-	GParameter * __params = g_new0 (GParameter, 3);
-	GParameter * __params_it = __params;
-	(__params_it->name = "name", g_value_init (&__params_it->value, G_TYPE_STRING), g_value_set_string (&__params_it->value, _name), __params_it++);
-	(__params_it->name = "type-reference", g_value_init (&__params_it->value, VALA_TYPE_TYPE_REFERENCE), g_value_set_object (&__params_it->value, type), __params_it++);
-	(__params_it->name = "source-reference", g_value_init (&__params_it->value, VALA_TYPE_SOURCE_REFERENCE), g_value_set_object (&__params_it->value, source), __params_it++);
-	ValaFormalParameter * self = g_object_newv (VALA_TYPE_FORMAL_PARAMETER, __params_it - __params, __params);
+	self = g_object_newv (VALA_TYPE_FORMAL_PARAMETER, 0, NULL);
+	vala_symbol_set_name (VALA_SYMBOL (self), _name);
+	vala_formal_parameter_set_type_reference (self, type);
+	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source);
 	return self;
 }
 
@@ -87,19 +83,28 @@ ValaFormalParameter* vala_formal_parameter_new (const char* _name, ValaTypeRefer
  */
 ValaFormalParameter* vala_formal_parameter_new_with_ellipsis (ValaSourceReference* source)
 {
+	ValaFormalParameter * self;
 	g_return_val_if_fail (source == NULL || VALA_IS_SOURCE_REFERENCE (source), NULL);
-	GParameter * __params = g_new0 (GParameter, 2);
-	GParameter * __params_it = __params;
-	(__params_it->name = "ellipsis", g_value_init (&__params_it->value, G_TYPE_BOOLEAN), g_value_set_boolean (&__params_it->value, TRUE), __params_it++);
-	(__params_it->name = "source-reference", g_value_init (&__params_it->value, VALA_TYPE_SOURCE_REFERENCE), g_value_set_object (&__params_it->value, source), __params_it++);
-	ValaFormalParameter * self = g_object_newv (VALA_TYPE_FORMAL_PARAMETER, __params_it - __params, __params);
+	self = g_object_newv (VALA_TYPE_FORMAL_PARAMETER, 0, NULL);
+	vala_formal_parameter_set_ellipsis (self, TRUE);
+	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source);
 	return self;
 }
 
 
 static void vala_formal_parameter_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor)
 {
-	ValaFormalParameter * self = VALA_FORMAL_PARAMETER (base);
+	ValaFormalParameter * self;
+	self = ((ValaFormalParameter*) base);
+	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
+	vala_code_visitor_visit_formal_parameter (visitor, self);
+}
+
+
+static void vala_formal_parameter_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor)
+{
+	ValaFormalParameter * self;
+	self = ((ValaFormalParameter*) base);
 	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	if (!vala_formal_parameter_get_ellipsis (self)) {
 		vala_code_node_accept (VALA_CODE_NODE (vala_formal_parameter_get_type_reference (self)), visitor);
@@ -107,19 +112,22 @@ static void vala_formal_parameter_real_accept (ValaCodeNode* base, ValaCodeVisit
 			vala_code_node_accept (VALA_CODE_NODE (vala_formal_parameter_get_default_expression (self)), visitor);
 		}
 	}
-	vala_code_visitor_visit_formal_parameter (visitor, self);
 }
 
 
-static GList* vala_formal_parameter_real_get_parameters (ValaInvokable* base)
+static GeeCollection* vala_formal_parameter_real_get_parameters (ValaInvokable* base)
 {
-	ValaFormalParameter * self = VALA_FORMAL_PARAMETER (base);
+	ValaFormalParameter * self;
+	ValaCallback* __temp1;
+	ValaCallback* cb;
+	GeeCollection* __temp2;
+	self = ((ValaFormalParameter*) base);
 	if (!vala_invokable_is_invokable (VALA_INVOKABLE (self))) {
-		return NULL;
+		return GEE_COLLECTION (NULL);
 	}
-	ValaCallback* __temp1 = NULL;
-	ValaCallback* cb = (__temp1 = VALA_CALLBACK (vala_type_reference_get_data_type (vala_formal_parameter_get_type_reference (self))), (__temp1 == NULL ? NULL : g_object_ref (__temp1)));
-	GList* __temp2 = NULL;
+	__temp1 = NULL;
+	cb = (__temp1 = VALA_CALLBACK (vala_type_reference_get_data_type (vala_formal_parameter_get_type_reference (self))), (__temp1 == NULL ? NULL : g_object_ref (__temp1)));
+	__temp2 = NULL;
 	return (__temp2 = vala_callback_get_parameters (cb), (cb == NULL ? NULL : (cb = (g_object_unref (cb), NULL))), __temp2);
 	(cb == NULL ? NULL : (cb = (g_object_unref (cb), NULL)));
 }
@@ -127,14 +135,19 @@ static GList* vala_formal_parameter_real_get_parameters (ValaInvokable* base)
 
 static ValaTypeReference* vala_formal_parameter_real_get_return_type (ValaInvokable* base)
 {
-	ValaFormalParameter * self = VALA_FORMAL_PARAMETER (base);
+	ValaFormalParameter * self;
+	ValaCallback* __temp4;
+	ValaCallback* cb;
+	ValaTypeReference* __temp5;
+	ValaTypeReference* __temp6;
+	self = ((ValaFormalParameter*) base);
 	if (!vala_invokable_is_invokable (VALA_INVOKABLE (self))) {
 		return VALA_TYPE_REFERENCE (NULL);
 	}
-	ValaCallback* __temp4 = NULL;
-	ValaCallback* cb = (__temp4 = VALA_CALLBACK (vala_type_reference_get_data_type (vala_formal_parameter_get_type_reference (self))), (__temp4 == NULL ? NULL : g_object_ref (__temp4)));
-	ValaTypeReference* __temp5 = NULL;
-	ValaTypeReference* __temp6 = NULL;
+	__temp4 = NULL;
+	cb = (__temp4 = VALA_CALLBACK (vala_type_reference_get_data_type (vala_formal_parameter_get_type_reference (self))), (__temp4 == NULL ? NULL : g_object_ref (__temp4)));
+	__temp5 = NULL;
+	__temp6 = NULL;
 	return (__temp6 = (__temp5 = vala_callback_get_return_type (cb), (__temp5 == NULL ? NULL : g_object_ref (__temp5))), (cb == NULL ? NULL : (cb = (g_object_unref (cb), NULL))), __temp6);
 	(cb == NULL ? NULL : (cb = (g_object_unref (cb), NULL)));
 }
@@ -142,26 +155,12 @@ static ValaTypeReference* vala_formal_parameter_real_get_return_type (ValaInvoka
 
 static gboolean vala_formal_parameter_real_is_invokable (ValaInvokable* base)
 {
-	ValaFormalParameter * self = VALA_FORMAL_PARAMETER (base);
+	ValaFormalParameter * self;
+	self = ((ValaFormalParameter*) base);
 	return (VALA_IS_CALLBACK (vala_type_reference_get_data_type (vala_formal_parameter_get_type_reference (self))));
 }
 
 
-char* vala_formal_parameter_get_name (ValaFormalParameter* self)
-{
-	g_return_val_if_fail (VALA_IS_FORMAL_PARAMETER (self), NULL);
-	return self->priv->_name;
-}
-
-
-void vala_formal_parameter_set_name (ValaFormalParameter* self, const char* value)
-{
-	g_return_if_fail (VALA_IS_FORMAL_PARAMETER (self));
-	char* __temp9 = NULL;
-	self->priv->_name = (__temp9 = g_strdup (value), (self->priv->_name = (g_free (self->priv->_name), NULL)), __temp9);
-}
-
-
 ValaTypeReference* vala_formal_parameter_get_type_reference (ValaFormalParameter* self)
 {
 	g_return_val_if_fail (VALA_IS_FORMAL_PARAMETER (self), NULL);
@@ -171,10 +170,12 @@ ValaTypeReference* vala_formal_parameter_get_type_reference (ValaFormalParameter
 
 void vala_formal_parameter_set_type_reference (ValaFormalParameter* self, ValaTypeReference* value)
 {
+	ValaTypeReference* __temp10;
+	ValaTypeReference* __temp9;
 	g_return_if_fail (VALA_IS_FORMAL_PARAMETER (self));
-	ValaTypeReference* __temp12 = NULL;
-	ValaTypeReference* __temp11 = NULL;
-	self->priv->_type_reference = (__temp12 = (__temp11 = value, (__temp11 == NULL ? NULL : g_object_ref (__temp11))), (self->priv->_type_reference == NULL ? NULL : (self->priv->_type_reference = (g_object_unref (self->priv->_type_reference), NULL))), __temp12);
+	__temp10 = NULL;
+	__temp9 = NULL;
+	self->priv->_type_reference = (__temp10 = (__temp9 = value, (__temp9 == NULL ? NULL : g_object_ref (__temp9))), (self->priv->_type_reference == NULL ? NULL : (self->priv->_type_reference = (g_object_unref (self->priv->_type_reference), NULL))), __temp10);
 }
 
 
@@ -201,10 +202,12 @@ ValaExpression* vala_formal_parameter_get_default_expression (ValaFormalParamete
 
 void vala_formal_parameter_set_default_expression (ValaFormalParameter* self, ValaExpression* value)
 {
+	ValaExpression* __temp14;
+	ValaExpression* __temp13;
 	g_return_if_fail (VALA_IS_FORMAL_PARAMETER (self));
-	ValaExpression* __temp16 = NULL;
-	ValaExpression* __temp15 = NULL;
-	self->priv->_default_expression = (__temp16 = (__temp15 = value, (__temp15 == NULL ? NULL : g_object_ref (__temp15))), (self->priv->_default_expression == NULL ? NULL : (self->priv->_default_expression = (g_object_unref (self->priv->_default_expression), NULL))), __temp16);
+	__temp14 = NULL;
+	__temp13 = NULL;
+	self->priv->_default_expression = (__temp14 = (__temp13 = value, (__temp13 == NULL ? NULL : g_object_ref (__temp13))), (self->priv->_default_expression == NULL ? NULL : (self->priv->_default_expression = (g_object_unref (self->priv->_default_expression), NULL))), __temp14);
 }
 
 
@@ -238,11 +241,9 @@ void vala_formal_parameter_set_construct_parameter (ValaFormalParameter* self, g
 
 static void vala_formal_parameter_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec)
 {
-	ValaFormalParameter * self = VALA_FORMAL_PARAMETER (object);
+	ValaFormalParameter * self;
+	self = VALA_FORMAL_PARAMETER (object);
 	switch (property_id) {
-		case VALA_FORMAL_PARAMETER_NAME:
-		g_value_set_string (value, vala_formal_parameter_get_name (self));
-		break;
 		case VALA_FORMAL_PARAMETER_TYPE_REFERENCE:
 		g_value_set_object (value, vala_formal_parameter_get_type_reference (self));
 		break;
@@ -264,11 +265,9 @@ static void vala_formal_parameter_get_property (GObject * object, guint property
 
 static void vala_formal_parameter_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec)
 {
-	ValaFormalParameter * self = VALA_FORMAL_PARAMETER (object);
+	ValaFormalParameter * self;
+	self = VALA_FORMAL_PARAMETER (object);
 	switch (property_id) {
-		case VALA_FORMAL_PARAMETER_NAME:
-		vala_formal_parameter_set_name (self, g_value_get_string (value));
-		break;
 		case VALA_FORMAL_PARAMETER_TYPE_REFERENCE:
 		vala_formal_parameter_set_type_reference (self, g_value_get_object (value));
 		break;
@@ -296,7 +295,7 @@ static void vala_formal_parameter_class_init (ValaFormalParameterClass * klass)
 	G_OBJECT_CLASS (klass)->set_property = vala_formal_parameter_set_property;
 	G_OBJECT_CLASS (klass)->dispose = vala_formal_parameter_dispose;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_formal_parameter_real_accept;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_FORMAL_PARAMETER_NAME, g_param_spec_string ("name", "foo", "bar", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
+	VALA_CODE_NODE_CLASS (klass)->accept_children = vala_formal_parameter_real_accept_children;
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_FORMAL_PARAMETER_TYPE_REFERENCE, g_param_spec_object ("type-reference", "foo", "bar", VALA_TYPE_TYPE_REFERENCE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_FORMAL_PARAMETER_ELLIPSIS, g_param_spec_boolean ("ellipsis", "foo", "bar", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_FORMAL_PARAMETER_DEFAULT_EXPRESSION, g_param_spec_object ("default-expression", "foo", "bar", VALA_TYPE_EXPRESSION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
@@ -322,25 +321,25 @@ static void vala_formal_parameter_init (ValaFormalParameter * self)
 
 static void vala_formal_parameter_dispose (GObject * obj)
 {
-	ValaFormalParameter * self = VALA_FORMAL_PARAMETER (obj);
-	(self->priv->_name = (g_free (self->priv->_name), NULL));
-	(self->priv->_type_reference == NULL ? NULL : (self->priv->_type_reference = (g_object_unref (self->priv->_type_reference), NULL)));
-	(self->priv->_default_expression == NULL ? NULL : (self->priv->_default_expression = (g_object_unref (self->priv->_default_expression), NULL)));
+	ValaFormalParameter * self;
 	ValaFormalParameterClass * klass;
 	GObjectClass * parent_class;
+	self = VALA_FORMAL_PARAMETER (obj);
+	(self->priv->_type_reference == NULL ? NULL : (self->priv->_type_reference = (g_object_unref (self->priv->_type_reference), NULL)));
+	(self->priv->_default_expression == NULL ? NULL : (self->priv->_default_expression = (g_object_unref (self->priv->_default_expression), NULL)));
 	klass = VALA_FORMAL_PARAMETER_CLASS (g_type_class_peek (VALA_TYPE_FORMAL_PARAMETER));
 	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
 	parent_class->dispose (obj);
 }
 
 
-GType vala_formal_parameter_get_type ()
+GType vala_formal_parameter_get_type (void)
 {
 	static GType vala_formal_parameter_type_id = 0;
 	if (G_UNLIKELY (vala_formal_parameter_type_id == 0)) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaFormalParameterClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_formal_parameter_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaFormalParameter), 0, (GInstanceInitFunc) vala_formal_parameter_init };
-		vala_formal_parameter_type_id = g_type_register_static (VALA_TYPE_CODE_NODE, "ValaFormalParameter", &g_define_type_info, 0);
 		static const GInterfaceInfo vala_invokable_info = { (GInterfaceInitFunc) vala_formal_parameter_vala_invokable_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
+		vala_formal_parameter_type_id = g_type_register_static (VALA_TYPE_SYMBOL, "ValaFormalParameter", &g_define_type_info, 0);
 		g_type_add_interface_static (vala_formal_parameter_type_id, VALA_TYPE_INVOKABLE, &vala_invokable_info);
 	}
 	return vala_formal_parameter_type_id;
