@@ -25,8 +25,9 @@
 
 #include <glib.h>
 #include <glib-object.h>
-#include <vala/valastatement.h>
+#include <gee/collection.h>
 #include <vala/valacodenode.h>
+#include <vala/valastatement.h>
 
 G_BEGIN_DECLS
 
@@ -44,23 +45,23 @@ typedef struct _ValaForStatementPrivate ValaForStatementPrivate;
  * Represents a for iteration statement in the source code.
  */
 struct _ValaForStatement {
-	ValaStatement parent;
+	ValaCodeNode parent;
 	ValaForStatementPrivate * priv;
 };
 struct _ValaForStatementClass {
-	ValaStatementClass parent;
+	ValaCodeNodeClass parent;
 };
 
-ValaForStatement* vala_for_statement_new (ValaExpression* cond, ValaStatement* _body, ValaSourceReference* source);
+ValaForStatement* vala_for_statement_new (ValaExpression* condition, ValaBlock* body, ValaSourceReference* source_reference);
 void vala_for_statement_add_initializer (ValaForStatement* self, ValaExpression* init);
-GList* vala_for_statement_get_initializer (ValaForStatement* self);
+GeeCollection* vala_for_statement_get_initializer (ValaForStatement* self);
 void vala_for_statement_add_iterator (ValaForStatement* self, ValaExpression* iter);
-GList* vala_for_statement_get_iterator (ValaForStatement* self);
+GeeCollection* vala_for_statement_get_iterator (ValaForStatement* self);
 ValaExpression* vala_for_statement_get_condition (ValaForStatement* self);
 void vala_for_statement_set_condition (ValaForStatement* self, ValaExpression* value);
-ValaStatement* vala_for_statement_get_body (ValaForStatement* self);
-void vala_for_statement_set_body (ValaForStatement* self, ValaStatement* value);
-GType vala_for_statement_get_type ();
+ValaBlock* vala_for_statement_get_body (ValaForStatement* self);
+void vala_for_statement_set_body (ValaForStatement* self, ValaBlock* value);
+GType vala_for_statement_get_type (void);
 
 G_END_DECLS
 
