@@ -1,6 +1,6 @@
 /* valaifstatement.vala
  *
- * Copyright (C) 2006  Jürg Billeter
+ * Copyright (C) 2006-2007  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -25,8 +25,8 @@
 
 #include <glib.h>
 #include <glib-object.h>
-#include <vala/valastatement.h>
 #include <vala/valacodenode.h>
+#include <vala/valastatement.h>
 
 G_BEGIN_DECLS
 
@@ -44,11 +44,11 @@ typedef struct _ValaIfStatementPrivate ValaIfStatementPrivate;
  * Represents an if selection statement in the source code.
  */
 struct _ValaIfStatement {
-	ValaStatement parent;
+	ValaCodeNode parent;
 	ValaIfStatementPrivate * priv;
 };
 struct _ValaIfStatementClass {
-	ValaStatementClass parent;
+	ValaCodeNodeClass parent;
 };
 
 ValaIfStatement* vala_if_statement_new (ValaExpression* cond, ValaBlock* true_stmt, ValaBlock* false_stmt, ValaSourceReference* source);
@@ -58,7 +58,7 @@ ValaBlock* vala_if_statement_get_true_statement (ValaIfStatement* self);
 void vala_if_statement_set_true_statement (ValaIfStatement* self, ValaBlock* value);
 ValaBlock* vala_if_statement_get_false_statement (ValaIfStatement* self);
 void vala_if_statement_set_false_statement (ValaIfStatement* self, ValaBlock* value);
-GType vala_if_statement_get_type ();
+GType vala_if_statement_get_type (void);
 
 G_END_DECLS
 
