@@ -27,6 +27,7 @@
 #include <glib-object.h>
 #include <stdlib.h>
 #include <string.h>
+#include <gee/collection.h>
 #include <vala/valadatatype.h>
 #include <vala/valacodenode.h>
 
@@ -53,16 +54,20 @@ struct _ValaInterfaceClass {
 	ValaDataTypeClass parent;
 };
 
-ValaInterface* vala_interface_new (const char* _name, ValaSourceReference* source);
+ValaInterface* vala_interface_new (const char* name, ValaSourceReference* source_reference);
 void vala_interface_add_type_parameter (ValaInterface* self, ValaTypeParameter* p);
+GeeCollection* vala_interface_get_type_parameters (ValaInterface* self);
 void vala_interface_add_prerequisite (ValaInterface* self, ValaTypeReference* type);
-GList* vala_interface_get_prerequisites (ValaInterface* self);
+void vala_interface_prepend_prerequisite (ValaInterface* self, ValaTypeReference* type);
+GeeCollection* vala_interface_get_prerequisites (ValaInterface* self);
 void vala_interface_add_method (ValaInterface* self, ValaMethod* m);
-GList* vala_interface_get_methods (ValaInterface* self);
+GeeCollection* vala_interface_get_methods (ValaInterface* self);
+void vala_interface_add_field (ValaInterface* self, ValaField* f);
+GeeCollection* vala_interface_get_fields (ValaInterface* self);
 void vala_interface_add_property (ValaInterface* self, ValaProperty* prop);
-GList* vala_interface_get_properties (ValaInterface* self);
+GeeCollection* vala_interface_get_properties (ValaInterface* self);
 void vala_interface_add_signal (ValaInterface* self, ValaSignal* sig);
-GList* vala_interface_get_signals (ValaInterface* self);
+GeeCollection* vala_interface_get_signals (ValaInterface* self);
 char* vala_interface_get_lower_case_csuffix (ValaInterface* self);
 void vala_interface_set_lower_case_csuffix (ValaInterface* self, const char* csuffix);
 void vala_interface_process_attributes (ValaInterface* self);
@@ -70,7 +75,7 @@ char* vala_interface_get_type_cname (ValaInterface* self);
 void vala_interface_set_type_cname (ValaInterface* self, const char* type_cname);
 gboolean vala_interface_get_is_static (ValaInterface* self);
 void vala_interface_set_is_static (ValaInterface* self, gboolean value);
-GType vala_interface_get_type ();
+GType vala_interface_get_type (void);
 
 G_END_DECLS
 
