@@ -23,25 +23,20 @@
 
 #ifndef __VALAINTERFACEWRITER_H__
 #define __VALAINTERFACEWRITER_H__
-typedef struct _ValaInterfaceWriter ValaInterfaceWriter;
-typedef struct _ValaInterfaceWriterClass ValaInterfaceWriterClass;
-typedef struct _ValaInterfaceWriterPrivate ValaInterfaceWriterPrivate;
 
 #include <glib.h>
 #include <glib-object.h>
 #include <stdlib.h>
 #include <string.h>
+#include <gee/collection.h>
 #include <vala/valacodevisitor.h>
 #include <vala/valacodecontext.h>
-#include <vala/valasourcefile.h>
 #include <vala/valanamespace.h>
 #include <vala/valaclass.h>
 #include <vala/valastruct.h>
 #include <vala/valainterface.h>
 #include <vala/valaenum.h>
 #include <vala/valaenumvalue.h>
-#include <vala/valaflags.h>
-#include <vala/valaflagsvalue.h>
 #include <vala/valaconstant.h>
 #include <vala/valafield.h>
 #include <vala/valacallback.h>
@@ -49,6 +44,7 @@ typedef struct _ValaInterfaceWriterPrivate ValaInterfaceWriterPrivate;
 #include <vala/valacreationmethod.h>
 #include <vala/valaproperty.h>
 #include <vala/valasignal.h>
+#include <vala/valatypereference.h>
 
 G_BEGIN_DECLS
 
@@ -60,6 +56,9 @@ G_BEGIN_DECLS
 #define VALA_IS_INTERFACE_WRITER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_INTERFACE_WRITER))
 #define VALA_INTERFACE_WRITER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_INTERFACE_WRITER, ValaInterfaceWriterClass))
 
+typedef struct _ValaInterfaceWriter ValaInterfaceWriter;
+typedef struct _ValaInterfaceWriterClass ValaInterfaceWriterClass;
+typedef struct _ValaInterfaceWriterPrivate ValaInterfaceWriterPrivate;
 
 /**
  * Code visitor generating Vala API file for the public interface.
@@ -73,7 +72,7 @@ struct _ValaInterfaceWriterClass {
 };
 
 void vala_interface_writer_write_file (ValaInterfaceWriter* self, ValaCodeContext* context, const char* filename);
-GType vala_interface_writer_get_type ();
+GType vala_interface_writer_get_type (void);
 
 G_END_DECLS
 
