@@ -27,6 +27,7 @@
 #include <glib-object.h>
 #include <stdlib.h>
 #include <string.h>
+#include <gee/collection.h>
 #include <vala/valaexpression.h>
 #include <vala/valacodenode.h>
 
@@ -54,17 +55,17 @@ struct _ValaLambdaExpressionClass {
 	ValaExpressionClass parent;
 };
 
-ValaLambdaExpression* vala_lambda_expression_new (ValaExpression* body, ValaSourceReference* source);
-ValaLambdaExpression* vala_lambda_expression_new_with_statement_body (ValaBlock* body, ValaSourceReference* source);
+ValaLambdaExpression* vala_lambda_expression_new (ValaExpression* expression_body, ValaSourceReference* source_reference);
+ValaLambdaExpression* vala_lambda_expression_new_with_statement_body (ValaBlock* statement_body, ValaSourceReference* source_reference);
 void vala_lambda_expression_add_parameter (ValaLambdaExpression* self, const char* param);
-GList* vala_lambda_expression_get_parameters (ValaLambdaExpression* self);
+GeeCollection* vala_lambda_expression_get_parameters (ValaLambdaExpression* self);
 ValaExpression* vala_lambda_expression_get_expression_body (ValaLambdaExpression* self);
 void vala_lambda_expression_set_expression_body (ValaLambdaExpression* self, ValaExpression* value);
 ValaBlock* vala_lambda_expression_get_statement_body (ValaLambdaExpression* self);
 void vala_lambda_expression_set_statement_body (ValaLambdaExpression* self, ValaBlock* value);
 ValaMethod* vala_lambda_expression_get_method (ValaLambdaExpression* self);
 void vala_lambda_expression_set_method (ValaLambdaExpression* self, ValaMethod* value);
-GType vala_lambda_expression_get_type ();
+GType vala_lambda_expression_get_type (void);
 
 G_END_DECLS
 
