@@ -1,6 +1,6 @@
 /* valalockstatement.vala
  *
- * Copyright (C) 2006  Raffaele Sandrini
+ * Copyright (C) 2006-2007  Raffaele Sandrini, Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -25,8 +25,8 @@
 
 #include <glib.h>
 #include <glib-object.h>
-#include <vala/valastatement.h>
 #include <vala/valacodenode.h>
+#include <vala/valastatement.h>
 
 G_BEGIN_DECLS
 
@@ -44,19 +44,19 @@ typedef struct _ValaLockStatementPrivate ValaLockStatementPrivate;
  * Represents a lock statement e.g. "lock (a) { f(a) }".
  */
 struct _ValaLockStatement {
-	ValaStatement parent;
+	ValaCodeNode parent;
 	ValaLockStatementPrivate * priv;
 };
 struct _ValaLockStatementClass {
-	ValaStatementClass parent;
+	ValaCodeNodeClass parent;
 };
 
-ValaLockStatement* vala_lock_statement_new (ValaExpression* _resource, ValaStatement* _body, ValaSourceReference* source);
+ValaLockStatement* vala_lock_statement_new (ValaExpression* resource, ValaBlock* body, ValaSourceReference* source_reference);
 ValaExpression* vala_lock_statement_get_resource (ValaLockStatement* self);
 void vala_lock_statement_set_resource (ValaLockStatement* self, ValaExpression* value);
-ValaStatement* vala_lock_statement_get_body (ValaLockStatement* self);
-void vala_lock_statement_set_body (ValaLockStatement* self, ValaStatement* value);
-GType vala_lock_statement_get_type ();
+ValaBlock* vala_lock_statement_get_body (ValaLockStatement* self);
+void vala_lock_statement_set_body (ValaLockStatement* self, ValaBlock* value);
+GType vala_lock_statement_get_type (void);
 
 G_END_DECLS
 
