@@ -20,24 +20,24 @@
  * 	Jürg Billeter <j@bitron.ch>
  *	Raffaele Sandrini <rasa@gmx.ch>
  */
-#define VALA_FREE_CHECKED(o,f) ((o) == NULL ? NULL : ((o) = (f (o), NULL)))
-#define VALA_FREE_UNCHECKED(o,f) ((o) = (f (o), NULL))
 
 #include "valamethod.h"
+#include <gee/arraylist.h>
+#include <gee/list.h>
+#include <gee/readonlycollection.h>
+#include <gee/iterable.h>
+#include <gee/iterator.h>
 #include <vala/valatypereference.h>
 #include <vala/valablock.h>
 #include <vala/valamethod.h>
 #include <vala/valaformalparameter.h>
 #include <vala/valasourcereference.h>
-#include <vala/valacodevisitor.h>
 #include <vala/valasymbol.h>
-#include <vala/valadatatype.h>
-#include <vala/valanamespace.h>
-#include <vala/valaclass.h>
+#include <vala/valascope.h>
+#include <vala/valacodevisitor.h>
 #include <vala/valaattribute.h>
 
 struct _ValaMethodPrivate {
-	char* _name;
 	ValaTypeReference* _return_type;
 	ValaBlock* _body;
 	gboolean _is_abstract;
@@ -51,15 +51,14 @@ struct _ValaMethodPrivate {
 	ValaFormalParameter* _this_parameter;
 	gboolean _printf_format;
 	gboolean _instance;
-	GList* parameters;
+	GeeList* parameters;
 	char* cname;
 	gboolean _no_array_length;
-	GList* error_domains;
+	GeeList* error_domains;
 };
 #define VALA_METHOD_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_METHOD, ValaMethodPrivate))
 enum  {
 	VALA_METHOD_DUMMY_PROPERTY,
-	VALA_METHOD_NAME,
 	VALA_METHOD_RETURN_TYPE,
 	VALA_METHOD_BODY,
 	VALA_METHOD_INSTANCE,
@@ -75,7 +74,7 @@ enum  {
 	VALA_METHOD_NO_ARRAY_LENGTH,
 	VALA_METHOD_PRINTF_FORMAT
 };
-static GList* vala_method_real_get_parameters (ValaInvokable* base);
+static GeeCollection* vala_method_real_get_parameters (ValaInvokable* base);
 static ValaTypeReference* vala_method_real_get_return_type (ValaInvokable* base);
 static gboolean vala_method_real_is_invokable (ValaInvokable* base);
 static void vala_method_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
@@ -95,19 +94,15 @@ static void vala_method_dispose (GObject * obj);
  * @param source      reference to source code
  * @return            newly created method
  */
-ValaMethod* vala_method_new (const char* _name, ValaTypeReference* _return_type, ValaSourceReference* source)
+ValaMethod* vala_method_new (const char* name, ValaTypeReference* return_type, ValaSourceReference* source_reference)
 {
-	GParameter * __params;
-	GParameter * __params_it;
 	ValaMethod * self;
-	g_return_val_if_fail (_return_type == NULL || VALA_IS_TYPE_REFERENCE (_return_type), NULL);
-	g_return_val_if_fail (source == NULL || VALA_IS_SOURCE_REFERENCE (source), NULL);
-	__params = g_new0 (GParameter, 3);
-	__params_it = __params;
-	(__params_it->name = "name", g_value_init (&__params_it->value, G_TYPE_STRING), g_value_set_string (&__params_it->value, _name), __params_it++);
-	(__params_it->name = "return-type", g_value_init (&__params_it->value, VALA_TYPE_TYPE_REFERENCE), g_value_set_object (&__params_it->value, _return_type), __params_it++);
-	(__params_it->name = "source-reference", g_value_init (&__params_it->value, VALA_TYPE_SOURCE_REFERENCE), g_value_set_object (&__params_it->value, source), __params_it++);
-	self = g_object_newv (VALA_TYPE_METHOD, __params_it - __params, __params);
+	g_return_val_if_fail (return_type == NULL || VALA_IS_TYPE_REFERENCE (return_type), NULL);
+	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
+	self = g_object_newv (VALA_TYPE_METHOD, 0, NULL);
+	vala_symbol_set_name (VALA_SYMBOL (self), name);
+	vala_method_set_return_type (self, return_type);
+	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source_reference);
 	return self;
 }
 
@@ -122,17 +117,20 @@ void vala_method_add_parameter (ValaMethod* self, ValaFormalParameter* param)
 	g_return_if_fail (VALA_IS_METHOD (self));
 	g_return_if_fail (VALA_IS_FORMAL_PARAMETER (param));
 	if (vala_method_get_no_array_length (self)) {
-		(vala_formal_parameter_set_no_array_length (param, TRUE), vala_formal_parameter_get_no_array_length (param));
+		vala_formal_parameter_set_no_array_length (param, TRUE);
+	}
+	gee_collection_add (GEE_COLLECTION (self->priv->parameters), param);
+	if (!vala_formal_parameter_get_ellipsis (param)) {
+		vala_scope_add (vala_symbol_get_scope (((ValaSymbol*) self)), vala_symbol_get_name (((ValaSymbol*) param)), VALA_SYMBOL (param));
 	}
-	self->priv->parameters = g_list_append (self->priv->parameters, g_object_ref (param));
 }
 
 
-static GList* vala_method_real_get_parameters (ValaInvokable* base)
+static GeeCollection* vala_method_real_get_parameters (ValaInvokable* base)
 {
 	ValaMethod * self;
-	self = VALA_METHOD (base);
-	return g_list_copy (self->priv->parameters);
+	self = ((ValaMethod*) base);
+	return GEE_COLLECTION (gee_read_only_collection_new (g_object_ref, g_object_unref, GEE_COLLECTION (self->priv->parameters)));
 }
 
 
@@ -140,7 +138,7 @@ static ValaTypeReference* vala_method_real_get_return_type (ValaInvokable* base)
 {
 	ValaMethod * self;
 	ValaTypeReference* __temp1;
-	self = VALA_METHOD (base);
+	self = ((ValaMethod*) base);
 	__temp1 = NULL;
 	return (__temp1 = vala_method_get_return_type (self), (__temp1 == NULL ? NULL : g_object_ref (__temp1)));
 }
@@ -149,7 +147,7 @@ static ValaTypeReference* vala_method_real_get_return_type (ValaInvokable* base)
 static gboolean vala_method_real_is_invokable (ValaInvokable* base)
 {
 	ValaMethod * self;
-	self = VALA_METHOD (base);
+	self = ((ValaMethod*) base);
 	return TRUE;
 }
 
@@ -157,7 +155,7 @@ static gboolean vala_method_real_is_invokable (ValaInvokable* base)
 static void vala_method_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor)
 {
 	ValaMethod * self;
-	self = VALA_METHOD (base);
+	self = ((ValaMethod*) base);
 	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	vala_code_visitor_visit_method (visitor, self);
 }
@@ -166,36 +164,40 @@ static void vala_method_real_accept (ValaCodeNode* base, ValaCodeVisitor* visito
 static void vala_method_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor)
 {
 	ValaMethod * self;
-	self = VALA_METHOD (base);
+	self = ((ValaMethod*) base);
 	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	if (vala_method_get_return_type (self) != NULL) {
 		vala_code_node_accept (VALA_CODE_NODE (vala_method_get_return_type (self)), visitor);
 	}
 	{
-		GList* __temp4;
-		GList* param_it;
-		__temp4 = NULL;
-		__temp4 = self->priv->parameters;
-		for (param_it = __temp4; param_it != NULL; param_it = param_it->next) {
+		GeeList* param_collection;
+		GeeIterator* param_it;
+		param_collection = self->priv->parameters;
+		param_it = gee_iterable_iterator (GEE_ITERABLE (param_collection));
+		while (gee_iterator_next (param_it)) {
 			ValaFormalParameter* param;
-			param = param_it->data;
+			param = gee_iterator_get (param_it);
 			{
 				vala_code_node_accept (VALA_CODE_NODE (param), visitor);
+				(param == NULL ? NULL : (param = (g_object_unref (param), NULL)));
 			}
 		}
+		(param_it == NULL ? NULL : (param_it = (g_object_unref (param_it), NULL)));
 	}
 	{
-		GList* __temp5;
-		GList* error_domain_it;
-		__temp5 = NULL;
-		__temp5 = self->priv->error_domains;
-		for (error_domain_it = __temp5; error_domain_it != NULL; error_domain_it = error_domain_it->next) {
+		GeeList* error_domain_collection;
+		GeeIterator* error_domain_it;
+		error_domain_collection = self->priv->error_domains;
+		error_domain_it = gee_iterable_iterator (GEE_ITERABLE (error_domain_collection));
+		while (gee_iterator_next (error_domain_it)) {
 			ValaTypeReference* error_domain;
-			error_domain = error_domain_it->data;
+			error_domain = gee_iterator_get (error_domain_it);
 			{
 				vala_code_node_accept (VALA_CODE_NODE (error_domain), visitor);
+				(error_domain == NULL ? NULL : (error_domain = (g_object_unref (error_domain), NULL)));
 			}
 		}
+		(error_domain_it == NULL ? NULL : (error_domain_it = (g_object_unref (error_domain_it), NULL)));
 	}
 	if (vala_method_get_body (self) != NULL) {
 		vala_code_node_accept (VALA_CODE_NODE (vala_method_get_body (self)), visitor);
@@ -210,15 +212,15 @@ static void vala_method_real_accept_children (ValaCodeNode* base, ValaCodeVisito
  */
 char* vala_method_get_cname (ValaMethod* self)
 {
-	const char* __temp7;
+	const char* __temp5;
 	g_return_val_if_fail (VALA_IS_METHOD (self), NULL);
 	if (self->priv->cname == NULL) {
-		char* __temp6;
-		__temp6 = NULL;
-		self->priv->cname = (__temp6 = vala_method_get_default_cname (self), (self->priv->cname = (g_free (self->priv->cname), NULL)), __temp6);
+		char* __temp4;
+		__temp4 = NULL;
+		self->priv->cname = (__temp4 = vala_method_get_default_cname (self), (self->priv->cname = (g_free (self->priv->cname), NULL)), __temp4);
 	}
-	__temp7 = NULL;
-	return (__temp7 = self->priv->cname, (__temp7 == NULL ? NULL : g_strdup (__temp7)));
+	__temp5 = NULL;
+	return (__temp5 = self->priv->cname, (__temp5 == NULL ? NULL : g_strdup (__temp5)));
 }
 
 
@@ -230,47 +232,20 @@ char* vala_method_get_cname (ValaMethod* self)
  */
 static char* vala_method_real_get_default_cname (ValaMethod* self)
 {
-	ValaCodeNode* __temp9;
-	ValaCodeNode* parent;
 	g_return_val_if_fail (VALA_IS_METHOD (self), NULL);
-	__temp9 = NULL;
-	parent = (__temp9 = vala_symbol_get_node (vala_symbol_get_parent_symbol (vala_code_node_get_symbol (VALA_CODE_NODE (self)))), (__temp9 == NULL ? NULL : g_object_ref (__temp9)));
-	if (VALA_IS_DATA_TYPE (parent)) {
-		if (g_str_has_prefix (vala_method_get_name (self), "_")) {
-			char* __temp10;
-			char* __temp11;
-			char* __temp12;
-			__temp10 = NULL;
-			__temp11 = NULL;
-			__temp12 = NULL;
-			return (__temp12 = (__temp11 = g_strdup_printf ("_%s%s", (__temp10 = vala_data_type_get_lower_case_cprefix ((VALA_DATA_TYPE (parent)))), g_utf8_offset_to_pointer (vala_method_get_name (self), 1)), (__temp10 = (g_free (__temp10), NULL)), __temp11), (parent == NULL ? NULL : (parent = (g_object_unref (parent), NULL))), __temp12);
-		} else {
-			char* __temp13;
-			char* __temp14;
-			char* __temp15;
-			__temp13 = NULL;
-			__temp14 = NULL;
-			__temp15 = NULL;
-			return (__temp15 = (__temp14 = g_strdup_printf ("%s%s", (__temp13 = vala_data_type_get_lower_case_cprefix ((VALA_DATA_TYPE (parent)))), vala_method_get_name (self)), (__temp13 = (g_free (__temp13), NULL)), __temp14), (parent == NULL ? NULL : (parent = (g_object_unref (parent), NULL))), __temp15);
-		}
+	if (g_str_has_prefix (vala_symbol_get_name (((ValaSymbol*) self)), "_")) {
+		char* __temp7;
+		char* __temp8;
+		__temp7 = NULL;
+		__temp8 = NULL;
+		return (__temp8 = g_strdup_printf ("_%s%s", (__temp7 = vala_symbol_get_lower_case_cprefix (vala_symbol_get_parent_symbol (((ValaSymbol*) self)))), g_utf8_offset_to_pointer (vala_symbol_get_name (((ValaSymbol*) self)), 1)), (__temp7 = (g_free (__temp7), NULL)), __temp8);
 	} else {
-		if (VALA_IS_NAMESPACE (parent)) {
-			char* __temp16;
-			char* __temp17;
-			char* __temp18;
-			__temp16 = NULL;
-			__temp17 = NULL;
-			__temp18 = NULL;
-			return (__temp18 = (__temp17 = g_strdup_printf ("%s%s", (__temp16 = vala_namespace_get_lower_case_cprefix ((VALA_NAMESPACE (parent)))), vala_method_get_name (self)), (__temp16 = (g_free (__temp16), NULL)), __temp17), (parent == NULL ? NULL : (parent = (g_object_unref (parent), NULL))), __temp18);
-		} else {
-			const char* __temp19;
-			char* __temp20;
-			__temp19 = NULL;
-			__temp20 = NULL;
-			return (__temp20 = (__temp19 = vala_method_get_name (self), (__temp19 == NULL ? NULL : g_strdup (__temp19))), (parent == NULL ? NULL : (parent = (g_object_unref (parent), NULL))), __temp20);
-		}
+		char* __temp10;
+		char* __temp11;
+		__temp10 = NULL;
+		__temp11 = NULL;
+		return (__temp11 = g_strdup_printf ("%s%s", (__temp10 = vala_symbol_get_lower_case_cprefix (vala_symbol_get_parent_symbol (((ValaSymbol*) self)))), vala_symbol_get_name (((ValaSymbol*) self))), (__temp10 = (g_free (__temp10), NULL)), __temp11);
 	}
-	(parent == NULL ? NULL : (parent = (g_object_unref (parent), NULL)));
 }
 
 
@@ -290,18 +265,11 @@ char* vala_method_get_real_cname (ValaMethod* self)
 {
 	g_return_val_if_fail (VALA_IS_METHOD (self), NULL);
 	if (vala_method_get_base_method (self) != NULL || vala_method_get_base_interface_method (self) != NULL) {
-		ValaClass* __temp21;
-		ValaClass* parent;
-		char* __temp22;
-		char* __temp23;
-		char* __temp24;
-		__temp21 = NULL;
-		parent = (__temp21 = VALA_CLASS (vala_symbol_get_node (vala_symbol_get_parent_symbol (vala_code_node_get_symbol (VALA_CODE_NODE (self))))), (__temp21 == NULL ? NULL : g_object_ref (__temp21)));
-		__temp22 = NULL;
-		__temp23 = NULL;
-		__temp24 = NULL;
-		return (__temp24 = (__temp23 = g_strdup_printf ("%s_real_%s", (__temp22 = vala_data_type_get_lower_case_cname (VALA_DATA_TYPE (parent), NULL)), vala_method_get_name (self)), (__temp22 = (g_free (__temp22), NULL)), __temp23), (parent == NULL ? NULL : (parent = (g_object_unref (parent), NULL))), __temp24);
-		(parent == NULL ? NULL : (parent = (g_object_unref (parent), NULL)));
+		char* __temp13;
+		char* __temp14;
+		__temp13 = NULL;
+		__temp14 = NULL;
+		return (__temp14 = g_strdup_printf ("%s_real_%s", (__temp13 = vala_symbol_get_lower_case_cname (vala_symbol_get_parent_symbol (((ValaSymbol*) self)), NULL)), vala_symbol_get_name (((ValaSymbol*) self))), (__temp13 = (g_free (__temp13), NULL)), __temp14);
 	} else {
 		return vala_method_get_cname (self);
 	}
@@ -315,12 +283,12 @@ char* vala_method_get_real_cname (ValaMethod* self)
  */
 void vala_method_set_cname (ValaMethod* self, const char* cname)
 {
-	char* __temp27;
-	const char* __temp26;
+	char* __temp18;
+	const char* __temp17;
 	g_return_if_fail (VALA_IS_METHOD (self));
-	__temp27 = NULL;
-	__temp26 = NULL;
-	self->priv->cname = (__temp27 = (__temp26 = cname, (__temp26 == NULL ? NULL : g_strdup (__temp26))), (self->priv->cname = (g_free (self->priv->cname), NULL)), __temp27);
+	__temp18 = NULL;
+	__temp17 = NULL;
+	self->priv->cname = (__temp18 = (__temp17 = cname, (__temp17 == NULL ? NULL : g_strdup (__temp17))), (self->priv->cname = (g_free (self->priv->cname), NULL)), __temp18);
 }
 
 
@@ -329,10 +297,31 @@ static void vala_method_process_ccode_attribute (ValaMethod* self, ValaAttribute
 	g_return_if_fail (VALA_IS_METHOD (self));
 	g_return_if_fail (a == NULL || VALA_IS_ATTRIBUTE (a));
 	if (vala_attribute_has_argument (a, "cname")) {
-		char* __temp28;
-		__temp28 = NULL;
-		vala_method_set_cname (self, (__temp28 = vala_attribute_get_string (a, "cname")));
-		(__temp28 = (g_free (__temp28), NULL));
+		char* __temp19;
+		__temp19 = NULL;
+		vala_method_set_cname (self, (__temp19 = vala_attribute_get_string (a, "cname")));
+		(__temp19 = (g_free (__temp19), NULL));
+	}
+	if (vala_attribute_has_argument (a, "cheader_filename")) {
+		char* val;
+		val = vala_attribute_get_string (a, "cheader_filename");
+		{
+			char** filename_collection;
+			char** filename_it;
+			filename_collection = g_strsplit (val, ",", 0);
+			for (filename_it = filename_collection; *filename_it != NULL; filename_it = filename_it + 1) {
+				const char* __temp20;
+				char* filename;
+				__temp20 = NULL;
+				filename = (__temp20 = *filename_it, (__temp20 == NULL ? NULL : g_strdup (__temp20)));
+				{
+					vala_member_add_cheader_filename (VALA_MEMBER (self), filename);
+					(filename = (g_free (filename), NULL));
+				}
+			}
+			(filename_collection = (g_strfreev (filename_collection), NULL));
+		}
+		(val = (g_free (val), NULL));
 	}
 }
 
@@ -344,34 +333,35 @@ void vala_method_process_attributes (ValaMethod* self)
 {
 	g_return_if_fail (VALA_IS_METHOD (self));
 	{
-		GList* __temp29;
+		GList* a_collection;
 		GList* a_it;
-		__temp29 = NULL;
-		__temp29 = VALA_CODE_NODE (self)->attributes;
-		for (a_it = __temp29; a_it != NULL; a_it = a_it->next) {
+		a_collection = ((ValaCodeNode*) self)->attributes;
+		for (a_it = a_collection; a_it != NULL; a_it = a_it->next) {
+			ValaAttribute* __temp21;
 			ValaAttribute* a;
-			a = a_it->data;
+			__temp21 = NULL;
+			a = (__temp21 = a_it->data, (__temp21 == NULL ? NULL : g_object_ref (__temp21)));
 			{
 				if (g_utf8_collate (vala_attribute_get_name (a), "CCode") == 0) {
 					vala_method_process_ccode_attribute (self, a);
 				} else {
 					if (g_utf8_collate (vala_attribute_get_name (a), "ReturnsModifiedPointer") == 0) {
-						(vala_method_set_returns_modified_pointer (self, TRUE), vala_method_get_returns_modified_pointer (self));
+						vala_method_set_returns_modified_pointer (self, TRUE);
 					} else {
 						if (g_utf8_collate (vala_attribute_get_name (a), "InstanceLast") == 0) {
-							(vala_method_set_instance_last (self, TRUE), vala_method_get_instance_last (self));
+							vala_method_set_instance_last (self, TRUE);
 						} else {
 							if (g_utf8_collate (vala_attribute_get_name (a), "InstanceByReference") == 0) {
-								(vala_method_set_instance_by_reference (self, TRUE), vala_method_get_instance_by_reference (self));
+								vala_method_set_instance_by_reference (self, TRUE);
 							} else {
 								if (g_utf8_collate (vala_attribute_get_name (a), "FloatingReference") == 0) {
-									(vala_type_reference_set_floating_reference (vala_method_get_return_type (self), TRUE), vala_type_reference_get_floating_reference (vala_method_get_return_type (self)));
+									vala_type_reference_set_floating_reference (vala_method_get_return_type (self), TRUE);
 								} else {
 									if (g_utf8_collate (vala_attribute_get_name (a), "NoArrayLength") == 0) {
-										(vala_method_set_no_array_length (self, TRUE), vala_method_get_no_array_length (self));
+										vala_method_set_no_array_length (self, TRUE);
 									} else {
 										if (g_utf8_collate (vala_attribute_get_name (a), "PrintfFormat") == 0) {
-											(vala_method_set_printf_format (self, TRUE), vala_method_get_printf_format (self));
+											vala_method_set_printf_format (self, TRUE);
 										}
 									}
 								}
@@ -379,6 +369,7 @@ void vala_method_process_attributes (ValaMethod* self)
 						}
 					}
 				}
+				(a == NULL ? NULL : (a = (g_object_unref (a), NULL)));
 			}
 		}
 	}
@@ -394,50 +385,51 @@ void vala_method_process_attributes (ValaMethod* self)
  */
 gboolean vala_method_equals (ValaMethod* self, ValaMethod* m2)
 {
-	GList* method_params;
-	GList* method_params_it;
-	gboolean __temp36;
+	GeeCollection* __temp23;
+	GeeIterator* __temp24;
+	GeeIterator* method_params_it;
+	gboolean __temp30;
 	g_return_val_if_fail (VALA_IS_METHOD (self), FALSE);
 	g_return_val_if_fail (VALA_IS_METHOD (m2), FALSE);
 	if (!vala_type_reference_equals (vala_method_get_return_type (m2), vala_method_get_return_type (self))) {
 		return FALSE;
 	}
-	method_params = vala_invokable_get_parameters (VALA_INVOKABLE (m2));
-	method_params_it = method_params;
+	__temp23 = NULL;
+	__temp24 = NULL;
+	method_params_it = (__temp24 = gee_iterable_iterator (GEE_ITERABLE ((__temp23 = vala_invokable_get_parameters (VALA_INVOKABLE (m2))))), (__temp23 == NULL ? NULL : (__temp23 = (g_object_unref (__temp23), NULL))), __temp24);
 	{
-		GList* __temp34;
-		GList* param_it;
-		__temp34 = NULL;
-		__temp34 = self->priv->parameters;
-		for (param_it = __temp34; param_it != NULL; param_it = param_it->next) {
+		GeeList* param_collection;
+		GeeIterator* param_it;
+		param_collection = self->priv->parameters;
+		param_it = gee_iterable_iterator (GEE_ITERABLE (param_collection));
+		while (gee_iterator_next (param_it)) {
 			ValaFormalParameter* param;
-			param = param_it->data;
+			param = gee_iterator_get (param_it);
 			{
-				ValaFormalParameter* __temp32;
-				ValaFormalParameter* method_param;
+				ValaFormalParameter* __temp26;
+				gboolean __temp27;
 				/* method may not expect less arguments */
-				if (method_params_it == NULL) {
-					gboolean __temp31;
-					return (__temp31 = FALSE, (method_params == NULL ? NULL : (method_params = (g_list_free (method_params), NULL))), __temp31);
+				if (!gee_iterator_next (method_params_it)) {
+					gboolean __temp25;
+					return (__temp25 = FALSE, (param == NULL ? NULL : (param = (g_object_unref (param), NULL))), (param_it == NULL ? NULL : (param_it = (g_object_unref (param_it), NULL))), (method_params_it == NULL ? NULL : (method_params_it = (g_object_unref (method_params_it), NULL))), __temp25);
 				}
-				__temp32 = NULL;
-				method_param = (__temp32 = VALA_FORMAL_PARAMETER (method_params_it->data), (__temp32 == NULL ? NULL : g_object_ref (__temp32)));
-				if (!vala_type_reference_equals (vala_formal_parameter_get_type_reference (method_param), vala_formal_parameter_get_type_reference (param))) {
-					gboolean __temp33;
-					return (__temp33 = FALSE, (method_param == NULL ? NULL : (method_param = (g_object_unref (method_param), NULL))), __temp33);
+				__temp26 = NULL;
+				if ((__temp27 = !vala_type_reference_equals (vala_formal_parameter_get_type_reference ((__temp26 = gee_iterator_get (method_params_it))), vala_formal_parameter_get_type_reference (param)), (__temp26 == NULL ? NULL : (__temp26 = (g_object_unref (__temp26), NULL))), __temp27)) {
+					gboolean __temp28;
+					return (__temp28 = FALSE, (param == NULL ? NULL : (param = (g_object_unref (param), NULL))), (param_it == NULL ? NULL : (param_it = (g_object_unref (param_it), NULL))), (method_params_it == NULL ? NULL : (method_params_it = (g_object_unref (method_params_it), NULL))), __temp28);
 				}
-				method_params_it = method_params_it->next;
-				(method_param == NULL ? NULL : (method_param = (g_object_unref (method_param), NULL)));
+				(param == NULL ? NULL : (param = (g_object_unref (param), NULL)));
 			}
 		}
+		(param_it == NULL ? NULL : (param_it = (g_object_unref (param_it), NULL)));
 	}
 	/* method may not expect more arguments */
-	if (method_params_it != NULL) {
-		gboolean __temp35;
-		return (__temp35 = FALSE, (method_params == NULL ? NULL : (method_params = (g_list_free (method_params), NULL))), __temp35);
+	if (gee_iterator_next (method_params_it)) {
+		gboolean __temp29;
+		return (__temp29 = FALSE, (method_params_it == NULL ? NULL : (method_params_it = (g_object_unref (method_params_it), NULL))), __temp29);
 	}
-	return (__temp36 = TRUE, (method_params == NULL ? NULL : (method_params = (g_list_free (method_params), NULL))), __temp36);
-	(method_params == NULL ? NULL : (method_params = (g_list_free (method_params), NULL)));
+	return (__temp30 = TRUE, (method_params_it == NULL ? NULL : (method_params_it = (g_object_unref (method_params_it), NULL))), __temp30);
+	(method_params_it == NULL ? NULL : (method_params_it = (g_object_unref (method_params_it), NULL)));
 }
 
 
@@ -450,7 +442,7 @@ void vala_method_add_error_domain (ValaMethod* self, ValaTypeReference* error_do
 {
 	g_return_if_fail (VALA_IS_METHOD (self));
 	g_return_if_fail (VALA_IS_TYPE_REFERENCE (error_domain));
-	self->priv->error_domains = g_list_append (self->priv->error_domains, g_object_ref (error_domain));
+	gee_collection_add (GEE_COLLECTION (self->priv->error_domains), error_domain);
 }
 
 
@@ -459,28 +451,10 @@ void vala_method_add_error_domain (ValaMethod* self, ValaTypeReference* error_do
  *
  * @return list of error domains
  */
-GList* vala_method_get_error_domains (ValaMethod* self)
+GeeCollection* vala_method_get_error_domains (ValaMethod* self)
 {
 	g_return_val_if_fail (VALA_IS_METHOD (self), NULL);
-	return g_list_copy (self->priv->error_domains);
-}
-
-
-char* vala_method_get_name (ValaMethod* self)
-{
-	g_return_val_if_fail (VALA_IS_METHOD (self), NULL);
-	return self->priv->_name;
-}
-
-
-void vala_method_set_name (ValaMethod* self, const char* value)
-{
-	char* __temp40;
-	const char* __temp39;
-	g_return_if_fail (VALA_IS_METHOD (self));
-	__temp40 = NULL;
-	__temp39 = NULL;
-	self->priv->_name = (__temp40 = (__temp39 = value, (__temp39 == NULL ? NULL : g_strdup (__temp39))), (self->priv->_name = (g_free (self->priv->_name), NULL)), __temp40);
+	return GEE_COLLECTION (gee_read_only_collection_new (g_object_ref, g_object_unref, GEE_COLLECTION (self->priv->error_domains)));
 }
 
 
@@ -493,12 +467,12 @@ ValaTypeReference* vala_method_get_return_type (ValaMethod* self)
 
 void vala_method_set_return_type (ValaMethod* self, ValaTypeReference* value)
 {
-	ValaTypeReference* __temp43;
-	ValaTypeReference* __temp42;
+	ValaTypeReference* __temp34;
+	ValaTypeReference* __temp33;
 	g_return_if_fail (VALA_IS_METHOD (self));
-	__temp43 = NULL;
-	__temp42 = NULL;
-	self->priv->_return_type = (__temp43 = (__temp42 = value, (__temp42 == NULL ? NULL : g_object_ref (__temp42))), (self->priv->_return_type == NULL ? NULL : (self->priv->_return_type = (g_object_unref (self->priv->_return_type), NULL))), __temp43);
+	__temp34 = NULL;
+	__temp33 = NULL;
+	self->priv->_return_type = (__temp34 = (__temp33 = value, (__temp33 == NULL ? NULL : g_object_ref (__temp33))), (self->priv->_return_type == NULL ? NULL : (self->priv->_return_type = (g_object_unref (self->priv->_return_type), NULL))), __temp34);
 }
 
 
@@ -511,12 +485,12 @@ ValaBlock* vala_method_get_body (ValaMethod* self)
 
 void vala_method_set_body (ValaMethod* self, ValaBlock* value)
 {
-	ValaBlock* __temp46;
-	ValaBlock* __temp45;
+	ValaBlock* __temp37;
+	ValaBlock* __temp36;
 	g_return_if_fail (VALA_IS_METHOD (self));
-	__temp46 = NULL;
-	__temp45 = NULL;
-	self->priv->_body = (__temp46 = (__temp45 = value, (__temp45 == NULL ? NULL : g_object_ref (__temp45))), (self->priv->_body == NULL ? NULL : (self->priv->_body = (g_object_unref (self->priv->_body), NULL))), __temp46);
+	__temp37 = NULL;
+	__temp36 = NULL;
+	self->priv->_body = (__temp37 = (__temp36 = value, (__temp36 == NULL ? NULL : g_object_ref (__temp36))), (self->priv->_body == NULL ? NULL : (self->priv->_body = (g_object_unref (self->priv->_body), NULL))), __temp37);
 }
 
 
@@ -641,12 +615,12 @@ ValaMethod* vala_method_get_base_interface_method (ValaMethod* self)
 
 void vala_method_set_base_interface_method (ValaMethod* self, ValaMethod* value)
 {
-	ValaMethod* __temp57;
-	ValaMethod* __temp56;
+	ValaMethod* __temp48;
+	ValaMethod* __temp47;
 	g_return_if_fail (VALA_IS_METHOD (self));
-	__temp57 = NULL;
-	__temp56 = NULL;
-	self->priv->_base_interface_method = (__temp57 = (__temp56 = value, (__temp56 == NULL ? NULL : g_object_ref (__temp56))), (self->priv->_base_interface_method == NULL ? NULL : (self->priv->_base_interface_method = (g_object_unref (self->priv->_base_interface_method), NULL))), __temp57);
+	__temp48 = NULL;
+	__temp47 = NULL;
+	self->priv->_base_interface_method = (__temp48 = (__temp47 = value, (__temp47 == NULL ? NULL : g_object_ref (__temp47))), (self->priv->_base_interface_method == NULL ? NULL : (self->priv->_base_interface_method = (g_object_unref (self->priv->_base_interface_method), NULL))), __temp48);
 }
 
 
@@ -659,12 +633,12 @@ ValaFormalParameter* vala_method_get_this_parameter (ValaMethod* self)
 
 void vala_method_set_this_parameter (ValaMethod* self, ValaFormalParameter* value)
 {
-	ValaFormalParameter* __temp60;
-	ValaFormalParameter* __temp59;
+	ValaFormalParameter* __temp51;
+	ValaFormalParameter* __temp50;
 	g_return_if_fail (VALA_IS_METHOD (self));
-	__temp60 = NULL;
-	__temp59 = NULL;
-	self->priv->_this_parameter = (__temp60 = (__temp59 = value, (__temp59 == NULL ? NULL : g_object_ref (__temp59))), (self->priv->_this_parameter == NULL ? NULL : (self->priv->_this_parameter = (g_object_unref (self->priv->_this_parameter), NULL))), __temp60);
+	__temp51 = NULL;
+	__temp50 = NULL;
+	self->priv->_this_parameter = (__temp51 = (__temp50 = value, (__temp50 == NULL ? NULL : g_object_ref (__temp50))), (self->priv->_this_parameter == NULL ? NULL : (self->priv->_this_parameter = (g_object_unref (self->priv->_this_parameter), NULL))), __temp51);
 }
 
 
@@ -680,17 +654,19 @@ void vala_method_set_no_array_length (ValaMethod* self, gboolean value)
 	g_return_if_fail (VALA_IS_METHOD (self));
 	self->priv->_no_array_length = value;
 	{
-		GList* __temp62;
-		GList* param_it;
-		__temp62 = NULL;
-		__temp62 = self->priv->parameters;
-		for (param_it = __temp62; param_it != NULL; param_it = param_it->next) {
+		GeeList* param_collection;
+		GeeIterator* param_it;
+		param_collection = self->priv->parameters;
+		param_it = gee_iterable_iterator (GEE_ITERABLE (param_collection));
+		while (gee_iterator_next (param_it)) {
 			ValaFormalParameter* param;
-			param = param_it->data;
+			param = gee_iterator_get (param_it);
 			{
-				(vala_formal_parameter_set_no_array_length (param, value), vala_formal_parameter_get_no_array_length (param));
+				vala_formal_parameter_set_no_array_length (param, value);
+				(param == NULL ? NULL : (param = (g_object_unref (param), NULL)));
 			}
 		}
+		(param_it == NULL ? NULL : (param_it = (g_object_unref (param_it), NULL)));
 	}
 }
 
@@ -714,9 +690,6 @@ static void vala_method_get_property (GObject * object, guint property_id, GValu
 	ValaMethod * self;
 	self = VALA_METHOD (object);
 	switch (property_id) {
-		case VALA_METHOD_NAME:
-		g_value_set_string (value, vala_method_get_name (self));
-		break;
 		case VALA_METHOD_RETURN_TYPE:
 		g_value_set_object (value, vala_method_get_return_type (self));
 		break;
@@ -768,9 +741,6 @@ static void vala_method_set_property (GObject * object, guint property_id, const
 	ValaMethod * self;
 	self = VALA_METHOD (object);
 	switch (property_id) {
-		case VALA_METHOD_NAME:
-		vala_method_set_name (self, g_value_get_string (value));
-		break;
 		case VALA_METHOD_RETURN_TYPE:
 		vala_method_set_return_type (self, g_value_get_object (value));
 		break;
@@ -827,7 +797,6 @@ static void vala_method_class_init (ValaMethodClass * klass)
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_method_real_accept;
 	VALA_CODE_NODE_CLASS (klass)->accept_children = vala_method_real_accept_children;
 	VALA_METHOD_CLASS (klass)->get_default_cname = vala_method_real_get_default_cname;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_METHOD_NAME, g_param_spec_string ("name", "foo", "bar", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_METHOD_RETURN_TYPE, g_param_spec_object ("return-type", "foo", "bar", VALA_TYPE_TYPE_REFERENCE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_METHOD_BODY, g_param_spec_object ("body", "foo", "bar", VALA_TYPE_BLOCK, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_METHOD_INSTANCE, g_param_spec_boolean ("instance", "foo", "bar", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
@@ -858,6 +827,8 @@ static void vala_method_init (ValaMethod * self)
 {
 	self->priv = VALA_METHOD_GET_PRIVATE (self);
 	self->priv->_instance = TRUE;
+	self->priv->parameters = GEE_LIST (gee_array_list_new (g_object_ref, g_object_unref, g_direct_equal));
+	self->priv->error_domains = GEE_LIST (gee_array_list_new (g_object_ref, g_object_unref, g_direct_equal));
 }
 
 
@@ -867,21 +838,20 @@ static void vala_method_dispose (GObject * obj)
 	ValaMethodClass * klass;
 	GObjectClass * parent_class;
 	self = VALA_METHOD (obj);
-	(self->priv->_name = (g_free (self->priv->_name), NULL));
 	(self->priv->_return_type == NULL ? NULL : (self->priv->_return_type = (g_object_unref (self->priv->_return_type), NULL)));
 	(self->priv->_body == NULL ? NULL : (self->priv->_body = (g_object_unref (self->priv->_body), NULL)));
 	(self->priv->_base_interface_method == NULL ? NULL : (self->priv->_base_interface_method = (g_object_unref (self->priv->_base_interface_method), NULL)));
 	(self->priv->_this_parameter == NULL ? NULL : (self->priv->_this_parameter = (g_object_unref (self->priv->_this_parameter), NULL)));
-	(self->priv->parameters == NULL ? NULL : (self->priv->parameters = (g_list_foreach (self->priv->parameters, (GFunc) g_object_unref, NULL), g_list_free (self->priv->parameters), NULL)));
+	(self->priv->parameters == NULL ? NULL : (self->priv->parameters = (g_object_unref (self->priv->parameters), NULL)));
 	(self->priv->cname = (g_free (self->priv->cname), NULL));
-	(self->priv->error_domains == NULL ? NULL : (self->priv->error_domains = (g_list_foreach (self->priv->error_domains, (GFunc) g_object_unref, NULL), g_list_free (self->priv->error_domains), NULL)));
+	(self->priv->error_domains == NULL ? NULL : (self->priv->error_domains = (g_object_unref (self->priv->error_domains), NULL)));
 	klass = VALA_METHOD_CLASS (g_type_class_peek (VALA_TYPE_METHOD));
 	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
 	parent_class->dispose (obj);
 }
 
 
-GType vala_method_get_type ()
+GType vala_method_get_type (void)
 {
 	static GType vala_method_type_id = 0;
 	if (G_UNLIKELY (vala_method_type_id == 0)) {
