@@ -23,12 +23,12 @@
 
 #ifndef __VALAMETHOD_H__
 #define __VALAMETHOD_H__
-typedef struct _ValaMethodPrivate ValaMethodPrivate;
 
 #include <glib.h>
 #include <glib-object.h>
 #include <stdlib.h>
 #include <string.h>
+#include <gee/collection.h>
 #include <vala/valamember.h>
 #include <vala/valainvokable.h>
 #include <vala/valamemberaccessibility.h>
@@ -44,6 +44,7 @@ G_BEGIN_DECLS
 #define VALA_IS_METHOD_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_METHOD))
 #define VALA_METHOD_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_METHOD, ValaMethodClass))
 
+typedef struct _ValaMethodPrivate ValaMethodPrivate;
 
 /**
  * Represents a type or namespace method.
@@ -58,7 +59,7 @@ struct _ValaMethodClass {
 	char* (*get_default_cname) (ValaMethod* self);
 };
 
-ValaMethod* vala_method_new (const char* _name, ValaTypeReference* _return_type, ValaSourceReference* source);
+ValaMethod* vala_method_new (const char* name, ValaTypeReference* return_type, ValaSourceReference* source_reference);
 void vala_method_add_parameter (ValaMethod* self, ValaFormalParameter* param);
 char* vala_method_get_cname (ValaMethod* self);
 char* vala_method_get_default_cname (ValaMethod* self);
@@ -66,8 +67,8 @@ char* vala_method_get_real_cname (ValaMethod* self);
 void vala_method_set_cname (ValaMethod* self, const char* cname);
 void vala_method_process_attributes (ValaMethod* self);
 gboolean vala_method_equals (ValaMethod* self, ValaMethod* m2);
-char* vala_method_get_name (ValaMethod* self);
-void vala_method_set_name (ValaMethod* self, const char* value);
+void vala_method_add_error_domain (ValaMethod* self, ValaTypeReference* error_domain);
+GeeCollection* vala_method_get_error_domains (ValaMethod* self);
 ValaTypeReference* vala_method_get_return_type (ValaMethod* self);
 void vala_method_set_return_type (ValaMethod* self, ValaTypeReference* value);
 ValaBlock* vala_method_get_body (ValaMethod* self);
@@ -96,7 +97,7 @@ gboolean vala_method_get_no_array_length (ValaMethod* self);
 void vala_method_set_no_array_length (ValaMethod* self, gboolean value);
 gboolean vala_method_get_printf_format (ValaMethod* self);
 void vala_method_set_printf_format (ValaMethod* self, gboolean value);
-GType vala_method_get_type ();
+GType vala_method_get_type (void);
 
 G_END_DECLS
 
