@@ -19,8 +19,6 @@
  * Author:
  * 	Jürg Billeter <j@bitron.ch>
  */
-#define VALA_FREE_CHECKED(o,f) ((o) == NULL ? NULL : ((o) = (f (o), NULL)))
-#define VALA_FREE_UNCHECKED(o,f) ((o) = (f (o), NULL))
 
 #include "valapostfixexpression.h"
 #include <vala/valasourcereference.h>
@@ -35,7 +33,7 @@ struct _ValaPostfixExpressionPrivate {
 enum  {
 	VALA_POSTFIX_EXPRESSION_DUMMY_PROPERTY,
 	VALA_POSTFIX_EXPRESSION_INNER,
-	VALA_POSTFIX_EXPRESSION_INCREMENT,
+	VALA_POSTFIX_EXPRESSION_INCREMENT
 };
 static void vala_postfix_expression_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static gpointer vala_postfix_expression_parent_class = NULL;
@@ -52,21 +50,30 @@ static void vala_postfix_expression_dispose (GObject * obj);
  */
 ValaPostfixExpression* vala_postfix_expression_new (ValaExpression* _inner, gboolean inc, ValaSourceReference* source)
 {
+	GParameter * __params;
+	GParameter * __params_it;
+	ValaPostfixExpression * self;
 	g_return_val_if_fail (VALA_IS_EXPRESSION (_inner), NULL);
 	g_return_val_if_fail (source == NULL || VALA_IS_SOURCE_REFERENCE (source), NULL);
-	GParameter * __params = g_new0 (GParameter, 3);
-	GParameter * __params_it = __params;
+	__params = g_new0 (GParameter, 1);
+	__params_it = __params;
 	(__params_it->name = "inner", g_value_init (&__params_it->value, VALA_TYPE_EXPRESSION), g_value_set_object (&__params_it->value, _inner), __params_it++);
-	(__params_it->name = "increment", g_value_init (&__params_it->value, G_TYPE_BOOLEAN), g_value_set_boolean (&__params_it->value, inc), __params_it++);
-	(__params_it->name = "source-reference", g_value_init (&__params_it->value, VALA_TYPE_SOURCE_REFERENCE), g_value_set_object (&__params_it->value, source), __params_it++);
-	ValaPostfixExpression * self = g_object_newv (VALA_TYPE_POSTFIX_EXPRESSION, __params_it - __params, __params);
+	self = g_object_newv (VALA_TYPE_POSTFIX_EXPRESSION, __params_it - __params, __params);
+	vala_postfix_expression_set_increment (self, inc);
+	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source);
+	while (__params_it > __params) {
+		--__params_it;
+		g_value_unset (&__params_it->value);
+	}
+	g_free (__params);
 	return self;
 }
 
 
 static void vala_postfix_expression_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor)
 {
-	ValaPostfixExpression * self = VALA_POSTFIX_EXPRESSION (base);
+	ValaPostfixExpression * self;
+	self = ((ValaPostfixExpression*) base);
 	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	vala_code_node_accept (VALA_CODE_NODE (vala_postfix_expression_get_inner (self)), visitor);
 	vala_code_visitor_visit_postfix_expression (visitor, self);
@@ -82,8 +89,9 @@ ValaExpression* vala_postfix_expression_get_inner (ValaPostfixExpression* self)
 
 void vala_postfix_expression_set_inner (ValaPostfixExpression* self, ValaExpression* value)
 {
+	ValaExpression* __temp1;
 	g_return_if_fail (VALA_IS_POSTFIX_EXPRESSION (self));
-	ValaExpression* __temp1 = NULL;
+	__temp1 = NULL;
 	self->priv->_inner = (__temp1 = g_object_ref (value), (self->priv->_inner == NULL ? NULL : (self->priv->_inner = (g_object_unref (self->priv->_inner), NULL))), __temp1);
 }
 
@@ -104,7 +112,8 @@ void vala_postfix_expression_set_increment (ValaPostfixExpression* self, gboolea
 
 static void vala_postfix_expression_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec)
 {
-	ValaPostfixExpression * self = VALA_POSTFIX_EXPRESSION (object);
+	ValaPostfixExpression * self;
+	self = VALA_POSTFIX_EXPRESSION (object);
 	switch (property_id) {
 		case VALA_POSTFIX_EXPRESSION_INNER:
 		g_value_set_object (value, vala_postfix_expression_get_inner (self));
@@ -118,7 +127,8 @@ static void vala_postfix_expression_get_property (GObject * object, guint proper
 
 static void vala_postfix_expression_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec)
 {
-	ValaPostfixExpression * self = VALA_POSTFIX_EXPRESSION (object);
+	ValaPostfixExpression * self;
+	self = VALA_POSTFIX_EXPRESSION (object);
 	switch (property_id) {
 		case VALA_POSTFIX_EXPRESSION_INNER:
 		vala_postfix_expression_set_inner (self, g_value_get_object (value));
@@ -151,17 +161,18 @@ static void vala_postfix_expression_init (ValaPostfixExpression * self)
 
 static void vala_postfix_expression_dispose (GObject * obj)
 {
-	ValaPostfixExpression * self = VALA_POSTFIX_EXPRESSION (obj);
-	(self->priv->_inner == NULL ? NULL : (self->priv->_inner = (g_object_unref (self->priv->_inner), NULL)));
+	ValaPostfixExpression * self;
 	ValaPostfixExpressionClass * klass;
 	GObjectClass * parent_class;
+	self = VALA_POSTFIX_EXPRESSION (obj);
+	(self->priv->_inner == NULL ? NULL : (self->priv->_inner = (g_object_unref (self->priv->_inner), NULL)));
 	klass = VALA_POSTFIX_EXPRESSION_CLASS (g_type_class_peek (VALA_TYPE_POSTFIX_EXPRESSION));
 	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
 	parent_class->dispose (obj);
 }
 
 
-GType vala_postfix_expression_get_type ()
+GType vala_postfix_expression_get_type (void)
 {
 	static GType vala_postfix_expression_type_id = 0;
 	if (G_UNLIKELY (vala_postfix_expression_type_id == 0)) {
