@@ -1,6 +1,6 @@
 /* valapropertyaccessor.vala
  *
- * Copyright (C) 2006  Jürg Billeter
+ * Copyright (C) 2006-2007  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -19,33 +19,35 @@
  * Author:
  * 	Jürg Billeter <j@bitron.ch>
  */
-#define VALA_FREE_CHECKED(o,f) ((o) == NULL ? NULL : ((o) = (f (o), NULL)))
-#define VALA_FREE_UNCHECKED(o,f) ((o) = (f (o), NULL))
 
 #include "valapropertyaccessor.h"
-#include <vala/valastatement.h>
+#include <vala/valaproperty.h>
+#include <vala/valablock.h>
 #include <vala/valaformalparameter.h>
 #include <vala/valasourcereference.h>
 #include <vala/valapropertyaccessor.h>
 #include <vala/valacodevisitor.h>
 
 struct _ValaPropertyAccessorPrivate {
+	ValaProperty* _prop;
 	gboolean _readable;
 	gboolean _writable;
 	gboolean _construction;
-	ValaStatement* _body;
+	ValaBlock* _body;
 	ValaFormalParameter* _value_parameter;
 };
 #define VALA_PROPERTY_ACCESSOR_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_PROPERTY_ACCESSOR, ValaPropertyAccessorPrivate))
 enum  {
 	VALA_PROPERTY_ACCESSOR_DUMMY_PROPERTY,
+	VALA_PROPERTY_ACCESSOR_PROP,
 	VALA_PROPERTY_ACCESSOR_READABLE,
 	VALA_PROPERTY_ACCESSOR_WRITABLE,
 	VALA_PROPERTY_ACCESSOR_CONSTRUCTION,
 	VALA_PROPERTY_ACCESSOR_BODY,
-	VALA_PROPERTY_ACCESSOR_VALUE_PARAMETER,
+	VALA_PROPERTY_ACCESSOR_VALUE_PARAMETER
 };
 static void vala_property_accessor_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
+static void vala_property_accessor_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static gpointer vala_property_accessor_parent_class = NULL;
 static void vala_property_accessor_dispose (GObject * obj);
 
@@ -60,31 +62,52 @@ static void vala_property_accessor_dispose (GObject * obj);
  * @param source       reference to source code
  * @return             newly created property accessor
  */
-ValaPropertyAccessor* vala_property_accessor_new (gboolean _readable, gboolean _writable, gboolean _construction, ValaStatement* _body, ValaSourceReference* source)
+ValaPropertyAccessor* vala_property_accessor_new (gboolean readable, gboolean writable, gboolean construction, ValaBlock* body, ValaSourceReference* source_reference)
 {
-	g_return_val_if_fail (_body == NULL || VALA_IS_STATEMENT (_body), NULL);
-	g_return_val_if_fail (source == NULL || VALA_IS_SOURCE_REFERENCE (source), NULL);
-	GParameter * __params = g_new0 (GParameter, 5);
-	GParameter * __params_it = __params;
-	(__params_it->name = "readable", g_value_init (&__params_it->value, G_TYPE_BOOLEAN), g_value_set_boolean (&__params_it->value, _readable), __params_it++);
-	(__params_it->name = "writable", g_value_init (&__params_it->value, G_TYPE_BOOLEAN), g_value_set_boolean (&__params_it->value, _writable), __params_it++);
-	(__params_it->name = "construction", g_value_init (&__params_it->value, G_TYPE_BOOLEAN), g_value_set_boolean (&__params_it->value, _construction), __params_it++);
-	(__params_it->name = "body", g_value_init (&__params_it->value, VALA_TYPE_STATEMENT), g_value_set_object (&__params_it->value, _body), __params_it++);
-	(__params_it->name = "source-reference", g_value_init (&__params_it->value, VALA_TYPE_SOURCE_REFERENCE), g_value_set_object (&__params_it->value, source), __params_it++);
-	ValaPropertyAccessor * self = g_object_newv (VALA_TYPE_PROPERTY_ACCESSOR, __params_it - __params, __params);
+	ValaPropertyAccessor * self;
+	g_return_val_if_fail (body == NULL || VALA_IS_BLOCK (body), NULL);
+	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
+	self = g_object_newv (VALA_TYPE_PROPERTY_ACCESSOR, 0, NULL);
+	vala_property_accessor_set_readable (self, readable);
+	vala_property_accessor_set_writable (self, writable);
+	vala_property_accessor_set_construction (self, construction);
+	vala_property_accessor_set_body (self, body);
+	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source_reference);
 	return self;
 }
 
 
 static void vala_property_accessor_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor)
 {
-	ValaPropertyAccessor * self = VALA_PROPERTY_ACCESSOR (base);
+	ValaPropertyAccessor * self;
+	self = ((ValaPropertyAccessor*) base);
+	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
+	vala_code_visitor_visit_property_accessor (visitor, self);
+}
+
+
+static void vala_property_accessor_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor)
+{
+	ValaPropertyAccessor * self;
+	self = ((ValaPropertyAccessor*) base);
 	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
-	vala_code_visitor_visit_begin_property_accessor (visitor, self);
 	if (vala_property_accessor_get_body (self) != NULL) {
 		vala_code_node_accept (VALA_CODE_NODE (vala_property_accessor_get_body (self)), visitor);
 	}
-	vala_code_visitor_visit_end_property_accessor (visitor, self);
+}
+
+
+ValaProperty* vala_property_accessor_get_prop (ValaPropertyAccessor* self)
+{
+	g_return_val_if_fail (VALA_IS_PROPERTY_ACCESSOR (self), NULL);
+	return self->priv->_prop;
+}
+
+
+void vala_property_accessor_set_prop (ValaPropertyAccessor* self, ValaProperty* value)
+{
+	g_return_if_fail (VALA_IS_PROPERTY_ACCESSOR (self));
+	self->priv->_prop = value;
 }
 
 
@@ -130,19 +153,21 @@ void vala_property_accessor_set_construction (ValaPropertyAccessor* self, gboole
 }
 
 
-ValaStatement* vala_property_accessor_get_body (ValaPropertyAccessor* self)
+ValaBlock* vala_property_accessor_get_body (ValaPropertyAccessor* self)
 {
 	g_return_val_if_fail (VALA_IS_PROPERTY_ACCESSOR (self), NULL);
 	return self->priv->_body;
 }
 
 
-void vala_property_accessor_set_body (ValaPropertyAccessor* self, ValaStatement* value)
+void vala_property_accessor_set_body (ValaPropertyAccessor* self, ValaBlock* value)
 {
+	ValaBlock* __temp6;
+	ValaBlock* __temp5;
 	g_return_if_fail (VALA_IS_PROPERTY_ACCESSOR (self));
-	ValaStatement* __temp5 = NULL;
-	ValaStatement* __temp4 = NULL;
-	self->priv->_body = (__temp5 = (__temp4 = value, (__temp4 == NULL ? NULL : g_object_ref (__temp4))), (self->priv->_body == NULL ? NULL : (self->priv->_body = (g_object_unref (self->priv->_body), NULL))), __temp5);
+	__temp6 = NULL;
+	__temp5 = NULL;
+	self->priv->_body = (__temp6 = (__temp5 = value, (__temp5 == NULL ? NULL : g_object_ref (__temp5))), (self->priv->_body == NULL ? NULL : (self->priv->_body = (g_object_unref (self->priv->_body), NULL))), __temp6);
 }
 
 
@@ -155,17 +180,23 @@ ValaFormalParameter* vala_property_accessor_get_value_parameter (ValaPropertyAcc
 
 void vala_property_accessor_set_value_parameter (ValaPropertyAccessor* self, ValaFormalParameter* value)
 {
+	ValaFormalParameter* __temp9;
+	ValaFormalParameter* __temp8;
 	g_return_if_fail (VALA_IS_PROPERTY_ACCESSOR (self));
-	ValaFormalParameter* __temp8 = NULL;
-	ValaFormalParameter* __temp7 = NULL;
-	self->priv->_value_parameter = (__temp8 = (__temp7 = value, (__temp7 == NULL ? NULL : g_object_ref (__temp7))), (self->priv->_value_parameter == NULL ? NULL : (self->priv->_value_parameter = (g_object_unref (self->priv->_value_parameter), NULL))), __temp8);
+	__temp9 = NULL;
+	__temp8 = NULL;
+	self->priv->_value_parameter = (__temp9 = (__temp8 = value, (__temp8 == NULL ? NULL : g_object_ref (__temp8))), (self->priv->_value_parameter == NULL ? NULL : (self->priv->_value_parameter = (g_object_unref (self->priv->_value_parameter), NULL))), __temp9);
 }
 
 
 static void vala_property_accessor_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec)
 {
-	ValaPropertyAccessor * self = VALA_PROPERTY_ACCESSOR (object);
+	ValaPropertyAccessor * self;
+	self = VALA_PROPERTY_ACCESSOR (object);
 	switch (property_id) {
+		case VALA_PROPERTY_ACCESSOR_PROP:
+		g_value_set_object (value, vala_property_accessor_get_prop (self));
+		break;
 		case VALA_PROPERTY_ACCESSOR_READABLE:
 		g_value_set_boolean (value, vala_property_accessor_get_readable (self));
 		break;
@@ -187,8 +218,12 @@ static void vala_property_accessor_get_property (GObject * object, guint propert
 
 static void vala_property_accessor_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec)
 {
-	ValaPropertyAccessor * self = VALA_PROPERTY_ACCESSOR (object);
+	ValaPropertyAccessor * self;
+	self = VALA_PROPERTY_ACCESSOR (object);
 	switch (property_id) {
+		case VALA_PROPERTY_ACCESSOR_PROP:
+		vala_property_accessor_set_prop (self, g_value_get_object (value));
+		break;
 		case VALA_PROPERTY_ACCESSOR_READABLE:
 		vala_property_accessor_set_readable (self, g_value_get_boolean (value));
 		break;
@@ -216,10 +251,12 @@ static void vala_property_accessor_class_init (ValaPropertyAccessorClass * klass
 	G_OBJECT_CLASS (klass)->set_property = vala_property_accessor_set_property;
 	G_OBJECT_CLASS (klass)->dispose = vala_property_accessor_dispose;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_property_accessor_real_accept;
+	VALA_CODE_NODE_CLASS (klass)->accept_children = vala_property_accessor_real_accept_children;
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_PROPERTY_ACCESSOR_PROP, g_param_spec_object ("prop", "foo", "bar", VALA_TYPE_PROPERTY, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_PROPERTY_ACCESSOR_READABLE, g_param_spec_boolean ("readable", "foo", "bar", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_PROPERTY_ACCESSOR_WRITABLE, g_param_spec_boolean ("writable", "foo", "bar", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_PROPERTY_ACCESSOR_CONSTRUCTION, g_param_spec_boolean ("construction", "foo", "bar", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_PROPERTY_ACCESSOR_BODY, g_param_spec_object ("body", "foo", "bar", VALA_TYPE_STATEMENT, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_PROPERTY_ACCESSOR_BODY, g_param_spec_object ("body", "foo", "bar", VALA_TYPE_BLOCK, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_PROPERTY_ACCESSOR_VALUE_PARAMETER, g_param_spec_object ("value-parameter", "foo", "bar", VALA_TYPE_FORMAL_PARAMETER, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
@@ -232,18 +269,19 @@ static void vala_property_accessor_init (ValaPropertyAccessor * self)
 
 static void vala_property_accessor_dispose (GObject * obj)
 {
-	ValaPropertyAccessor * self = VALA_PROPERTY_ACCESSOR (obj);
-	(self->priv->_body == NULL ? NULL : (self->priv->_body = (g_object_unref (self->priv->_body), NULL)));
-	(self->priv->_value_parameter == NULL ? NULL : (self->priv->_value_parameter = (g_object_unref (self->priv->_value_parameter), NULL)));
+	ValaPropertyAccessor * self;
 	ValaPropertyAccessorClass * klass;
 	GObjectClass * parent_class;
+	self = VALA_PROPERTY_ACCESSOR (obj);
+	(self->priv->_body == NULL ? NULL : (self->priv->_body = (g_object_unref (self->priv->_body), NULL)));
+	(self->priv->_value_parameter == NULL ? NULL : (self->priv->_value_parameter = (g_object_unref (self->priv->_value_parameter), NULL)));
 	klass = VALA_PROPERTY_ACCESSOR_CLASS (g_type_class_peek (VALA_TYPE_PROPERTY_ACCESSOR));
 	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
 	parent_class->dispose (obj);
 }
 
 
-GType vala_property_accessor_get_type ()
+GType vala_property_accessor_get_type (void)
 {
 	static GType vala_property_accessor_type_id = 0;
 	if (G_UNLIKELY (vala_property_accessor_type_id == 0)) {
