@@ -1,6 +1,6 @@
 /* valareturnstatement.vala
  *
- * Copyright (C) 2006  Jürg Billeter
+ * Copyright (C) 2006-2007  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -25,8 +25,8 @@
 
 #include <glib.h>
 #include <glib-object.h>
-#include <vala/valastatement.h>
 #include <vala/valacodenode.h>
+#include <vala/valastatement.h>
 
 G_BEGIN_DECLS
 
@@ -44,17 +44,17 @@ typedef struct _ValaReturnStatementPrivate ValaReturnStatementPrivate;
  * Represents a return statement in the source code.
  */
 struct _ValaReturnStatement {
-	ValaStatement parent;
+	ValaCodeNode parent;
 	ValaReturnStatementPrivate * priv;
 };
 struct _ValaReturnStatementClass {
-	ValaStatementClass parent;
+	ValaCodeNodeClass parent;
 };
 
 ValaReturnStatement* vala_return_statement_new (ValaExpression* result, ValaSourceReference* source);
 ValaExpression* vala_return_statement_get_return_expression (ValaReturnStatement* self);
 void vala_return_statement_set_return_expression (ValaReturnStatement* self, ValaExpression* value);
-GType vala_return_statement_get_type ();
+GType vala_return_statement_get_type (void);
 
 G_END_DECLS
 
