@@ -26,12 +26,12 @@
 
 #include <glib.h>
 #include <glib-object.h>
+#include <gee/collection.h>
 #include <stdlib.h>
 #include <string.h>
 #include <vala/valacodevisitor.h>
 #include <vala/valacodecontext.h>
 #include <vala/valasourcefile.h>
-#include <vala/valanamespace.h>
 #include <vala/valaclass.h>
 #include <vala/valainterface.h>
 #include <vala/valadatatype.h>
@@ -70,12 +70,12 @@
 #include <vala/valanullliteral.h>
 #include <vala/valaliteralexpression.h>
 #include <vala/valatypereference.h>
-#include <vala/valacodenode.h>
 #include <vala/valasymbol.h>
 #include <vala/valaparenthesizedexpression.h>
 #include <vala/valamemberaccess.h>
 #include <vala/valainvocationexpression.h>
 #include <vala/valaexpression.h>
+#include <vala/valacodenode.h>
 #include <vala/valaelementaccess.h>
 #include <vala/valabaseaccess.h>
 #include <vala/valapostfixexpression.h>
@@ -121,9 +121,10 @@ struct _ValaSemanticAnalyzerClass {
 ValaSemanticAnalyzer* vala_semantic_analyzer_new (gboolean manage_memory);
 void vala_semantic_analyzer_analyze (ValaSemanticAnalyzer* self, ValaCodeContext* context);
 ValaSymbol* vala_semantic_analyzer_symbol_lookup_inherited (ValaSymbol* sym, const char* name);
+ValaTypeReference* vala_semantic_analyzer_get_actual_type (ValaTypeReference* derived_instance_type, ValaSymbol* generic_member, ValaTypeReference* generic_type, ValaCodeNode* node_reference);
 gboolean vala_semantic_analyzer_get_memory_management (ValaSemanticAnalyzer* self);
 void vala_semantic_analyzer_set_memory_management (ValaSemanticAnalyzer* self, gboolean value);
-GType vala_semantic_analyzer_get_type ();
+GType vala_semantic_analyzer_get_type (void);
 
 G_END_DECLS
 
