@@ -1,6 +1,6 @@
 /* valasignal.vala
  *
- * Copyright (C) 2006  Jürg Billeter
+ * Copyright (C) 2006-2007  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -19,26 +19,27 @@
  * Author:
  * 	Jürg Billeter <j@bitron.ch>
  */
-#define VALA_FREE_CHECKED(o,f) ((o) == NULL ? NULL : ((o) = (f (o), NULL)))
-#define VALA_FREE_UNCHECKED(o,f) ((o) = (f (o), NULL))
 
 #include "valasignal.h"
+#include <gee/arraylist.h>
+#include <gee/list.h>
+#include <gee/readonlycollection.h>
 #include <vala/valatypereference.h>
 #include <vala/valacallback.h>
 #include <vala/valasourcereference.h>
+#include <vala/valasymbol.h>
 #include <vala/valasignal.h>
 #include <vala/valaformalparameter.h>
-#include <vala/valasymbol.h>
+#include <vala/valascope.h>
 #include <vala/valadatatype.h>
 #include <vala/valacodevisitor.h>
 #include <vala/valaattribute.h>
 
 struct _ValaSignalPrivate {
-	char* _name;
 	ValaTypeReference* _return_type;
 	ValaMemberAccessibility _access;
 	gboolean _has_emitter;
-	GList* parameters;
+	GeeList* parameters;
 	ValaCallback* generated_callback;
 	char* cname;
 	gboolean lock_used;
@@ -46,15 +47,15 @@ struct _ValaSignalPrivate {
 #define VALA_SIGNAL_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_SIGNAL, ValaSignalPrivate))
 enum  {
 	VALA_SIGNAL_DUMMY_PROPERTY,
-	VALA_SIGNAL_NAME,
 	VALA_SIGNAL_RETURN_TYPE,
 	VALA_SIGNAL_ACCESS,
-	VALA_SIGNAL_HAS_EMITTER,
+	VALA_SIGNAL_HAS_EMITTER
 };
-static GList* vala_signal_real_get_parameters (ValaInvokable* base);
+static GeeCollection* vala_signal_real_get_parameters (ValaInvokable* base);
 static ValaTypeReference* vala_signal_real_get_return_type (ValaInvokable* base);
 static gboolean vala_signal_real_is_invokable (ValaInvokable* base);
 static void vala_signal_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
+static void vala_signal_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static gboolean vala_signal_real_get_lock_used (ValaLockable* base);
 static void vala_signal_real_set_lock_used (ValaLockable* base, gboolean used);
 static gpointer vala_signal_parent_class = NULL;
@@ -71,17 +72,16 @@ static void vala_signal_dispose (GObject * obj);
  * @param source      reference to source code
  * @return            newly created signal
  */
-ValaSignal* vala_signal_new (const char* _name, ValaTypeReference* _return_type, ValaSourceReference* source)
+ValaSignal* vala_signal_new (const char* name, ValaTypeReference* return_type, ValaSourceReference* source_reference)
 {
-	g_return_val_if_fail (_name != NULL, NULL);
-	g_return_val_if_fail (VALA_IS_TYPE_REFERENCE (_return_type), NULL);
-	g_return_val_if_fail (source == NULL || VALA_IS_SOURCE_REFERENCE (source), NULL);
-	GParameter * __params = g_new0 (GParameter, 3);
-	GParameter * __params_it = __params;
-	(__params_it->name = "name", g_value_init (&__params_it->value, G_TYPE_STRING), g_value_set_string (&__params_it->value, _name), __params_it++);
-	(__params_it->name = "return-type", g_value_init (&__params_it->value, VALA_TYPE_TYPE_REFERENCE), g_value_set_object (&__params_it->value, _return_type), __params_it++);
-	(__params_it->name = "source-reference", g_value_init (&__params_it->value, VALA_TYPE_SOURCE_REFERENCE), g_value_set_object (&__params_it->value, source), __params_it++);
-	ValaSignal * self = g_object_newv (VALA_TYPE_SIGNAL, __params_it - __params, __params);
+	ValaSignal * self;
+	g_return_val_if_fail (name != NULL, NULL);
+	g_return_val_if_fail (VALA_IS_TYPE_REFERENCE (return_type), NULL);
+	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
+	self = g_object_newv (VALA_TYPE_SIGNAL, 0, NULL);
+	vala_symbol_set_name (VALA_SYMBOL (self), name);
+	vala_signal_set_return_type (self, return_type);
+	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source_reference);
 	return self;
 }
 
@@ -95,27 +95,31 @@ void vala_signal_add_parameter (ValaSignal* self, ValaFormalParameter* param)
 {
 	g_return_if_fail (VALA_IS_SIGNAL (self));
 	g_return_if_fail (VALA_IS_FORMAL_PARAMETER (param));
-	self->priv->parameters = g_list_append (self->priv->parameters, g_object_ref (param));
+	gee_collection_add (GEE_COLLECTION (self->priv->parameters), param);
+	vala_scope_add (vala_symbol_get_scope (((ValaSymbol*) self)), vala_symbol_get_name (((ValaSymbol*) param)), VALA_SYMBOL (param));
 }
 
 
-static GList* vala_signal_real_get_parameters (ValaInvokable* base)
+static GeeCollection* vala_signal_real_get_parameters (ValaInvokable* base)
 {
-	ValaSignal * self = VALA_SIGNAL (base);
-	return g_list_copy (self->priv->parameters);
+	ValaSignal * self;
+	self = ((ValaSignal*) base);
+	return GEE_COLLECTION (gee_read_only_collection_new (g_object_ref, g_object_unref, GEE_COLLECTION (self->priv->parameters)));
 }
 
 
 static ValaTypeReference* vala_signal_real_get_return_type (ValaInvokable* base)
 {
-	ValaSignal * self = VALA_SIGNAL (base);
+	ValaSignal * self;
+	self = ((ValaSignal*) base);
 	return g_object_ref (vala_signal_get_return_type (self));
 }
 
 
 static gboolean vala_signal_real_is_invokable (ValaInvokable* base)
 {
-	ValaSignal * self = VALA_SIGNAL (base);
+	ValaSignal * self;
+	self = ((ValaSignal*) base);
 	return TRUE;
 }
 
@@ -127,31 +131,39 @@ static gboolean vala_signal_real_is_invokable (ValaInvokable* base)
  */
 ValaCallback* vala_signal_get_callback (ValaSignal* self)
 {
+	ValaCallback* __temp4;
 	g_return_val_if_fail (VALA_IS_SIGNAL (self), NULL);
 	if (self->priv->generated_callback == NULL) {
-		ValaCallback* __temp3 = NULL;
+		ValaCallback* __temp3;
+		ValaTypeReference* sender_type;
+		ValaFormalParameter* sender_param;
+		__temp3 = NULL;
 		self->priv->generated_callback = (__temp3 = vala_callback_new (NULL, vala_signal_get_return_type (self), NULL), (self->priv->generated_callback == NULL ? NULL : (self->priv->generated_callback = (g_object_unref (self->priv->generated_callback), NULL))), __temp3);
-		(vala_callback_set_instance (self->priv->generated_callback, TRUE), vala_callback_get_instance (self->priv->generated_callback));
-		ValaTypeReference* sender_type = vala_type_reference_new ();
-		(vala_type_reference_set_data_type (sender_type, VALA_DATA_TYPE (vala_symbol_get_node (vala_symbol_get_parent_symbol (vala_code_node_get_symbol (VALA_CODE_NODE (self)))))), vala_type_reference_get_data_type (sender_type));
-		ValaFormalParameter* sender_param = vala_formal_parameter_new ("sender", sender_type, NULL);
+		vala_callback_set_instance (self->priv->generated_callback, TRUE);
+		sender_type = vala_type_reference_new ();
+		vala_type_reference_set_data_type (sender_type, VALA_DATA_TYPE (vala_symbol_get_parent_symbol (((ValaSymbol*) self))));
+		sender_param = vala_formal_parameter_new ("sender", sender_type, NULL);
 		vala_callback_add_parameter (self->priv->generated_callback, sender_param);
 		{
-			GList* __temp4 = NULL;
-			__temp4 = self->priv->parameters;
-			GList* param_it;
-			for (param_it = __temp4; param_it != NULL; param_it = param_it->next) {
-				ValaFormalParameter* param = param_it->data;
+			GeeList* param_collection;
+			GeeIterator* param_it;
+			param_collection = self->priv->parameters;
+			param_it = gee_iterable_iterator (GEE_ITERABLE (param_collection));
+			while (gee_iterator_next (param_it)) {
+				ValaFormalParameter* param;
+				param = gee_iterator_get (param_it);
 				{
 					vala_callback_add_parameter (self->priv->generated_callback, param);
+					(param = (g_object_unref (param), NULL));
 				}
 			}
+			(param_it == NULL ? NULL : (param_it = (g_object_unref (param_it), NULL)));
 		}
 		(sender_type == NULL ? NULL : (sender_type = (g_object_unref (sender_type), NULL)));
 		(sender_param == NULL ? NULL : (sender_param = (g_object_unref (sender_param), NULL)));
 	}
-	ValaCallback* __temp5 = NULL;
-	return (__temp5 = self->priv->generated_callback, (__temp5 == NULL ? NULL : g_object_ref (__temp5)));
+	__temp4 = NULL;
+	return (__temp4 = self->priv->generated_callback, (__temp4 == NULL ? NULL : g_object_ref (__temp4)));
 }
 
 
@@ -162,21 +174,27 @@ ValaCallback* vala_signal_get_callback (ValaSignal* self)
  */
 char* vala_signal_get_cname (ValaSignal* self)
 {
+	const char* __temp8;
 	g_return_val_if_fail (VALA_IS_SIGNAL (self), NULL);
 	if (self->priv->cname == NULL) {
-		char* __temp7 = NULL;
-		self->priv->cname = (__temp7 = g_strdup (vala_signal_get_name (self)), (self->priv->cname = (g_free (self->priv->cname), NULL)), __temp7);
+		char* __temp7;
+		const char* __temp6;
+		__temp7 = NULL;
+		__temp6 = NULL;
+		self->priv->cname = (__temp7 = (__temp6 = vala_symbol_get_name (((ValaSymbol*) self)), (__temp6 == NULL ? NULL : g_strdup (__temp6))), (self->priv->cname = (g_free (self->priv->cname), NULL)), __temp7);
 	}
-	const char* __temp8 = NULL;
+	__temp8 = NULL;
 	return (__temp8 = self->priv->cname, (__temp8 == NULL ? NULL : g_strdup (__temp8)));
 }
 
 
 void vala_signal_set_cname (ValaSignal* self, const char* cname)
 {
+	char* __temp11;
+	const char* __temp10;
 	g_return_if_fail (VALA_IS_SIGNAL (self));
-	char* __temp11 = NULL;
-	const char* __temp10 = NULL;
+	__temp11 = NULL;
+	__temp10 = NULL;
 	self->priv->cname = (__temp11 = (__temp10 = cname, (__temp10 == NULL ? NULL : g_strdup (__temp10))), (self->priv->cname = (g_free (self->priv->cname), NULL)), __temp11);
 }
 
@@ -188,23 +206,31 @@ void vala_signal_set_cname (ValaSignal* self, const char* cname)
  */
 ValaCCodeConstant* vala_signal_get_canonical_cconstant (ValaSignal* self)
 {
+	GString* str;
+	const char* __temp12;
+	char* i;
+	ValaCCodeConstant* __temp15;
 	g_return_val_if_fail (VALA_IS_SIGNAL (self), NULL);
-	GString* str = g_string_new ("\"");
-	char* i = g_strdup (vala_signal_get_name (self));
+	str = g_string_new ("\"");
+	__temp12 = NULL;
+	i = (__temp12 = vala_symbol_get_name (((ValaSymbol*) self)), (__temp12 == NULL ? NULL : g_strdup (__temp12)));
 	while (g_utf8_strlen (i, -1) > 0) {
-		gunichar c = g_utf8_get_char (i);
+		gunichar c;
+		char* __temp14;
+		const char* __temp13;
+		c = g_utf8_get_char (i);
 		if (c == '_') {
 			g_string_append_c (str, '-');
 		} else {
 			g_string_append_unichar (str, c);
 		}
-		char* __temp13 = NULL;
-		const char* __temp12 = NULL;
-		i = (__temp13 = (__temp12 = g_utf8_next_char (i), (__temp12 == NULL ? NULL : g_strdup (__temp12))), (i = (g_free (i), NULL)), __temp13);
+		__temp14 = NULL;
+		__temp13 = NULL;
+		i = (__temp14 = (__temp13 = g_utf8_next_char (i), (__temp13 == NULL ? NULL : g_strdup (__temp13))), (i = (g_free (i), NULL)), __temp14);
 	}
 	g_string_append_c (str, '"');
-	ValaCCodeConstant* __temp14 = NULL;
-	return (__temp14 = vala_ccode_constant_new (str->str), (str == NULL ? NULL : (str = (g_string_free (str, TRUE), NULL))), (i = (g_free (i), NULL)), __temp14);
+	__temp15 = NULL;
+	return (__temp15 = vala_ccode_constant_new (str->str), (str == NULL ? NULL : (str = (g_string_free (str, TRUE), NULL))), (i = (g_free (i), NULL)), __temp15);
 	(str == NULL ? NULL : (str = (g_string_free (str, TRUE), NULL)));
 	(i = (g_free (i), NULL));
 }
@@ -212,23 +238,35 @@ ValaCCodeConstant* vala_signal_get_canonical_cconstant (ValaSignal* self)
 
 static void vala_signal_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor)
 {
-	ValaSignal * self = VALA_SIGNAL (base);
+	ValaSignal * self;
+	self = ((ValaSignal*) base);
 	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	vala_code_visitor_visit_member (visitor, VALA_MEMBER (self));
-	vala_code_visitor_visit_begin_signal (visitor, self);
+	vala_code_visitor_visit_signal (visitor, self);
+}
+
+
+static void vala_signal_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor)
+{
+	ValaSignal * self;
+	self = ((ValaSignal*) base);
+	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	vala_code_node_accept (VALA_CODE_NODE (vala_signal_get_return_type (self)), visitor);
 	{
-		GList* __temp15 = NULL;
-		__temp15 = self->priv->parameters;
-		GList* param_it;
-		for (param_it = __temp15; param_it != NULL; param_it = param_it->next) {
-			ValaFormalParameter* param = param_it->data;
+		GeeList* param_collection;
+		GeeIterator* param_it;
+		param_collection = self->priv->parameters;
+		param_it = gee_iterable_iterator (GEE_ITERABLE (param_collection));
+		while (gee_iterator_next (param_it)) {
+			ValaFormalParameter* param;
+			param = gee_iterator_get (param_it);
 			{
 				vala_code_node_accept (VALA_CODE_NODE (param), visitor);
+				(param == NULL ? NULL : (param = (g_object_unref (param), NULL)));
 			}
 		}
+		(param_it == NULL ? NULL : (param_it = (g_object_unref (param_it), NULL)));
 	}
-	vala_code_visitor_visit_end_signal (visitor, self);
 }
 
 
@@ -239,15 +277,19 @@ void vala_signal_process_attributes (ValaSignal* self)
 {
 	g_return_if_fail (VALA_IS_SIGNAL (self));
 	{
-		GList* __temp16 = NULL;
-		__temp16 = VALA_CODE_NODE (self)->attributes;
+		GList* a_collection;
 		GList* a_it;
-		for (a_it = __temp16; a_it != NULL; a_it = a_it->next) {
-			ValaAttribute* a = a_it->data;
+		a_collection = ((ValaCodeNode*) self)->attributes;
+		for (a_it = a_collection; a_it != NULL; a_it = a_it->next) {
+			ValaAttribute* __temp16;
+			ValaAttribute* a;
+			__temp16 = NULL;
+			a = (__temp16 = a_it->data, (__temp16 == NULL ? NULL : g_object_ref (__temp16)));
 			{
 				if (g_utf8_collate (vala_attribute_get_name (a), "HasEmitter") == 0) {
-					(vala_signal_set_has_emitter (self, TRUE), vala_signal_get_has_emitter (self));
+					vala_signal_set_has_emitter (self, TRUE);
 				}
+				(a == NULL ? NULL : (a = (g_object_unref (a), NULL)));
 			}
 		}
 	}
@@ -256,33 +298,20 @@ void vala_signal_process_attributes (ValaSignal* self)
 
 static gboolean vala_signal_real_get_lock_used (ValaLockable* base)
 {
-	ValaSignal * self = VALA_SIGNAL (base);
+	ValaSignal * self;
+	self = ((ValaSignal*) base);
 	return self->priv->lock_used;
 }
 
 
 static void vala_signal_real_set_lock_used (ValaLockable* base, gboolean used)
 {
-	ValaSignal * self = VALA_SIGNAL (base);
+	ValaSignal * self;
+	self = ((ValaSignal*) base);
 	self->priv->lock_used = used;
 }
 
 
-char* vala_signal_get_name (ValaSignal* self)
-{
-	g_return_val_if_fail (VALA_IS_SIGNAL (self), NULL);
-	return self->priv->_name;
-}
-
-
-void vala_signal_set_name (ValaSignal* self, const char* value)
-{
-	g_return_if_fail (VALA_IS_SIGNAL (self));
-	char* __temp19 = NULL;
-	self->priv->_name = (__temp19 = g_strdup (value), (self->priv->_name = (g_free (self->priv->_name), NULL)), __temp19);
-}
-
-
 ValaTypeReference* vala_signal_get_return_type (ValaSignal* self)
 {
 	g_return_val_if_fail (VALA_IS_SIGNAL (self), NULL);
@@ -292,9 +321,10 @@ ValaTypeReference* vala_signal_get_return_type (ValaSignal* self)
 
 void vala_signal_set_return_type (ValaSignal* self, ValaTypeReference* value)
 {
+	ValaTypeReference* __temp19;
 	g_return_if_fail (VALA_IS_SIGNAL (self));
-	ValaTypeReference* __temp21 = NULL;
-	self->priv->_return_type = (__temp21 = g_object_ref (value), (self->priv->_return_type == NULL ? NULL : (self->priv->_return_type = (g_object_unref (self->priv->_return_type), NULL))), __temp21);
+	__temp19 = NULL;
+	self->priv->_return_type = (__temp19 = g_object_ref (value), (self->priv->_return_type == NULL ? NULL : (self->priv->_return_type = (g_object_unref (self->priv->_return_type), NULL))), __temp19);
 }
 
 
@@ -328,11 +358,9 @@ void vala_signal_set_has_emitter (ValaSignal* self, gboolean value)
 
 static void vala_signal_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec)
 {
-	ValaSignal * self = VALA_SIGNAL (object);
+	ValaSignal * self;
+	self = VALA_SIGNAL (object);
 	switch (property_id) {
-		case VALA_SIGNAL_NAME:
-		g_value_set_string (value, vala_signal_get_name (self));
-		break;
 		case VALA_SIGNAL_RETURN_TYPE:
 		g_value_set_object (value, vala_signal_get_return_type (self));
 		break;
@@ -348,11 +376,9 @@ static void vala_signal_get_property (GObject * object, guint property_id, GValu
 
 static void vala_signal_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec)
 {
-	ValaSignal * self = VALA_SIGNAL (object);
+	ValaSignal * self;
+	self = VALA_SIGNAL (object);
 	switch (property_id) {
-		case VALA_SIGNAL_NAME:
-		vala_signal_set_name (self, g_value_get_string (value));
-		break;
 		case VALA_SIGNAL_RETURN_TYPE:
 		vala_signal_set_return_type (self, g_value_get_object (value));
 		break;
@@ -374,8 +400,8 @@ static void vala_signal_class_init (ValaSignalClass * klass)
 	G_OBJECT_CLASS (klass)->set_property = vala_signal_set_property;
 	G_OBJECT_CLASS (klass)->dispose = vala_signal_dispose;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_signal_real_accept;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_SIGNAL_NAME, g_param_spec_string ("name", "foo", "bar", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_SIGNAL_RETURN_TYPE, g_param_spec_object ("return-type", "foo", "bar", VALA_TYPE_TYPE_REFERENCE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
+	VALA_CODE_NODE_CLASS (klass)->accept_children = vala_signal_real_accept_children;
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_SIGNAL_RETURN_TYPE, g_param_spec_object ("return-type", "foo", "bar", VALA_TYPE_TYPE_REFERENCE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_SIGNAL_ACCESS, g_param_spec_int ("access", "foo", "bar", G_MININT, G_MAXINT, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_SIGNAL_HAS_EMITTER, g_param_spec_boolean ("has-emitter", "foo", "bar", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
@@ -401,35 +427,36 @@ static void vala_signal_vala_lockable_interface_init (ValaLockableIface * iface)
 static void vala_signal_init (ValaSignal * self)
 {
 	self->priv = VALA_SIGNAL_GET_PRIVATE (self);
+	self->priv->parameters = GEE_LIST (gee_array_list_new (g_object_ref, g_object_unref, g_direct_equal));
 	self->priv->lock_used = FALSE;
 }
 
 
 static void vala_signal_dispose (GObject * obj)
 {
-	ValaSignal * self = VALA_SIGNAL (obj);
-	(self->priv->_name = (g_free (self->priv->_name), NULL));
-	(self->priv->_return_type == NULL ? NULL : (self->priv->_return_type = (g_object_unref (self->priv->_return_type), NULL)));
-	(self->priv->parameters == NULL ? NULL : (self->priv->parameters = (g_list_foreach (self->priv->parameters, (GFunc) g_object_unref, NULL), g_list_free (self->priv->parameters), NULL)));
-	(self->priv->generated_callback == NULL ? NULL : (self->priv->generated_callback = (g_object_unref (self->priv->generated_callback), NULL)));
-	(self->priv->cname = (g_free (self->priv->cname), NULL));
+	ValaSignal * self;
 	ValaSignalClass * klass;
 	GObjectClass * parent_class;
+	self = VALA_SIGNAL (obj);
+	(self->priv->_return_type == NULL ? NULL : (self->priv->_return_type = (g_object_unref (self->priv->_return_type), NULL)));
+	(self->priv->parameters == NULL ? NULL : (self->priv->parameters = (g_object_unref (self->priv->parameters), NULL)));
+	(self->priv->generated_callback == NULL ? NULL : (self->priv->generated_callback = (g_object_unref (self->priv->generated_callback), NULL)));
+	(self->priv->cname = (g_free (self->priv->cname), NULL));
 	klass = VALA_SIGNAL_CLASS (g_type_class_peek (VALA_TYPE_SIGNAL));
 	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
 	parent_class->dispose (obj);
 }
 
 
-GType vala_signal_get_type ()
+GType vala_signal_get_type (void)
 {
 	static GType vala_signal_type_id = 0;
 	if (G_UNLIKELY (vala_signal_type_id == 0)) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaSignalClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_signal_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaSignal), 0, (GInstanceInitFunc) vala_signal_init };
-		vala_signal_type_id = g_type_register_static (VALA_TYPE_MEMBER, "ValaSignal", &g_define_type_info, 0);
 		static const GInterfaceInfo vala_invokable_info = { (GInterfaceInitFunc) vala_signal_vala_invokable_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
-		g_type_add_interface_static (vala_signal_type_id, VALA_TYPE_INVOKABLE, &vala_invokable_info);
 		static const GInterfaceInfo vala_lockable_info = { (GInterfaceInitFunc) vala_signal_vala_lockable_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
+		vala_signal_type_id = g_type_register_static (VALA_TYPE_MEMBER, "ValaSignal", &g_define_type_info, 0);
+		g_type_add_interface_static (vala_signal_type_id, VALA_TYPE_INVOKABLE, &vala_invokable_info);
 		g_type_add_interface_static (vala_signal_type_id, VALA_TYPE_LOCKABLE, &vala_lockable_info);
 	}
 	return vala_signal_type_id;
