@@ -19,8 +19,6 @@
  * Author:
  * 	Jürg Billeter <j@bitron.ch>
  */
-#define VALA_FREE_CHECKED(o,f) ((o) == NULL ? NULL : ((o) = (f (o), NULL)))
-#define VALA_FREE_UNCHECKED(o,f) ((o) = (f (o), NULL))
 
 #include "valasizeofexpression.h"
 #include <vala/valatypereference.h>
@@ -55,11 +53,16 @@ ValaSizeofExpression* vala_sizeof_expression_new (ValaTypeReference* type, ValaS
 	ValaSizeofExpression * self;
 	g_return_val_if_fail (VALA_IS_TYPE_REFERENCE (type), NULL);
 	g_return_val_if_fail (source == NULL || VALA_IS_SOURCE_REFERENCE (source), NULL);
-	__params = g_new0 (GParameter, 2);
+	__params = g_new0 (GParameter, 1);
 	__params_it = __params;
 	(__params_it->name = "type-reference", g_value_init (&__params_it->value, VALA_TYPE_TYPE_REFERENCE), g_value_set_object (&__params_it->value, type), __params_it++);
-	(__params_it->name = "source-reference", g_value_init (&__params_it->value, VALA_TYPE_SOURCE_REFERENCE), g_value_set_object (&__params_it->value, source), __params_it++);
 	self = g_object_newv (VALA_TYPE_SIZEOF_EXPRESSION, __params_it - __params, __params);
+	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source);
+	while (__params_it > __params) {
+		--__params_it;
+		g_value_unset (&__params_it->value);
+	}
+	g_free (__params);
 	return self;
 }
 
@@ -67,7 +70,7 @@ ValaSizeofExpression* vala_sizeof_expression_new (ValaTypeReference* type, ValaS
 static void vala_sizeof_expression_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor)
 {
 	ValaSizeofExpression * self;
-	self = VALA_SIZEOF_EXPRESSION (base);
+	self = ((ValaSizeofExpression*) base);
 	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	vala_code_node_accept (VALA_CODE_NODE (vala_sizeof_expression_get_type_reference (self)), visitor);
 	vala_code_visitor_visit_sizeof_expression (visitor, self);
@@ -145,7 +148,7 @@ static void vala_sizeof_expression_dispose (GObject * obj)
 }
 
 
-GType vala_sizeof_expression_get_type ()
+GType vala_sizeof_expression_get_type (void)
 {
 	static GType vala_sizeof_expression_type_id = 0;
 	if (G_UNLIKELY (vala_sizeof_expression_type_id == 0)) {
