@@ -19,13 +19,13 @@
  * Author:
  * 	Jürg Billeter <j@bitron.ch>
  */
-#define VALA_FREE_CHECKED(o,f) ((o) == NULL ? NULL : ((o) = (f (o), NULL)))
-#define VALA_FREE_UNCHECKED(o,f) ((o) = (f (o), NULL))
 
 #include "valasourcefile.h"
+#include <gee/arraylist.h>
+#include <gee/list.h>
+#include <gee/readonlycollection.h>
 #include <vala/valasourcefilecycle.h>
 #include <vala/valacodecontext.h>
-#include <vala/valanamespace.h>
 #include <vala/valanamespacereference.h>
 #include <vala/valacodevisitor.h>
 #include <vala/valasymbol.h>
@@ -46,18 +46,17 @@ struct _ValaSourceFilePrivate {
 	gboolean _is_cycle_head;
 	gint _mark;
 	ValaCodeContext* _context;
-	GList* using_directives;
-	ValaNamespace* global_namespace;
-	GList* namespaces;
+	GeeList* using_directives;
+	GeeList* nodes;
 	char* cheader_filename;
 	char* csource_filename;
 	char* cinclude_filename;
-	GList* header_external_includes;
-	GList* header_internal_includes;
-	GList* source_external_includes;
-	GList* source_internal_includes;
-	GList* header_internal_full_dependencies;
-	GList* header_internal_dependencies;
+	GeeList* header_external_includes;
+	GeeList* header_internal_includes;
+	GeeList* source_external_includes;
+	GeeList* source_internal_includes;
+	GeeList* header_internal_full_dependencies;
+	GeeList* header_internal_dependencies;
 };
 #define VALA_SOURCE_FILE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_SOURCE_FILE, ValaSourceFilePrivate))
 enum  {
@@ -70,7 +69,6 @@ enum  {
 	VALA_SOURCE_FILE_MARK,
 	VALA_SOURCE_FILE_CONTEXT
 };
-static GObject * vala_source_file_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
 static gpointer vala_source_file_parent_class = NULL;
 static void vala_source_file_dispose (GObject * obj);
 
@@ -82,19 +80,15 @@ static void vala_source_file_dispose (GObject * obj);
  * @param pkg      true if this is a VAPI package file
  * @return         newly created source file
  */
-ValaSourceFile* vala_source_file_new (ValaCodeContext* _context, const char* _filename, gboolean _pkg)
+ValaSourceFile* vala_source_file_new (ValaCodeContext* context, const char* filename, gboolean pkg)
 {
-	GParameter * __params;
-	GParameter * __params_it;
 	ValaSourceFile * self;
-	g_return_val_if_fail (VALA_IS_CODE_CONTEXT (_context), NULL);
-	g_return_val_if_fail (_filename != NULL, NULL);
-	__params = g_new0 (GParameter, 3);
-	__params_it = __params;
-	(__params_it->name = "context", g_value_init (&__params_it->value, VALA_TYPE_CODE_CONTEXT), g_value_set_object (&__params_it->value, _context), __params_it++);
-	(__params_it->name = "filename", g_value_init (&__params_it->value, G_TYPE_STRING), g_value_set_string (&__params_it->value, _filename), __params_it++);
-	(__params_it->name = "pkg", g_value_init (&__params_it->value, G_TYPE_BOOLEAN), g_value_set_boolean (&__params_it->value, _pkg), __params_it++);
-	self = g_object_newv (VALA_TYPE_SOURCE_FILE, __params_it - __params, __params);
+	g_return_val_if_fail (VALA_IS_CODE_CONTEXT (context), NULL);
+	g_return_val_if_fail (filename != NULL, NULL);
+	self = g_object_newv (VALA_TYPE_SOURCE_FILE, 0, NULL);
+	vala_source_file_set_context (self, context);
+	vala_source_file_set_filename (self, filename);
+	vala_source_file_set_pkg (self, pkg);
 	return self;
 }
 
@@ -108,7 +102,7 @@ void vala_source_file_add_using_directive (ValaSourceFile* self, ValaNamespaceRe
 {
 	g_return_if_fail (VALA_IS_SOURCE_FILE (self));
 	g_return_if_fail (VALA_IS_NAMESPACE_REFERENCE (ns));
-	self->priv->using_directives = g_list_append (self->priv->using_directives, g_object_ref (ns));
+	gee_collection_add (GEE_COLLECTION (self->priv->using_directives), ns);
 }
 
 
@@ -117,49 +111,35 @@ void vala_source_file_add_using_directive (ValaSourceFile* self, ValaNamespaceRe
  *
  * @return using directive list
  */
-GList* vala_source_file_get_using_directives (ValaSourceFile* self)
+GeeCollection* vala_source_file_get_using_directives (ValaSourceFile* self)
 {
 	g_return_val_if_fail (VALA_IS_SOURCE_FILE (self), NULL);
-	return g_list_copy (self->priv->using_directives);
+	return GEE_COLLECTION (gee_read_only_collection_new (g_object_ref, g_object_unref, GEE_COLLECTION (self->priv->using_directives)));
 }
 
 
 /**
- * Adds the specified namespace to this source file.
+ * Adds the specified code node to this source file.
  *
- * @param ns a namespace
+ * @param node a code node
  */
-void vala_source_file_add_namespace (ValaSourceFile* self, ValaNamespace* ns)
+void vala_source_file_add_node (ValaSourceFile* self, ValaCodeNode* node)
 {
 	g_return_if_fail (VALA_IS_SOURCE_FILE (self));
-	g_return_if_fail (VALA_IS_NAMESPACE (ns));
-	self->priv->namespaces = g_list_append (self->priv->namespaces, g_object_ref (ns));
+	g_return_if_fail (VALA_IS_CODE_NODE (node));
+	gee_collection_add (GEE_COLLECTION (self->priv->nodes), node);
 }
 
 
 /**
- * Returns the implicitly declared root namespace of this source file.
+ * Returns a copy of the list of code nodes.
  *
- * @return root namespace
+ * @return code node list
  */
-ValaNamespace* vala_source_file_get_global_namespace (ValaSourceFile* self)
-{
-	ValaNamespace* __temp1;
-	g_return_val_if_fail (VALA_IS_SOURCE_FILE (self), NULL);
-	__temp1 = NULL;
-	return (__temp1 = self->priv->global_namespace, (__temp1 == NULL ? NULL : g_object_ref (__temp1)));
-}
-
-
-/**
- * Returns a copy of the list of namespaces.
- *
- * @return namespace list
- */
-GList* vala_source_file_get_namespaces (ValaSourceFile* self)
+GeeCollection* vala_source_file_get_nodes (ValaSourceFile* self)
 {
 	g_return_val_if_fail (VALA_IS_SOURCE_FILE (self), NULL);
-	return g_list_copy (self->priv->namespaces);
+	return GEE_COLLECTION (gee_read_only_collection_new (g_object_ref, g_object_unref, GEE_COLLECTION (self->priv->nodes)));
 }
 
 
@@ -176,31 +156,34 @@ void vala_source_file_accept_children (ValaSourceFile* self, ValaCodeVisitor* vi
 	g_return_if_fail (VALA_IS_SOURCE_FILE (self));
 	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	{
-		GList* __temp4;
-		GList* ns_ref_it;
-		__temp4 = NULL;
-		__temp4 = self->priv->using_directives;
-		for (ns_ref_it = __temp4; ns_ref_it != NULL; ns_ref_it = ns_ref_it->next) {
+		GeeList* ns_ref_collection;
+		GeeIterator* ns_ref_it;
+		ns_ref_collection = self->priv->using_directives;
+		ns_ref_it = gee_iterable_iterator (GEE_ITERABLE (ns_ref_collection));
+		while (gee_iterator_next (ns_ref_it)) {
 			ValaNamespaceReference* ns_ref;
-			ns_ref = ns_ref_it->data;
+			ns_ref = gee_iterator_get (ns_ref_it);
 			{
 				vala_code_node_accept (VALA_CODE_NODE (ns_ref), visitor);
+				(ns_ref == NULL ? NULL : (ns_ref = (g_object_unref (ns_ref), NULL)));
 			}
 		}
+		(ns_ref_it == NULL ? NULL : (ns_ref_it = (g_object_unref (ns_ref_it), NULL)));
 	}
-	vala_code_node_accept (VALA_CODE_NODE (self->priv->global_namespace), visitor);
 	{
-		GList* __temp5;
-		GList* ns_it;
-		__temp5 = NULL;
-		__temp5 = self->priv->namespaces;
-		for (ns_it = __temp5; ns_it != NULL; ns_it = ns_it->next) {
-			ValaNamespace* ns;
-			ns = ns_it->data;
+		GeeList* node_collection;
+		GeeIterator* node_it;
+		node_collection = self->priv->nodes;
+		node_it = gee_iterable_iterator (GEE_ITERABLE (node_collection));
+		while (gee_iterator_next (node_it)) {
+			ValaCodeNode* node;
+			node = gee_iterator_get (node_it);
 			{
-				vala_code_node_accept (VALA_CODE_NODE (ns), visitor);
+				vala_code_node_accept (node, visitor);
+				(node == NULL ? NULL : (node = (g_object_unref (node), NULL)));
 			}
 		}
+		(node_it == NULL ? NULL : (node_it = (g_object_unref (node_it), NULL)));
 	}
 }
 
@@ -212,18 +195,18 @@ void vala_source_file_accept_children (ValaSourceFile* self, ValaCodeVisitor* vi
  */
 char* vala_source_file_get_cheader_filename (ValaSourceFile* self)
 {
-	const char* __temp7;
+	const char* __temp3;
 	g_return_val_if_fail (VALA_IS_SOURCE_FILE (self), NULL);
 	if (self->priv->cheader_filename == NULL) {
 		char* basename;
-		char* __temp6;
+		char* __temp2;
 		basename = g_strndup (vala_source_file_get_filename (self), ((guint) (g_utf8_strlen (vala_source_file_get_filename (self), -1) - g_utf8_strlen (".vala", -1))));
-		__temp6 = NULL;
-		self->priv->cheader_filename = (__temp6 = g_strdup_printf ("%s.h", basename), (self->priv->cheader_filename = (g_free (self->priv->cheader_filename), NULL)), __temp6);
+		__temp2 = NULL;
+		self->priv->cheader_filename = (__temp2 = g_strdup_printf ("%s.h", basename), (self->priv->cheader_filename = (g_free (self->priv->cheader_filename), NULL)), __temp2);
 		(basename = (g_free (basename), NULL));
 	}
-	__temp7 = NULL;
-	return (__temp7 = self->priv->cheader_filename, (__temp7 == NULL ? NULL : g_strdup (__temp7)));
+	__temp3 = NULL;
+	return (__temp3 = self->priv->cheader_filename, (__temp3 == NULL ? NULL : g_strdup (__temp3)));
 }
 
 
@@ -234,18 +217,18 @@ char* vala_source_file_get_cheader_filename (ValaSourceFile* self)
  */
 char* vala_source_file_get_csource_filename (ValaSourceFile* self)
 {
-	const char* __temp10;
+	const char* __temp6;
 	g_return_val_if_fail (VALA_IS_SOURCE_FILE (self), NULL);
 	if (self->priv->csource_filename == NULL) {
 		char* basename;
-		char* __temp9;
+		char* __temp5;
 		basename = g_strndup (vala_source_file_get_filename (self), ((guint) (g_utf8_strlen (vala_source_file_get_filename (self), -1) - g_utf8_strlen (".vala", -1))));
-		__temp9 = NULL;
-		self->priv->csource_filename = (__temp9 = g_strdup_printf ("%s.c", basename), (self->priv->csource_filename = (g_free (self->priv->csource_filename), NULL)), __temp9);
+		__temp5 = NULL;
+		self->priv->csource_filename = (__temp5 = g_strdup_printf ("%s.c", basename), (self->priv->csource_filename = (g_free (self->priv->csource_filename), NULL)), __temp5);
 		(basename = (g_free (basename), NULL));
 	}
-	__temp10 = NULL;
-	return (__temp10 = self->priv->csource_filename, (__temp10 == NULL ? NULL : g_strdup (__temp10)));
+	__temp6 = NULL;
+	return (__temp6 = self->priv->csource_filename, (__temp6 == NULL ? NULL : g_strdup (__temp6)));
 }
 
 
@@ -257,24 +240,24 @@ char* vala_source_file_get_csource_filename (ValaSourceFile* self)
  */
 char* vala_source_file_get_cinclude_filename (ValaSourceFile* self)
 {
-	const char* __temp14;
+	const char* __temp10;
 	g_return_val_if_fail (VALA_IS_SOURCE_FILE (self), NULL);
 	if (self->priv->cinclude_filename == NULL) {
 		char* basename;
 		basename = g_strndup (vala_source_file_get_filename (self), ((guint) (g_utf8_strlen (vala_source_file_get_filename (self), -1) - g_utf8_strlen (".vala", -1))));
 		if (vala_code_context_get_library (vala_source_file_get_context (self)) != NULL) {
-			char* __temp12;
-			__temp12 = NULL;
-			self->priv->cinclude_filename = (__temp12 = g_strdup_printf ("%s/%s.h", vala_code_context_get_library (vala_source_file_get_context (self)), basename), (self->priv->cinclude_filename = (g_free (self->priv->cinclude_filename), NULL)), __temp12);
+			char* __temp8;
+			__temp8 = NULL;
+			self->priv->cinclude_filename = (__temp8 = g_strdup_printf ("%s/%s.h", vala_code_context_get_library (vala_source_file_get_context (self)), basename), (self->priv->cinclude_filename = (g_free (self->priv->cinclude_filename), NULL)), __temp8);
 		} else {
-			char* __temp13;
-			__temp13 = NULL;
-			self->priv->cinclude_filename = (__temp13 = g_strdup_printf ("%s.h", basename), (self->priv->cinclude_filename = (g_free (self->priv->cinclude_filename), NULL)), __temp13);
+			char* __temp9;
+			__temp9 = NULL;
+			self->priv->cinclude_filename = (__temp9 = g_strdup_printf ("%s.h", basename), (self->priv->cinclude_filename = (g_free (self->priv->cinclude_filename), NULL)), __temp9);
 		}
 		(basename = (g_free (basename), NULL));
 	}
-	__temp14 = NULL;
-	return (__temp14 = self->priv->cinclude_filename, (__temp14 == NULL ? NULL : g_strdup (__temp14)));
+	__temp10 = NULL;
+	return (__temp10 = self->priv->cinclude_filename, (__temp10 == NULL ? NULL : g_strdup (__temp10)));
 }
 
 
@@ -287,106 +270,121 @@ char* vala_source_file_get_cinclude_filename (ValaSourceFile* self)
  */
 void vala_source_file_add_symbol_dependency (ValaSourceFile* self, ValaSymbol* sym, ValaSourceFileDependencyType dep_type)
 {
-	ValaDataType* t;
+	ValaSymbol* s;
 	g_return_if_fail (VALA_IS_SOURCE_FILE (self));
 	g_return_if_fail (VALA_IS_SYMBOL (sym));
-	t = NULL;
-	if (VALA_IS_DATA_TYPE (vala_symbol_get_node (sym))) {
-		ValaDataType* __temp17;
-		ValaDataType* __temp16;
-		__temp17 = NULL;
-		__temp16 = NULL;
-		t = (__temp17 = (__temp16 = VALA_DATA_TYPE (vala_symbol_get_node (sym)), (__temp16 == NULL ? NULL : g_object_ref (__temp16))), (t == NULL ? NULL : (t = (g_object_unref (t), NULL))), __temp17);
+	if (vala_source_file_get_pkg (self)) {
+		return;
+	}
+	s = NULL;
+	if (VALA_IS_DATA_TYPE (sym) || VALA_IS_METHOD (sym) || VALA_IS_FIELD (sym) || VALA_IS_PROPERTY (sym) || VALA_IS_CONSTANT (sym)) {
+		ValaSymbol* __temp12;
+		__temp12 = NULL;
+		s = (__temp12 = g_object_ref (sym), (s == NULL ? NULL : (s = (g_object_unref (s), NULL))), __temp12);
 	} else {
-		if (VALA_IS_METHOD (vala_symbol_get_node (sym)) || VALA_IS_FIELD (vala_symbol_get_node (sym))) {
-			if (VALA_IS_DATA_TYPE (vala_symbol_get_node (vala_symbol_get_parent_symbol (sym)))) {
-				ValaDataType* __temp19;
-				ValaDataType* __temp18;
-				__temp19 = NULL;
-				__temp18 = NULL;
-				t = (__temp19 = (__temp18 = VALA_DATA_TYPE (vala_symbol_get_node (vala_symbol_get_parent_symbol (sym))), (__temp18 == NULL ? NULL : g_object_ref (__temp18))), (t == NULL ? NULL : (t = (g_object_unref (t), NULL))), __temp19);
-			} else {
-				(t == NULL ? NULL : (t = (g_object_unref (t), NULL)));
+		if (VALA_IS_FORMAL_PARAMETER (sym)) {
+			ValaFormalParameter* __temp13;
+			ValaFormalParameter* fp;
+			ValaSymbol* __temp15;
+			ValaDataType* __temp14;
+			__temp13 = NULL;
+			fp = (__temp13 = VALA_FORMAL_PARAMETER (sym), (__temp13 == NULL ? NULL : g_object_ref (__temp13)));
+			__temp15 = NULL;
+			__temp14 = NULL;
+			s = (__temp15 = VALA_SYMBOL ((__temp14 = vala_type_reference_get_data_type (vala_formal_parameter_get_type_reference (fp)), (__temp14 == NULL ? NULL : g_object_ref (__temp14)))), (s == NULL ? NULL : (s = (g_object_unref (s), NULL))), __temp15);
+			if (s == NULL) {
+				(fp == NULL ? NULL : (fp = (g_object_unref (fp), NULL)));
+				(s == NULL ? NULL : (s = (g_object_unref (s), NULL)));
 				return;
 			}
+			(fp == NULL ? NULL : (fp = (g_object_unref (fp), NULL)));
 		} else {
-			if (VALA_IS_PROPERTY (vala_symbol_get_node (sym))) {
-				ValaDataType* __temp21;
-				ValaDataType* __temp20;
-				__temp21 = NULL;
-				__temp20 = NULL;
-				t = (__temp21 = (__temp20 = VALA_DATA_TYPE (vala_symbol_get_node (vala_symbol_get_parent_symbol (sym))), (__temp20 == NULL ? NULL : g_object_ref (__temp20))), (t == NULL ? NULL : (t = (g_object_unref (t), NULL))), __temp21);
-			} else {
-				if (VALA_IS_CONSTANT (vala_symbol_get_node (sym))) {
-					if (VALA_IS_DATA_TYPE (vala_symbol_get_node (vala_symbol_get_parent_symbol (sym)))) {
-						ValaDataType* __temp23;
-						ValaDataType* __temp22;
-						__temp23 = NULL;
-						__temp22 = NULL;
-						t = (__temp23 = (__temp22 = VALA_DATA_TYPE (vala_symbol_get_node (vala_symbol_get_parent_symbol (sym))), (__temp22 == NULL ? NULL : g_object_ref (__temp22))), (t == NULL ? NULL : (t = (g_object_unref (t), NULL))), __temp23);
-					} else {
-						if (VALA_IS_NAMESPACE (vala_symbol_get_node (vala_symbol_get_parent_symbol (sym)))) {
-							ValaNamespace* __temp24;
-							ValaNamespace* ns;
-							__temp24 = NULL;
-							ns = (__temp24 = VALA_NAMESPACE (vala_symbol_get_node (vala_symbol_get_parent_symbol (sym))), (__temp24 == NULL ? NULL : g_object_ref (__temp24)));
-							self->priv->source_internal_includes = g_list_concat (self->priv->source_internal_includes, vala_namespace_get_cheader_filenames (ns));
-							(ns == NULL ? NULL : (ns = (g_object_unref (ns), NULL)));
-							(t == NULL ? NULL : (t = (g_object_unref (t), NULL)));
-							return;
-							(ns == NULL ? NULL : (ns = (g_object_unref (ns), NULL)));
-						} else {
-							(t == NULL ? NULL : (t = (g_object_unref (t), NULL)));
-							return;
-						}
-					}
-				} else {
-					if (VALA_IS_FORMAL_PARAMETER (vala_symbol_get_node (sym))) {
-						ValaFormalParameter* __temp25;
-						ValaFormalParameter* fp;
-						ValaDataType* __temp27;
-						ValaDataType* __temp26;
-						__temp25 = NULL;
-						fp = (__temp25 = VALA_FORMAL_PARAMETER (vala_symbol_get_node (sym)), (__temp25 == NULL ? NULL : g_object_ref (__temp25)));
-						__temp27 = NULL;
-						__temp26 = NULL;
-						t = (__temp27 = (__temp26 = vala_type_reference_get_data_type (vala_formal_parameter_get_type_reference (fp)), (__temp26 == NULL ? NULL : g_object_ref (__temp26))), (t == NULL ? NULL : (t = (g_object_unref (t), NULL))), __temp27);
-						if (t == NULL) {
-							(fp == NULL ? NULL : (fp = (g_object_unref (fp), NULL)));
-							(t == NULL ? NULL : (t = (g_object_unref (t), NULL)));
-							return;
-						}
-						(fp == NULL ? NULL : (fp = (g_object_unref (fp), NULL)));
-					} else {
-						(t == NULL ? NULL : (t = (g_object_unref (t), NULL)));
-						return;
-					}
-				}
-			}
+			(s == NULL ? NULL : (s = (g_object_unref (s), NULL)));
+			return;
 		}
 	}
 	/* generic type parameter */
 	if (dep_type == VALA_SOURCE_FILE_DEPENDENCY_TYPE_SOURCE) {
-		if (vala_source_file_get_pkg (vala_source_reference_get_file (vala_code_node_get_source_reference (VALA_CODE_NODE (t))))) {
-			self->priv->source_external_includes = g_list_concat (self->priv->source_external_includes, vala_data_type_get_cheader_filenames (t));
+		if (vala_source_file_get_pkg (vala_source_reference_get_file (vala_code_node_get_source_reference (((ValaCodeNode*) s))))) {
+			{
+				GeeCollection* fn_collection;
+				GeeIterator* fn_it;
+				fn_collection = vala_symbol_get_cheader_filenames (s);
+				fn_it = gee_iterable_iterator (GEE_ITERABLE (fn_collection));
+				while (gee_iterator_next (fn_it)) {
+					char* fn;
+					fn = gee_iterator_get (fn_it);
+					{
+						gee_collection_add (GEE_COLLECTION (self->priv->source_external_includes), fn);
+						(fn = (g_free (fn), NULL));
+					}
+				}
+				(fn_collection == NULL ? NULL : (fn_collection = (g_object_unref (fn_collection), NULL)));
+				(fn_it == NULL ? NULL : (fn_it = (g_object_unref (fn_it), NULL)));
+			}
 		} else {
-			self->priv->source_internal_includes = g_list_concat (self->priv->source_internal_includes, vala_data_type_get_cheader_filenames (t));
+			{
+				GeeCollection* fn_collection;
+				GeeIterator* fn_it;
+				fn_collection = vala_symbol_get_cheader_filenames (s);
+				fn_it = gee_iterable_iterator (GEE_ITERABLE (fn_collection));
+				while (gee_iterator_next (fn_it)) {
+					char* fn;
+					fn = gee_iterator_get (fn_it);
+					{
+						gee_collection_add (GEE_COLLECTION (self->priv->source_internal_includes), fn);
+						(fn = (g_free (fn), NULL));
+					}
+				}
+				(fn_collection == NULL ? NULL : (fn_collection = (g_object_unref (fn_collection), NULL)));
+				(fn_it == NULL ? NULL : (fn_it = (g_object_unref (fn_it), NULL)));
+			}
 		}
-		(t == NULL ? NULL : (t = (g_object_unref (t), NULL)));
+		(s == NULL ? NULL : (s = (g_object_unref (s), NULL)));
 		return;
 	}
-	if (vala_source_file_get_pkg (vala_source_reference_get_file (vala_code_node_get_source_reference (VALA_CODE_NODE (t))))) {
-		/* external package */
-		self->priv->header_external_includes = g_list_concat (self->priv->header_external_includes, vala_data_type_get_cheader_filenames (t));
-		(t == NULL ? NULL : (t = (g_object_unref (t), NULL)));
+	if (vala_source_file_get_pkg (vala_source_reference_get_file (vala_code_node_get_source_reference (((ValaCodeNode*) s))))) {
+		{
+			GeeCollection* fn_collection;
+			GeeIterator* fn_it;
+			fn_collection = vala_symbol_get_cheader_filenames (s);
+			fn_it = gee_iterable_iterator (GEE_ITERABLE (fn_collection));
+			while (gee_iterator_next (fn_it)) {
+				char* fn;
+				fn = gee_iterator_get (fn_it);
+				{
+					/* external package */
+					gee_collection_add (GEE_COLLECTION (self->priv->header_external_includes), fn);
+					(fn = (g_free (fn), NULL));
+				}
+			}
+			(fn_collection == NULL ? NULL : (fn_collection = (g_object_unref (fn_collection), NULL)));
+			(fn_it == NULL ? NULL : (fn_it = (g_object_unref (fn_it), NULL)));
+		}
+		(s == NULL ? NULL : (s = (g_object_unref (s), NULL)));
 		return;
 	}
-	if (dep_type == VALA_SOURCE_FILE_DEPENDENCY_TYPE_HEADER_FULL || !vala_data_type_is_reference_type (t)) {
-		self->priv->header_internal_includes = g_list_concat (self->priv->header_internal_includes, vala_data_type_get_cheader_filenames (t));
-		self->priv->header_internal_full_dependencies = g_list_append (self->priv->header_internal_full_dependencies, vala_source_reference_get_file (vala_code_node_get_source_reference (VALA_CODE_NODE (t))));
+	if (dep_type == VALA_SOURCE_FILE_DEPENDENCY_TYPE_HEADER_FULL || (VALA_IS_DATA_TYPE (s) && !vala_data_type_is_reference_type ((VALA_DATA_TYPE (s))))) {
+		{
+			GeeCollection* fn_collection;
+			GeeIterator* fn_it;
+			fn_collection = vala_symbol_get_cheader_filenames (s);
+			fn_it = gee_iterable_iterator (GEE_ITERABLE (fn_collection));
+			while (gee_iterator_next (fn_it)) {
+				char* fn;
+				fn = gee_iterator_get (fn_it);
+				{
+					gee_collection_add (GEE_COLLECTION (self->priv->header_internal_includes), fn);
+					(fn = (g_free (fn), NULL));
+				}
+			}
+			(fn_collection == NULL ? NULL : (fn_collection = (g_object_unref (fn_collection), NULL)));
+			(fn_it == NULL ? NULL : (fn_it = (g_object_unref (fn_it), NULL)));
+		}
+		gee_collection_add (GEE_COLLECTION (self->priv->header_internal_full_dependencies), vala_source_reference_get_file (vala_code_node_get_source_reference (((ValaCodeNode*) s))));
 	}
-	self->priv->header_internal_dependencies = g_list_append (self->priv->header_internal_dependencies, vala_source_reference_get_file (vala_code_node_get_source_reference (VALA_CODE_NODE (t))));
-	(t == NULL ? NULL : (t = (g_object_unref (t), NULL)));
+	gee_collection_add (GEE_COLLECTION (self->priv->header_internal_dependencies), vala_source_reference_get_file (vala_code_node_get_source_reference (((ValaCodeNode*) s))));
+	(s == NULL ? NULL : (s = (g_object_unref (s), NULL)));
 }
 
 
@@ -396,10 +394,10 @@ void vala_source_file_add_symbol_dependency (ValaSourceFile* self, ValaSymbol* s
  *
  * @return external include list for C header file
  */
-GList* vala_source_file_get_header_external_includes (ValaSourceFile* self)
+GeeCollection* vala_source_file_get_header_external_includes (ValaSourceFile* self)
 {
 	g_return_val_if_fail (VALA_IS_SOURCE_FILE (self), NULL);
-	return self->priv->header_external_includes;
+	return GEE_COLLECTION (gee_read_only_collection_new (g_strdup, g_free, GEE_COLLECTION (self->priv->header_external_includes)));
 }
 
 
@@ -411,9 +409,15 @@ GList* vala_source_file_get_header_external_includes (ValaSourceFile* self)
  */
 void vala_source_file_add_header_internal_include (ValaSourceFile* self, const char* include)
 {
+	char* __temp17;
+	gboolean __temp18;
 	g_return_if_fail (VALA_IS_SOURCE_FILE (self));
 	g_return_if_fail (include != NULL);
-	self->priv->header_internal_includes = g_list_append (self->priv->header_internal_includes, g_strdup (include));
+	/* skip includes to self */
+	__temp17 = NULL;
+	if ((__temp18 = g_utf8_collate (include, (__temp17 = vala_source_file_get_cinclude_filename (self))) != 0, (__temp17 = (g_free (__temp17), NULL)), __temp18)) {
+		gee_collection_add (GEE_COLLECTION (self->priv->header_internal_includes), include);
+	}
 }
 
 
@@ -423,10 +427,10 @@ void vala_source_file_add_header_internal_include (ValaSourceFile* self, const c
  *
  * @return internal include list for C header file
  */
-GList* vala_source_file_get_header_internal_includes (ValaSourceFile* self)
+GeeCollection* vala_source_file_get_header_internal_includes (ValaSourceFile* self)
 {
 	g_return_val_if_fail (VALA_IS_SOURCE_FILE (self), NULL);
-	return self->priv->header_internal_includes;
+	return GEE_COLLECTION (gee_read_only_collection_new (g_strdup, g_free, GEE_COLLECTION (self->priv->header_internal_includes)));
 }
 
 
@@ -436,10 +440,10 @@ GList* vala_source_file_get_header_internal_includes (ValaSourceFile* self)
  *
  * @return include list for C source file
  */
-GList* vala_source_file_get_source_external_includes (ValaSourceFile* self)
+GeeCollection* vala_source_file_get_source_external_includes (ValaSourceFile* self)
 {
 	g_return_val_if_fail (VALA_IS_SOURCE_FILE (self), NULL);
-	return self->priv->source_external_includes;
+	return GEE_COLLECTION (gee_read_only_collection_new (g_strdup, g_free, GEE_COLLECTION (self->priv->source_external_includes)));
 }
 
 
@@ -449,10 +453,10 @@ GList* vala_source_file_get_source_external_includes (ValaSourceFile* self)
  *
  * @return include list for C source file
  */
-GList* vala_source_file_get_source_internal_includes (ValaSourceFile* self)
+GeeCollection* vala_source_file_get_source_internal_includes (ValaSourceFile* self)
 {
 	g_return_val_if_fail (VALA_IS_SOURCE_FILE (self), NULL);
-	return self->priv->source_internal_includes;
+	return GEE_COLLECTION (gee_read_only_collection_new (g_strdup, g_free, GEE_COLLECTION (self->priv->source_internal_includes)));
 }
 
 
@@ -462,10 +466,10 @@ GList* vala_source_file_get_source_internal_includes (ValaSourceFile* self)
  *
  * @return definite source file dependencies
  */
-GList* vala_source_file_get_header_internal_full_dependencies (ValaSourceFile* self)
+GeeCollection* vala_source_file_get_header_internal_full_dependencies (ValaSourceFile* self)
 {
 	g_return_val_if_fail (VALA_IS_SOURCE_FILE (self), NULL);
-	return self->priv->header_internal_full_dependencies;
+	return GEE_COLLECTION (gee_read_only_collection_new (NULL, NULL, GEE_COLLECTION (self->priv->header_internal_full_dependencies)));
 }
 
 
@@ -475,10 +479,10 @@ GList* vala_source_file_get_header_internal_full_dependencies (ValaSourceFile* s
  *
  * @return loose source file dependencies
  */
-GList* vala_source_file_get_header_internal_dependencies (ValaSourceFile* self)
+GeeCollection* vala_source_file_get_header_internal_dependencies (ValaSourceFile* self)
 {
 	g_return_val_if_fail (VALA_IS_SOURCE_FILE (self), NULL);
-	return self->priv->header_internal_dependencies;
+	return GEE_COLLECTION (gee_read_only_collection_new (NULL, NULL, GEE_COLLECTION (self->priv->header_internal_dependencies)));
 }
 
 
@@ -491,10 +495,10 @@ char* vala_source_file_get_filename (ValaSourceFile* self)
 
 void vala_source_file_set_filename (ValaSourceFile* self, const char* value)
 {
-	char* __temp35;
+	char* __temp25;
 	g_return_if_fail (VALA_IS_SOURCE_FILE (self));
-	__temp35 = NULL;
-	self->priv->_filename = (__temp35 = g_strdup (value), (self->priv->_filename = (g_free (self->priv->_filename), NULL)), __temp35);
+	__temp25 = NULL;
+	self->priv->_filename = (__temp25 = g_strdup (value), (self->priv->_filename = (g_free (self->priv->_filename), NULL)), __temp25);
 }
 
 
@@ -507,12 +511,12 @@ char* vala_source_file_get_comment (ValaSourceFile* self)
 
 void vala_source_file_set_comment (ValaSourceFile* self, const char* value)
 {
-	char* __temp38;
-	const char* __temp37;
+	char* __temp28;
+	const char* __temp27;
 	g_return_if_fail (VALA_IS_SOURCE_FILE (self));
-	__temp38 = NULL;
-	__temp37 = NULL;
-	self->priv->_comment = (__temp38 = (__temp37 = value, (__temp37 == NULL ? NULL : g_strdup (__temp37))), (self->priv->_comment = (g_free (self->priv->_comment), NULL)), __temp38);
+	__temp28 = NULL;
+	__temp27 = NULL;
+	self->priv->_comment = (__temp28 = (__temp27 = value, (__temp27 == NULL ? NULL : g_strdup (__temp27))), (self->priv->_comment = (g_free (self->priv->_comment), NULL)), __temp28);
 }
 
 
@@ -539,12 +543,12 @@ ValaSourceFileCycle* vala_source_file_get_cycle (ValaSourceFile* self)
 
 void vala_source_file_set_cycle (ValaSourceFile* self, ValaSourceFileCycle* value)
 {
-	ValaSourceFileCycle* __temp42;
-	ValaSourceFileCycle* __temp41;
+	ValaSourceFileCycle* __temp32;
+	ValaSourceFileCycle* __temp31;
 	g_return_if_fail (VALA_IS_SOURCE_FILE (self));
-	__temp42 = NULL;
-	__temp41 = NULL;
-	self->priv->_cycle = (__temp42 = (__temp41 = value, (__temp41 == NULL ? NULL : g_object_ref (__temp41))), (self->priv->_cycle == NULL ? NULL : (self->priv->_cycle = (g_object_unref (self->priv->_cycle), NULL))), __temp42);
+	__temp32 = NULL;
+	__temp31 = NULL;
+	self->priv->_cycle = (__temp32 = (__temp31 = value, (__temp31 == NULL ? NULL : g_object_ref (__temp31))), (self->priv->_cycle == NULL ? NULL : (self->priv->_cycle = (g_object_unref (self->priv->_cycle), NULL))), __temp32);
 }
 
 
@@ -590,25 +594,6 @@ void vala_source_file_set_context (ValaSourceFile* self, ValaCodeContext* value)
 }
 
 
-static GObject * vala_source_file_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties)
-{
-	GObject * obj;
-	ValaSourceFileClass * klass;
-	GObjectClass * parent_class;
-	ValaSourceFile * self;
-	klass = VALA_SOURCE_FILE_CLASS (g_type_class_peek (VALA_TYPE_SOURCE_FILE));
-	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
-	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
-	self = VALA_SOURCE_FILE (obj);
-	{
-		ValaNamespace* __temp46;
-		__temp46 = NULL;
-		self->priv->global_namespace = (__temp46 = vala_namespace_new (NULL, vala_source_reference_new (self, 0, 0, 0, 0)), (self->priv->global_namespace == NULL ? NULL : (self->priv->global_namespace = (g_object_unref (self->priv->global_namespace), NULL))), __temp46);
-	}
-	return obj;
-}
-
-
 static void vala_source_file_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec)
 {
 	ValaSourceFile * self;
@@ -675,9 +660,8 @@ static void vala_source_file_class_init (ValaSourceFileClass * klass)
 	g_type_class_add_private (klass, sizeof (ValaSourceFilePrivate));
 	G_OBJECT_CLASS (klass)->get_property = vala_source_file_get_property;
 	G_OBJECT_CLASS (klass)->set_property = vala_source_file_set_property;
-	G_OBJECT_CLASS (klass)->constructor = vala_source_file_constructor;
 	G_OBJECT_CLASS (klass)->dispose = vala_source_file_dispose;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_SOURCE_FILE_FILENAME, g_param_spec_string ("filename", "foo", "bar", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_SOURCE_FILE_FILENAME, g_param_spec_string ("filename", "foo", "bar", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_SOURCE_FILE_COMMENT, g_param_spec_string ("comment", "foo", "bar", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_SOURCE_FILE_PKG, g_param_spec_boolean ("pkg", "foo", "bar", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_SOURCE_FILE_CYCLE, g_param_spec_object ("cycle", "foo", "bar", VALA_TYPE_SOURCE_FILE_CYCLE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
@@ -690,9 +674,17 @@ static void vala_source_file_class_init (ValaSourceFileClass * klass)
 static void vala_source_file_init (ValaSourceFile * self)
 {
 	self->priv = VALA_SOURCE_FILE_GET_PRIVATE (self);
+	self->priv->using_directives = GEE_LIST (gee_array_list_new (g_object_ref, g_object_unref, g_direct_equal));
+	self->priv->nodes = GEE_LIST (gee_array_list_new (g_object_ref, g_object_unref, g_direct_equal));
 	self->priv->cheader_filename = NULL;
 	self->priv->csource_filename = NULL;
 	self->priv->cinclude_filename = NULL;
+	self->priv->header_external_includes = GEE_LIST (gee_array_list_new (g_strdup, g_free, g_direct_equal));
+	self->priv->header_internal_includes = GEE_LIST (gee_array_list_new (g_strdup, g_free, g_direct_equal));
+	self->priv->source_external_includes = GEE_LIST (gee_array_list_new (g_strdup, g_free, g_direct_equal));
+	self->priv->source_internal_includes = GEE_LIST (gee_array_list_new (g_strdup, g_free, g_direct_equal));
+	self->priv->header_internal_full_dependencies = GEE_LIST (gee_array_list_new (NULL, NULL, g_direct_equal));
+	self->priv->header_internal_dependencies = GEE_LIST (gee_array_list_new (NULL, NULL, g_direct_equal));
 }
 
 
@@ -705,25 +697,24 @@ static void vala_source_file_dispose (GObject * obj)
 	(self->priv->_filename = (g_free (self->priv->_filename), NULL));
 	(self->priv->_comment = (g_free (self->priv->_comment), NULL));
 	(self->priv->_cycle == NULL ? NULL : (self->priv->_cycle = (g_object_unref (self->priv->_cycle), NULL)));
-	(self->priv->using_directives == NULL ? NULL : (self->priv->using_directives = (g_list_foreach (self->priv->using_directives, (GFunc) g_object_unref, NULL), g_list_free (self->priv->using_directives), NULL)));
-	(self->priv->global_namespace == NULL ? NULL : (self->priv->global_namespace = (g_object_unref (self->priv->global_namespace), NULL)));
-	(self->priv->namespaces == NULL ? NULL : (self->priv->namespaces = (g_list_foreach (self->priv->namespaces, (GFunc) g_object_unref, NULL), g_list_free (self->priv->namespaces), NULL)));
+	(self->priv->using_directives == NULL ? NULL : (self->priv->using_directives = (g_object_unref (self->priv->using_directives), NULL)));
+	(self->priv->nodes == NULL ? NULL : (self->priv->nodes = (g_object_unref (self->priv->nodes), NULL)));
 	(self->priv->cheader_filename = (g_free (self->priv->cheader_filename), NULL));
 	(self->priv->csource_filename = (g_free (self->priv->csource_filename), NULL));
 	(self->priv->cinclude_filename = (g_free (self->priv->cinclude_filename), NULL));
-	(self->priv->header_external_includes == NULL ? NULL : (self->priv->header_external_includes = (g_list_foreach (self->priv->header_external_includes, (GFunc) g_free, NULL), g_list_free (self->priv->header_external_includes), NULL)));
-	(self->priv->header_internal_includes == NULL ? NULL : (self->priv->header_internal_includes = (g_list_foreach (self->priv->header_internal_includes, (GFunc) g_free, NULL), g_list_free (self->priv->header_internal_includes), NULL)));
-	(self->priv->source_external_includes == NULL ? NULL : (self->priv->source_external_includes = (g_list_foreach (self->priv->source_external_includes, (GFunc) g_free, NULL), g_list_free (self->priv->source_external_includes), NULL)));
-	(self->priv->source_internal_includes == NULL ? NULL : (self->priv->source_internal_includes = (g_list_foreach (self->priv->source_internal_includes, (GFunc) g_free, NULL), g_list_free (self->priv->source_internal_includes), NULL)));
-	(self->priv->header_internal_full_dependencies == NULL ? NULL : (self->priv->header_internal_full_dependencies = (g_list_free (self->priv->header_internal_full_dependencies), NULL)));
-	(self->priv->header_internal_dependencies == NULL ? NULL : (self->priv->header_internal_dependencies = (g_list_free (self->priv->header_internal_dependencies), NULL)));
+	(self->priv->header_external_includes == NULL ? NULL : (self->priv->header_external_includes = (g_object_unref (self->priv->header_external_includes), NULL)));
+	(self->priv->header_internal_includes == NULL ? NULL : (self->priv->header_internal_includes = (g_object_unref (self->priv->header_internal_includes), NULL)));
+	(self->priv->source_external_includes == NULL ? NULL : (self->priv->source_external_includes = (g_object_unref (self->priv->source_external_includes), NULL)));
+	(self->priv->source_internal_includes == NULL ? NULL : (self->priv->source_internal_includes = (g_object_unref (self->priv->source_internal_includes), NULL)));
+	(self->priv->header_internal_full_dependencies == NULL ? NULL : (self->priv->header_internal_full_dependencies = (g_object_unref (self->priv->header_internal_full_dependencies), NULL)));
+	(self->priv->header_internal_dependencies == NULL ? NULL : (self->priv->header_internal_dependencies = (g_object_unref (self->priv->header_internal_dependencies), NULL)));
 	klass = VALA_SOURCE_FILE_CLASS (g_type_class_peek (VALA_TYPE_SOURCE_FILE));
 	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
 	parent_class->dispose (obj);
 }
 
 
-GType vala_source_file_get_type ()
+GType vala_source_file_get_type (void)
 {
 	static GType vala_source_file_type_id = 0;
 	if (G_UNLIKELY (vala_source_file_type_id == 0)) {
