@@ -1,6 +1,6 @@
 /* valastringliteral.vala
  *
- * Copyright (C) 2006  Jürg Billeter
+ * Copyright (C) 2006-2007  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -19,8 +19,6 @@
  * Author:
  * 	Jürg Billeter <j@bitron.ch>
  */
-#define VALA_FREE_CHECKED(o,f) ((o) == NULL ? NULL : ((o) = (f (o), NULL)))
-#define VALA_FREE_UNCHECKED(o,f) ((o) = (f (o), NULL))
 
 #include "valastringliteral.h"
 #include <vala/valasourcereference.h>
@@ -33,7 +31,7 @@ struct _ValaStringLiteralPrivate {
 #define VALA_STRING_LITERAL_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_STRING_LITERAL, ValaStringLiteralPrivate))
 enum  {
 	VALA_STRING_LITERAL_DUMMY_PROPERTY,
-	VALA_STRING_LITERAL_VALUE,
+	VALA_STRING_LITERAL_VALUE
 };
 static void vala_string_literal_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static gpointer vala_string_literal_parent_class = NULL;
@@ -49,12 +47,11 @@ static void vala_string_literal_dispose (GObject * obj);
  */
 ValaStringLiteral* vala_string_literal_new (const char* s, ValaSourceReference* source)
 {
+	ValaStringLiteral * self;
 	g_return_val_if_fail (source == NULL || VALA_IS_SOURCE_REFERENCE (source), NULL);
-	GParameter * __params = g_new0 (GParameter, 2);
-	GParameter * __params_it = __params;
-	(__params_it->name = "value", g_value_init (&__params_it->value, G_TYPE_STRING), g_value_set_string (&__params_it->value, s), __params_it++);
-	(__params_it->name = "source-reference", g_value_init (&__params_it->value, VALA_TYPE_SOURCE_REFERENCE), g_value_set_object (&__params_it->value, source), __params_it++);
-	ValaStringLiteral * self = g_object_newv (VALA_TYPE_STRING_LITERAL, __params_it - __params, __params);
+	self = g_object_newv (VALA_TYPE_STRING_LITERAL, 0, NULL);
+	vala_string_literal_set_value (self, s);
+	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source);
 	return self;
 }
 
@@ -66,13 +63,15 @@ ValaStringLiteral* vala_string_literal_new (const char* s, ValaSourceReference*
  */
 char* vala_string_literal_eval (ValaStringLiteral* self)
 {
+	char* noquotes;
+	char* __temp1;
 	g_return_val_if_fail (VALA_IS_STRING_LITERAL (self), NULL);
 	if (vala_string_literal_get_value (self) == NULL) {
 		return NULL;
 	}
 	/* remove quotes */
-	char* noquotes = g_strndup (g_utf8_offset_to_pointer (vala_string_literal_get_value (self), 1), ((guint) (g_utf8_strlen (vala_string_literal_get_value (self), -1) - 2)));
-	char* __temp1 = NULL;
+	noquotes = g_strndup (g_utf8_offset_to_pointer (vala_string_literal_get_value (self), 1), ((guint) (g_utf8_strlen (vala_string_literal_get_value (self), -1) - 2)));
+	__temp1 = NULL;
 	return (__temp1 = g_strcompress (noquotes), (noquotes = (g_free (noquotes), NULL)), __temp1);
 	(noquotes = (g_free (noquotes), NULL));
 }
@@ -81,7 +80,8 @@ char* vala_string_literal_eval (ValaStringLiteral* self)
 /* unescape string */
 static void vala_string_literal_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor)
 {
-	ValaStringLiteral * self = VALA_STRING_LITERAL (base);
+	ValaStringLiteral * self;
+	self = ((ValaStringLiteral*) base);
 	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	vala_code_visitor_visit_string_literal (visitor, self);
 }
@@ -96,16 +96,19 @@ char* vala_string_literal_get_value (ValaStringLiteral* self)
 
 void vala_string_literal_set_value (ValaStringLiteral* self, const char* value)
 {
+	char* __temp4;
+	const char* __temp3;
 	g_return_if_fail (VALA_IS_STRING_LITERAL (self));
-	char* __temp4 = NULL;
-	const char* __temp3 = NULL;
+	__temp4 = NULL;
+	__temp3 = NULL;
 	self->priv->_value = (__temp4 = (__temp3 = value, (__temp3 == NULL ? NULL : g_strdup (__temp3))), (self->priv->_value = (g_free (self->priv->_value), NULL)), __temp4);
 }
 
 
 static void vala_string_literal_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec)
 {
-	ValaStringLiteral * self = VALA_STRING_LITERAL (object);
+	ValaStringLiteral * self;
+	self = VALA_STRING_LITERAL (object);
 	switch (property_id) {
 		case VALA_STRING_LITERAL_VALUE:
 		g_value_set_string (value, vala_string_literal_get_value (self));
@@ -116,7 +119,8 @@ static void vala_string_literal_get_property (GObject * object, guint property_i
 
 static void vala_string_literal_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec)
 {
-	ValaStringLiteral * self = VALA_STRING_LITERAL (object);
+	ValaStringLiteral * self;
+	self = VALA_STRING_LITERAL (object);
 	switch (property_id) {
 		case VALA_STRING_LITERAL_VALUE:
 		vala_string_literal_set_value (self, g_value_get_string (value));
@@ -145,17 +149,18 @@ static void vala_string_literal_init (ValaStringLiteral * self)
 
 static void vala_string_literal_dispose (GObject * obj)
 {
-	ValaStringLiteral * self = VALA_STRING_LITERAL (obj);
-	(self->priv->_value = (g_free (self->priv->_value), NULL));
+	ValaStringLiteral * self;
 	ValaStringLiteralClass * klass;
 	GObjectClass * parent_class;
+	self = VALA_STRING_LITERAL (obj);
+	(self->priv->_value = (g_free (self->priv->_value), NULL));
 	klass = VALA_STRING_LITERAL_CLASS (g_type_class_peek (VALA_TYPE_STRING_LITERAL));
 	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
 	parent_class->dispose (obj);
 }
 
 
-GType vala_string_literal_get_type ()
+GType vala_string_literal_get_type (void)
 {
 	static GType vala_string_literal_type_id = 0;
 	if (G_UNLIKELY (vala_string_literal_type_id == 0)) {
