@@ -27,6 +27,7 @@
 #include <glib-object.h>
 #include <stdlib.h>
 #include <string.h>
+#include <gee/collection.h>
 #include <vala/valacodenode.h>
 
 G_BEGIN_DECLS
@@ -45,26 +46,32 @@ typedef struct _ValaSymbolPrivate ValaSymbolPrivate;
  * Represents a node in the symbol tree.
  */
 struct _ValaSymbol {
-	GObject parent;
+	ValaCodeNode parent;
 	ValaSymbolPrivate * priv;
 };
 struct _ValaSymbolClass {
-	GObjectClass parent;
+	ValaCodeNodeClass parent;
+	char* (*get_cprefix) (ValaSymbol* self);
+	char* (*get_lower_case_cname) (ValaSymbol* self, const char* infix);
+	char* (*get_lower_case_cprefix) (ValaSymbol* self);
+	GeeCollection* (*get_cheader_filenames) (ValaSymbol* self);
 };
 
-ValaSymbol* vala_symbol_new (ValaCodeNode* _node);
 char* vala_symbol_get_full_name (ValaSymbol* self);
-void vala_symbol_add (ValaSymbol* self, const char* name, ValaSymbol* sym);
-ValaSymbol* vala_symbol_lookup (ValaSymbol* self, const char* name);
-ValaCodeNode* vala_symbol_get_node (ValaSymbol* self);
-void vala_symbol_set_node (ValaSymbol* self, ValaCodeNode* value);
+char* vala_symbol_get_cprefix (ValaSymbol* self);
+char* vala_symbol_get_lower_case_cname (ValaSymbol* self, const char* infix);
+char* vala_symbol_get_lower_case_cprefix (ValaSymbol* self);
+GeeCollection* vala_symbol_get_cheader_filenames (ValaSymbol* self);
+char* vala_symbol_camel_case_to_lower_case (const char* camel_case);
 ValaSymbol* vala_symbol_get_parent_symbol (ValaSymbol* self);
-void vala_symbol_set_parent_symbol (ValaSymbol* self, ValaSymbol* value);
+ValaScope* vala_symbol_get_owner (ValaSymbol* self);
+void vala_symbol_set_owner (ValaSymbol* self, ValaScope* value);
 char* vala_symbol_get_name (ValaSymbol* self);
 void vala_symbol_set_name (ValaSymbol* self, const char* value);
 gboolean vala_symbol_get_active (ValaSymbol* self);
 void vala_symbol_set_active (ValaSymbol* self, gboolean value);
-GType vala_symbol_get_type ();
+ValaScope* vala_symbol_get_scope (ValaSymbol* self);
+GType vala_symbol_get_type (void);
 
 G_END_DECLS
 
