@@ -22,16 +22,12 @@
 
 #ifndef __VALASYMBOLRESOLVER_H__
 #define __VALASYMBOLRESOLVER_H__
-typedef struct _ValaSymbolResolver ValaSymbolResolver;
-typedef struct _ValaSymbolResolverClass ValaSymbolResolverClass;
-typedef struct _ValaSymbolResolverPrivate ValaSymbolResolverPrivate;
 
 #include <glib.h>
 #include <glib-object.h>
 #include <vala/valacodevisitor.h>
 #include <vala/valacodecontext.h>
 #include <vala/valasourcefile.h>
-#include <vala/valanamespace.h>
 #include <vala/valaclass.h>
 #include <vala/valastruct.h>
 #include <vala/valainterface.h>
@@ -49,6 +45,9 @@ typedef struct _ValaSymbolResolverPrivate ValaSymbolResolverPrivate;
 #include <vala/valadestructor.h>
 #include <vala/valanamespacereference.h>
 #include <vala/valatypereference.h>
+#include <vala/valathrowstatement.h>
+#include <vala/valatrystatement.h>
+#include <vala/valacatchclause.h>
 
 G_BEGIN_DECLS
 
@@ -60,6 +59,9 @@ G_BEGIN_DECLS
 #define VALA_IS_SYMBOL_RESOLVER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_SYMBOL_RESOLVER))
 #define VALA_SYMBOL_RESOLVER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_SYMBOL_RESOLVER, ValaSymbolResolverClass))
 
+typedef struct _ValaSymbolResolver ValaSymbolResolver;
+typedef struct _ValaSymbolResolverClass ValaSymbolResolverClass;
+typedef struct _ValaSymbolResolverPrivate ValaSymbolResolverPrivate;
 
 /**
  * Code visitor resolving symbol names.
@@ -73,7 +75,7 @@ struct _ValaSymbolResolverClass {
 };
 
 void vala_symbol_resolver_resolve (ValaSymbolResolver* self, ValaCodeContext* context);
-GType vala_symbol_resolver_get_type ();
+GType vala_symbol_resolver_get_type (void);
 
 G_END_DECLS
 
