@@ -25,8 +25,8 @@
 
 #include <glib.h>
 #include <glib-object.h>
-#include <vala/valastatement.h>
 #include <vala/valacodenode.h>
+#include <vala/valastatement.h>
 
 G_BEGIN_DECLS
 
@@ -44,17 +44,17 @@ typedef struct _ValaThrowStatementPrivate ValaThrowStatementPrivate;
  * Represents a throw statement in the source code.
  */
 struct _ValaThrowStatement {
-	ValaStatement parent;
+	ValaCodeNode parent;
 	ValaThrowStatementPrivate * priv;
 };
 struct _ValaThrowStatementClass {
-	ValaStatementClass parent;
+	ValaCodeNodeClass parent;
 };
 
 ValaThrowStatement* vala_throw_statement_new (ValaExpression* error_expression, ValaSourceReference* source_reference);
 ValaExpression* vala_throw_statement_get_error_expression (ValaThrowStatement* self);
 void vala_throw_statement_set_error_expression (ValaThrowStatement* self, ValaExpression* value);
-GType vala_throw_statement_get_type ();
+GType vala_throw_statement_get_type (void);
 
 G_END_DECLS
 
