@@ -54,7 +54,7 @@ struct _ValaTypeofExpressionClass {
 ValaTypeofExpression* vala_typeof_expression_new (ValaTypeReference* type, ValaSourceReference* source);
 ValaTypeReference* vala_typeof_expression_get_type_reference (ValaTypeofExpression* self);
 void vala_typeof_expression_set_type_reference (ValaTypeofExpression* self, ValaTypeReference* value);
-GType vala_typeof_expression_get_type ();
+GType vala_typeof_expression_get_type (void);
 
 G_END_DECLS
 
